// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v0/services/campaign_criterion_service.proto

package services // import "google.golang.org/genproto/googleapis/ads/googleads/v0/services"

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"
import resources "google.golang.org/genproto/googleapis/ads/googleads/v0/resources"
import _ "google.golang.org/genproto/googleapis/api/annotations"
import field_mask "google.golang.org/genproto/protobuf/field_mask"

import (
	context "golang.org/x/net/context"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// Request message for [CampaignCriterionService.GetCampaignCriterion][google.ads.googleads.v0.services.CampaignCriterionService.GetCampaignCriterion].
type GetCampaignCriterionRequest struct {
	// The resource name of the criterion to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetCampaignCriterionRequest) Reset()         { *m = GetCampaignCriterionRequest{} }
func (m *GetCampaignCriterionRequest) String() string { return proto.CompactTextString(m) }
func (*GetCampaignCriterionRequest) ProtoMessage()    {}
func (*GetCampaignCriterionRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_campaign_criterion_service_9e44f1f5d681490b, []int{0}
}
func (m *GetCampaignCriterionRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetCampaignCriterionRequest.Unmarshal(m, b)
}
func (m *GetCampaignCriterionRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetCampaignCriterionRequest.Marshal(b, m, deterministic)
}
func (dst *GetCampaignCriterionRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetCampaignCriterionRequest.Merge(dst, src)
}
func (m *GetCampaignCriterionRequest) XXX_Size() int {
	return xxx_messageInfo_GetCampaignCriterionRequest.Size(m)
}
func (m *GetCampaignCriterionRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetCampaignCriterionRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetCampaignCriterionRequest proto.InternalMessageInfo

func (m *GetCampaignCriterionRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

// Request message for [CampaignCriterionService.MutateCampaignCriteria][google.ads.googleads.v0.services.CampaignCriterionService.MutateCampaignCriteria].
type MutateCampaignCriteriaRequest struct {
	// The ID of the customer whose criteria are being modified.
	CustomerId string `protobuf:"bytes,1,opt,name=customer_id,json=customerId,proto3" json:"customer_id,omitempty"`
	// The list of operations to perform on individual criteria.
	Operations           []*CampaignCriterionOperation `protobuf:"bytes,2,rep,name=operations,proto3" json:"operations,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                      `json:"-"`
	XXX_unrecognized     []byte                        `json:"-"`
	XXX_sizecache        int32                         `json:"-"`
}

func (m *MutateCampaignCriteriaRequest) Reset()         { *m = MutateCampaignCriteriaRequest{} }
func (m *MutateCampaignCriteriaRequest) String() string { return proto.CompactTextString(m) }
func (*MutateCampaignCriteriaRequest) ProtoMessage()    {}
func (*MutateCampaignCriteriaRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_campaign_criterion_service_9e44f1f5d681490b, []int{1}
}
func (m *MutateCampaignCriteriaRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MutateCampaignCriteriaRequest.Unmarshal(m, b)
}
func (m *MutateCampaignCriteriaRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MutateCampaignCriteriaRequest.Marshal(b, m, deterministic)
}
func (dst *MutateCampaignCriteriaRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MutateCampaignCriteriaRequest.Merge(dst, src)
}
func (m *MutateCampaignCriteriaRequest) XXX_Size() int {
	return xxx_messageInfo_MutateCampaignCriteriaRequest.Size(m)
}
func (m *MutateCampaignCriteriaRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_MutateCampaignCriteriaRequest.DiscardUnknown(m)
}

var xxx_messageInfo_MutateCampaignCriteriaRequest proto.InternalMessageInfo

func (m *MutateCampaignCriteriaRequest) GetCustomerId() string {
	if m != nil {
		return m.CustomerId
	}
	return ""
}

func (m *MutateCampaignCriteriaRequest) GetOperations() []*CampaignCriterionOperation {
	if m != nil {
		return m.Operations
	}
	return nil
}

// A single operation (create, update, remove) on a campaign criterion.
type CampaignCriterionOperation struct {
	// FieldMask that determines which resource fields are modified in an update.
	UpdateMask *field_mask.FieldMask `protobuf:"bytes,4,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
	// The mutate operation.
	//
	// Types that are valid to be assigned to Operation:
	//	*CampaignCriterionOperation_Create
	//	*CampaignCriterionOperation_Update
	//	*CampaignCriterionOperation_Remove
	Operation            isCampaignCriterionOperation_Operation `protobuf_oneof:"operation"`
	XXX_NoUnkeyedLiteral struct{}                               `json:"-"`
	XXX_unrecognized     []byte                                 `json:"-"`
	XXX_sizecache        int32                                  `json:"-"`
}

func (m *CampaignCriterionOperation) Reset()         { *m = CampaignCriterionOperation{} }
func (m *CampaignCriterionOperation) String() string { return proto.CompactTextString(m) }
func (*CampaignCriterionOperation) ProtoMessage()    {}
func (*CampaignCriterionOperation) Descriptor() ([]byte, []int) {
	return fileDescriptor_campaign_criterion_service_9e44f1f5d681490b, []int{2}
}
func (m *CampaignCriterionOperation) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CampaignCriterionOperation.Unmarshal(m, b)
}
func (m *CampaignCriterionOperation) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CampaignCriterionOperation.Marshal(b, m, deterministic)
}
func (dst *CampaignCriterionOperation) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CampaignCriterionOperation.Merge(dst, src)
}
func (m *CampaignCriterionOperation) XXX_Size() int {
	return xxx_messageInfo_CampaignCriterionOperation.Size(m)
}
func (m *CampaignCriterionOperation) XXX_DiscardUnknown() {
	xxx_messageInfo_CampaignCriterionOperation.DiscardUnknown(m)
}

var xxx_messageInfo_CampaignCriterionOperation proto.InternalMessageInfo

func (m *CampaignCriterionOperation) GetUpdateMask() *field_mask.FieldMask {
	if m != nil {
		return m.UpdateMask
	}
	return nil
}

type isCampaignCriterionOperation_Operation interface {
	isCampaignCriterionOperation_Operation()
}

type CampaignCriterionOperation_Create struct {
	Create *resources.CampaignCriterion `protobuf:"bytes,1,opt,name=create,proto3,oneof"`
}

type CampaignCriterionOperation_Update struct {
	Update *resources.CampaignCriterion `protobuf:"bytes,2,opt,name=update,proto3,oneof"`
}

type CampaignCriterionOperation_Remove struct {
	Remove string `protobuf:"bytes,3,opt,name=remove,proto3,oneof"`
}

func (*CampaignCriterionOperation_Create) isCampaignCriterionOperation_Operation() {}

func (*CampaignCriterionOperation_Update) isCampaignCriterionOperation_Operation() {}

func (*CampaignCriterionOperation_Remove) isCampaignCriterionOperation_Operation() {}

func (m *CampaignCriterionOperation) GetOperation() isCampaignCriterionOperation_Operation {
	if m != nil {
		return m.Operation
	}
	return nil
}

func (m *CampaignCriterionOperation) GetCreate() *resources.CampaignCriterion {
	if x, ok := m.GetOperation().(*CampaignCriterionOperation_Create); ok {
		return x.Create
	}
	return nil
}

func (m *CampaignCriterionOperation) GetUpdate() *resources.CampaignCriterion {
	if x, ok := m.GetOperation().(*CampaignCriterionOperation_Update); ok {
		return x.Update
	}
	return nil
}

func (m *CampaignCriterionOperation) GetRemove() string {
	if x, ok := m.GetOperation().(*CampaignCriterionOperation_Remove); ok {
		return x.Remove
	}
	return ""
}

// XXX_OneofFuncs is for the internal use of the proto package.
func (*CampaignCriterionOperation) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, func(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error), func(msg proto.Message) (n int), []interface{}) {
	return _CampaignCriterionOperation_OneofMarshaler, _CampaignCriterionOperation_OneofUnmarshaler, _CampaignCriterionOperation_OneofSizer, []interface{}{
		(*CampaignCriterionOperation_Create)(nil),
		(*CampaignCriterionOperation_Update)(nil),
		(*CampaignCriterionOperation_Remove)(nil),
	}
}

func _CampaignCriterionOperation_OneofMarshaler(msg proto.Message, b *proto.Buffer) error {
	m := msg.(*CampaignCriterionOperation)
	// operation
	switch x := m.Operation.(type) {
	case *CampaignCriterionOperation_Create:
		b.EncodeVarint(1<<3 | proto.WireBytes)
		if err := b.EncodeMessage(x.Create); err != nil {
			return err
		}
	case *CampaignCriterionOperation_Update:
		b.EncodeVarint(2<<3 | proto.WireBytes)
		if err := b.EncodeMessage(x.Update); err != nil {
			return err
		}
	case *CampaignCriterionOperation_Remove:
		b.EncodeVarint(3<<3 | proto.WireBytes)
		b.EncodeStringBytes(x.Remove)
	case nil:
	default:
		return fmt.Errorf("CampaignCriterionOperation.Operation has unexpected type %T", x)
	}
	return nil
}

func _CampaignCriterionOperation_OneofUnmarshaler(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error) {
	m := msg.(*CampaignCriterionOperation)
	switch tag {
	case 1: // operation.create
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		msg := new(resources.CampaignCriterion)
		err := b.DecodeMessage(msg)
		m.Operation = &CampaignCriterionOperation_Create{msg}
		return true, err
	case 2: // operation.update
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		msg := new(resources.CampaignCriterion)
		err := b.DecodeMessage(msg)
		m.Operation = &CampaignCriterionOperation_Update{msg}
		return true, err
	case 3: // operation.remove
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		x, err := b.DecodeStringBytes()
		m.Operation = &CampaignCriterionOperation_Remove{x}
		return true, err
	default:
		return false, nil
	}
}

func _CampaignCriterionOperation_OneofSizer(msg proto.Message) (n int) {
	m := msg.(*CampaignCriterionOperation)
	// operation
	switch x := m.Operation.(type) {
	case *CampaignCriterionOperation_Create:
		s := proto.Size(x.Create)
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(s))
		n += s
	case *CampaignCriterionOperation_Update:
		s := proto.Size(x.Update)
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(s))
		n += s
	case *CampaignCriterionOperation_Remove:
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(len(x.Remove)))
		n += len(x.Remove)
	case nil:
	default:
		panic(fmt.Sprintf("proto: unexpected type %T in oneof", x))
	}
	return n
}

// Response message for campaign criterion mutate.
type MutateCampaignCriteriaResponse struct {
	// All results for the mutate.
	Results              []*MutateCampaignCriterionResult `protobuf:"bytes,2,rep,name=results,proto3" json:"results,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                         `json:"-"`
	XXX_unrecognized     []byte                           `json:"-"`
	XXX_sizecache        int32                            `json:"-"`
}

func (m *MutateCampaignCriteriaResponse) Reset()         { *m = MutateCampaignCriteriaResponse{} }
func (m *MutateCampaignCriteriaResponse) String() string { return proto.CompactTextString(m) }
func (*MutateCampaignCriteriaResponse) ProtoMessage()    {}
func (*MutateCampaignCriteriaResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_campaign_criterion_service_9e44f1f5d681490b, []int{3}
}
func (m *MutateCampaignCriteriaResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MutateCampaignCriteriaResponse.Unmarshal(m, b)
}
func (m *MutateCampaignCriteriaResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MutateCampaignCriteriaResponse.Marshal(b, m, deterministic)
}
func (dst *MutateCampaignCriteriaResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MutateCampaignCriteriaResponse.Merge(dst, src)
}
func (m *MutateCampaignCriteriaResponse) XXX_Size() int {
	return xxx_messageInfo_MutateCampaignCriteriaResponse.Size(m)
}
func (m *MutateCampaignCriteriaResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_MutateCampaignCriteriaResponse.DiscardUnknown(m)
}

var xxx_messageInfo_MutateCampaignCriteriaResponse proto.InternalMessageInfo

func (m *MutateCampaignCriteriaResponse) GetResults() []*MutateCampaignCriterionResult {
	if m != nil {
		return m.Results
	}
	return nil
}

// The result for the criterion mutate.
type MutateCampaignCriterionResult struct {
	// Returned for successful operations.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *MutateCampaignCriterionResult) Reset()         { *m = MutateCampaignCriterionResult{} }
func (m *MutateCampaignCriterionResult) String() string { return proto.CompactTextString(m) }
func (*MutateCampaignCriterionResult) ProtoMessage()    {}
func (*MutateCampaignCriterionResult) Descriptor() ([]byte, []int) {
	return fileDescriptor_campaign_criterion_service_9e44f1f5d681490b, []int{4}
}
func (m *MutateCampaignCriterionResult) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MutateCampaignCriterionResult.Unmarshal(m, b)
}
func (m *MutateCampaignCriterionResult) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MutateCampaignCriterionResult.Marshal(b, m, deterministic)
}
func (dst *MutateCampaignCriterionResult) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MutateCampaignCriterionResult.Merge(dst, src)
}
func (m *MutateCampaignCriterionResult) XXX_Size() int {
	return xxx_messageInfo_MutateCampaignCriterionResult.Size(m)
}
func (m *MutateCampaignCriterionResult) XXX_DiscardUnknown() {
	xxx_messageInfo_MutateCampaignCriterionResult.DiscardUnknown(m)
}

var xxx_messageInfo_MutateCampaignCriterionResult proto.InternalMessageInfo

func (m *MutateCampaignCriterionResult) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetCampaignCriterionRequest)(nil), "google.ads.googleads.v0.services.GetCampaignCriterionRequest")
	proto.RegisterType((*MutateCampaignCriteriaRequest)(nil), "google.ads.googleads.v0.services.MutateCampaignCriteriaRequest")
	proto.RegisterType((*CampaignCriterionOperation)(nil), "google.ads.googleads.v0.services.CampaignCriterionOperation")
	proto.RegisterType((*MutateCampaignCriteriaResponse)(nil), "google.ads.googleads.v0.services.MutateCampaignCriteriaResponse")
	proto.RegisterType((*MutateCampaignCriterionResult)(nil), "google.ads.googleads.v0.services.MutateCampaignCriterionResult")
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// CampaignCriterionServiceClient is the client API for CampaignCriterionService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type CampaignCriterionServiceClient interface {
	// Returns the requested criterion in full detail.
	GetCampaignCriterion(ctx context.Context, in *GetCampaignCriterionRequest, opts ...grpc.CallOption) (*resources.CampaignCriterion, error)
	// Creates, updates, or removes criteria. Operation statuses are returned.
	MutateCampaignCriteria(ctx context.Context, in *MutateCampaignCriteriaRequest, opts ...grpc.CallOption) (*MutateCampaignCriteriaResponse, error)
}

type campaignCriterionServiceClient struct {
	cc *grpc.ClientConn
}

func NewCampaignCriterionServiceClient(cc *grpc.ClientConn) CampaignCriterionServiceClient {
	return &campaignCriterionServiceClient{cc}
}

func (c *campaignCriterionServiceClient) GetCampaignCriterion(ctx context.Context, in *GetCampaignCriterionRequest, opts ...grpc.CallOption) (*resources.CampaignCriterion, error) {
	out := new(resources.CampaignCriterion)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v0.services.CampaignCriterionService/GetCampaignCriterion", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *campaignCriterionServiceClient) MutateCampaignCriteria(ctx context.Context, in *MutateCampaignCriteriaRequest, opts ...grpc.CallOption) (*MutateCampaignCriteriaResponse, error) {
	out := new(MutateCampaignCriteriaResponse)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v0.services.CampaignCriterionService/MutateCampaignCriteria", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// CampaignCriterionServiceServer is the server API for CampaignCriterionService service.
type CampaignCriterionServiceServer interface {
	// Returns the requested criterion in full detail.
	GetCampaignCriterion(context.Context, *GetCampaignCriterionRequest) (*resources.CampaignCriterion, error)
	// Creates, updates, or removes criteria. Operation statuses are returned.
	MutateCampaignCriteria(context.Context, *MutateCampaignCriteriaRequest) (*MutateCampaignCriteriaResponse, error)
}

func RegisterCampaignCriterionServiceServer(s *grpc.Server, srv CampaignCriterionServiceServer) {
	s.RegisterService(&_CampaignCriterionService_serviceDesc, srv)
}

func _CampaignCriterionService_GetCampaignCriterion_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetCampaignCriterionRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(CampaignCriterionServiceServer).GetCampaignCriterion(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v0.services.CampaignCriterionService/GetCampaignCriterion",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(CampaignCriterionServiceServer).GetCampaignCriterion(ctx, req.(*GetCampaignCriterionRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _CampaignCriterionService_MutateCampaignCriteria_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(MutateCampaignCriteriaRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(CampaignCriterionServiceServer).MutateCampaignCriteria(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v0.services.CampaignCriterionService/MutateCampaignCriteria",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(CampaignCriterionServiceServer).MutateCampaignCriteria(ctx, req.(*MutateCampaignCriteriaRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _CampaignCriterionService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v0.services.CampaignCriterionService",
	HandlerType: (*CampaignCriterionServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetCampaignCriterion",
			Handler:    _CampaignCriterionService_GetCampaignCriterion_Handler,
		},
		{
			MethodName: "MutateCampaignCriteria",
			Handler:    _CampaignCriterionService_MutateCampaignCriteria_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v0/services/campaign_criterion_service.proto",
}

func init() {
	proto.RegisterFile("google/ads/googleads/v0/services/campaign_criterion_service.proto", fileDescriptor_campaign_criterion_service_9e44f1f5d681490b)
}

var fileDescriptor_campaign_criterion_service_9e44f1f5d681490b = []byte{
	// 599 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xa4, 0x94, 0x4f, 0x6f, 0xd3, 0x3e,
	0x18, 0xc7, 0x7f, 0x49, 0x7f, 0x2a, 0x9a, 0x03, 0x17, 0x0b, 0xa1, 0x28, 0x30, 0xa8, 0x02, 0x87,
	0xaa, 0x07, 0xa7, 0x2a, 0xe3, 0xd2, 0x51, 0xb1, 0x76, 0x88, 0x8e, 0xc3, 0xc6, 0x14, 0xa4, 0x49,
	0xa0, 0x4a, 0x95, 0x97, 0x78, 0x51, 0xb4, 0x26, 0x0e, 0xb6, 0xd3, 0x4b, 0xb5, 0x0b, 0x6f, 0x81,
	0x3b, 0x42, 0x1c, 0x79, 0x1d, 0x48, 0x48, 0x5c, 0x39, 0xef, 0xc6, 0x0b, 0x41, 0x8e, 0xe3, 0x30,
	0x68, 0x43, 0x51, 0xb9, 0x3d, 0x89, 0x1f, 0x7f, 0x9e, 0x3f, 0xdf, 0xe7, 0x31, 0x18, 0x46, 0x94,
	0x46, 0x33, 0xe2, 0xe1, 0x90, 0x7b, 0xca, 0x94, 0xd6, 0xbc, 0xeb, 0x71, 0xc2, 0xe6, 0x71, 0x40,
	0xb8, 0x17, 0xe0, 0x24, 0xc3, 0x71, 0x94, 0x4e, 0x03, 0x16, 0x0b, 0xc2, 0x62, 0x9a, 0x4e, 0xcb,
	0x33, 0x94, 0x31, 0x2a, 0x28, 0x6c, 0xa9, 0x7b, 0x08, 0x87, 0x1c, 0x55, 0x08, 0x34, 0xef, 0x22,
	0x8d, 0x70, 0xfa, 0x75, 0x41, 0x18, 0xe1, 0x34, 0x67, 0xab, 0xa3, 0x28, 0xba, 0x73, 0x47, 0xdf,
	0xcd, 0x62, 0x0f, 0xa7, 0x29, 0x15, 0x58, 0xc4, 0x34, 0xe5, 0xe5, 0x69, 0x19, 0xdb, 0x2b, 0xbe,
	0x4e, 0xf3, 0x33, 0xef, 0x2c, 0x26, 0xb3, 0x70, 0x9a, 0x60, 0x7e, 0xae, 0x3c, 0xdc, 0x11, 0xb8,
	0x3d, 0x26, 0x62, 0xbf, 0xc4, 0xef, 0x6b, 0xba, 0x4f, 0xde, 0xe4, 0x84, 0x0b, 0x78, 0x1f, 0xdc,
	0xd0, 0x49, 0x4c, 0x53, 0x9c, 0x10, 0xdb, 0x68, 0x19, 0xed, 0x2d, 0xff, 0xba, 0xfe, 0x79, 0x84,
	0x13, 0xe2, 0xbe, 0x37, 0xc0, 0xf6, 0x61, 0x2e, 0xb0, 0x20, 0xbf, 0x71, 0xb0, 0xc6, 0xdc, 0x03,
	0x56, 0x90, 0x73, 0x41, 0x13, 0xc2, 0xa6, 0x71, 0x58, 0x42, 0x80, 0xfe, 0xf5, 0x3c, 0x84, 0x13,
	0x00, 0x68, 0x46, 0x98, 0x4a, 0xde, 0x36, 0x5b, 0x8d, 0xb6, 0xd5, 0x7b, 0x8c, 0xd6, 0x75, 0x0e,
	0x2d, 0xe5, 0xfd, 0x42, 0x43, 0xfc, 0x2b, 0x3c, 0xf7, 0x83, 0x09, 0x9c, 0x7a, 0x57, 0xb8, 0x0b,
	0xac, 0x3c, 0x0b, 0xb1, 0x20, 0x45, 0x63, 0xec, 0xff, 0x5b, 0x46, 0xdb, 0xea, 0x39, 0x3a, 0xba,
	0xee, 0x1d, 0x7a, 0x26, 0x7b, 0x77, 0x88, 0xf9, 0xb9, 0x0f, 0x94, 0xbb, 0xb4, 0xe1, 0x11, 0x68,
	0x06, 0x8c, 0x60, 0xa1, 0x5a, 0x63, 0xf5, 0x76, 0x6a, 0xb3, 0xae, 0xd4, 0x5c, 0x4e, 0xfb, 0xe0,
	0x3f, 0xbf, 0xa4, 0x48, 0x9e, 0xa2, 0xdb, 0xe6, 0xbf, 0xf1, 0x14, 0x05, 0xda, 0xa0, 0xc9, 0x48,
	0x42, 0xe7, 0xc4, 0x6e, 0xc8, 0xae, 0xcb, 0x13, 0xf5, 0x3d, 0xb2, 0xc0, 0x56, 0xd5, 0x23, 0x77,
	0x01, 0xee, 0xd6, 0x49, 0xc8, 0x33, 0x9a, 0x72, 0x02, 0x5f, 0x81, 0x6b, 0x8c, 0xf0, 0x7c, 0x26,
	0xb4, 0x3e, 0x4f, 0xd6, 0xeb, 0xb3, 0x12, 0x29, 0xa7, 0x4b, 0x72, 0x7c, 0xcd, 0x73, 0x9f, 0xd6,
	0xcc, 0x8f, 0xf6, 0xfc, 0xab, 0x31, 0xec, 0x7d, 0x6e, 0x00, 0x7b, 0x09, 0xf0, 0x52, 0xa5, 0x02,
	0xbf, 0x18, 0xe0, 0xe6, 0xaa, 0x41, 0x87, 0x83, 0xf5, 0x55, 0xfc, 0x61, 0x41, 0x9c, 0x8d, 0xe4,
	0x71, 0xfb, 0x6f, 0xbf, 0x7d, 0x7f, 0x67, 0xee, 0xc0, 0x9e, 0xdc, 0xf2, 0xc5, 0x2f, 0xa5, 0x0d,
	0xf4, 0x56, 0x70, 0xaf, 0x53, 0xad, 0xbd, 0x16, 0xc3, 0xeb, 0x5c, 0xc0, 0x4b, 0x03, 0xdc, 0x5a,
	0x2d, 0x15, 0xdc, 0x54, 0x11, 0xbd, 0xa7, 0xce, 0xde, 0xe6, 0x00, 0x35, 0x25, 0xee, 0x5e, 0x51,
	0x59, 0xdf, 0x7d, 0x24, 0x2b, 0xfb, 0x59, 0xca, 0xe2, 0xca, 0xfa, 0x0f, 0x3a, 0x17, 0x4b, 0x85,
	0xf5, 0x93, 0x02, 0xdb, 0x37, 0x3a, 0xa3, 0x4b, 0x03, 0x3c, 0x08, 0x68, 0xb2, 0x36, 0x93, 0xd1,
	0x76, 0x9d, 0xd8, 0xc7, 0x72, 0x63, 0x8f, 0x8d, 0xd7, 0x07, 0x25, 0x22, 0xa2, 0x33, 0x9c, 0x46,
	0x88, 0xb2, 0xc8, 0x8b, 0x48, 0x5a, 0xec, 0xb3, 0x7e, 0x67, 0xb3, 0x98, 0xd7, 0xbf, 0xed, 0xbb,
	0xda, 0xf8, 0x68, 0x36, 0xc6, 0xc3, 0xe1, 0x27, 0xb3, 0x35, 0x56, 0xc0, 0x61, 0xc8, 0x91, 0x32,
	0xa5, 0x75, 0xd2, 0x45, 0x65, 0x60, 0xfe, 0x55, 0xbb, 0x4c, 0x86, 0x21, 0x9f, 0x54, 0x2e, 0x93,
	0x93, 0xee, 0x44, 0xbb, 0x9c, 0x36, 0x8b, 0x04, 0x1e, 0xfe, 0x08, 0x00, 0x00, 0xff, 0xff, 0x12,
	0xdf, 0x1f, 0x23, 0x5b, 0x06, 0x00, 0x00,
}
