// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v0/resources/geo_target_constant.proto

package resources // import "google.golang.org/genproto/googleapis/ads/googleads/v0/resources"

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"
import wrappers "github.com/golang/protobuf/ptypes/wrappers"
import enums "google.golang.org/genproto/googleapis/ads/googleads/v0/enums"

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// A geo target constant.
type GeoTargetConstant struct {
	// The resource name of the geo target constant.
	// Geo target constant resource names have the form:
	//
	// `geoTargetConstants/{geo_target_constant_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The ID of the geo target constant.
	Id *wrappers.Int64Value `protobuf:"bytes,3,opt,name=id,proto3" json:"id,omitempty"`
	// Geo target constant English name.
	Name *wrappers.StringValue `protobuf:"bytes,4,opt,name=name,proto3" json:"name,omitempty"`
	// The ISO-3166-1 alpha-2 country code that is associated with the target.
	CountryCode *wrappers.StringValue `protobuf:"bytes,5,opt,name=country_code,json=countryCode,proto3" json:"country_code,omitempty"`
	// Geo target constant target type.
	TargetType *wrappers.StringValue `protobuf:"bytes,6,opt,name=target_type,json=targetType,proto3" json:"target_type,omitempty"`
	// Geo target constant status.
	Status               enums.GeoTargetConstantStatusEnum_GeoTargetConstantStatus `protobuf:"varint,7,opt,name=status,proto3,enum=google.ads.googleads.v0.enums.GeoTargetConstantStatusEnum_GeoTargetConstantStatus" json:"status,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                                                  `json:"-"`
	XXX_unrecognized     []byte                                                    `json:"-"`
	XXX_sizecache        int32                                                     `json:"-"`
}

func (m *GeoTargetConstant) Reset()         { *m = GeoTargetConstant{} }
func (m *GeoTargetConstant) String() string { return proto.CompactTextString(m) }
func (*GeoTargetConstant) ProtoMessage()    {}
func (*GeoTargetConstant) Descriptor() ([]byte, []int) {
	return fileDescriptor_geo_target_constant_07179001f0b69e8d, []int{0}
}
func (m *GeoTargetConstant) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GeoTargetConstant.Unmarshal(m, b)
}
func (m *GeoTargetConstant) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GeoTargetConstant.Marshal(b, m, deterministic)
}
func (dst *GeoTargetConstant) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GeoTargetConstant.Merge(dst, src)
}
func (m *GeoTargetConstant) XXX_Size() int {
	return xxx_messageInfo_GeoTargetConstant.Size(m)
}
func (m *GeoTargetConstant) XXX_DiscardUnknown() {
	xxx_messageInfo_GeoTargetConstant.DiscardUnknown(m)
}

var xxx_messageInfo_GeoTargetConstant proto.InternalMessageInfo

func (m *GeoTargetConstant) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *GeoTargetConstant) GetId() *wrappers.Int64Value {
	if m != nil {
		return m.Id
	}
	return nil
}

func (m *GeoTargetConstant) GetName() *wrappers.StringValue {
	if m != nil {
		return m.Name
	}
	return nil
}

func (m *GeoTargetConstant) GetCountryCode() *wrappers.StringValue {
	if m != nil {
		return m.CountryCode
	}
	return nil
}

func (m *GeoTargetConstant) GetTargetType() *wrappers.StringValue {
	if m != nil {
		return m.TargetType
	}
	return nil
}

func (m *GeoTargetConstant) GetStatus() enums.GeoTargetConstantStatusEnum_GeoTargetConstantStatus {
	if m != nil {
		return m.Status
	}
	return enums.GeoTargetConstantStatusEnum_UNSPECIFIED
}

func init() {
	proto.RegisterType((*GeoTargetConstant)(nil), "google.ads.googleads.v0.resources.GeoTargetConstant")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v0/resources/geo_target_constant.proto", fileDescriptor_geo_target_constant_07179001f0b69e8d)
}

var fileDescriptor_geo_target_constant_07179001f0b69e8d = []byte{
	// 400 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x92, 0xd1, 0xca, 0xd3, 0x30,
	0x14, 0xc7, 0x69, 0xf7, 0x39, 0x31, 0xfb, 0x14, 0xec, 0x85, 0x94, 0x4f, 0x91, 0x4d, 0x11, 0x06,
	0x42, 0x5a, 0xa6, 0x78, 0x33, 0x54, 0xba, 0x21, 0x43, 0x2f, 0x64, 0x74, 0x63, 0x17, 0x52, 0x28,
	0x59, 0x73, 0x0c, 0x95, 0x35, 0x29, 0x49, 0x3a, 0xd9, 0xb5, 0x6f, 0xe2, 0xa5, 0x8f, 0xe2, 0x2b,
	0xf8, 0x32, 0xb2, 0x24, 0xed, 0xcd, 0x9c, 0xdf, 0xee, 0xfe, 0x6d, 0xfe, 0xbf, 0xff, 0x39, 0x39,
	0x39, 0x68, 0xca, 0x84, 0x60, 0x3b, 0x88, 0x08, 0x55, 0x91, 0x95, 0x47, 0xb5, 0x8f, 0x23, 0x09,
	0x4a, 0x34, 0xb2, 0x00, 0x15, 0x31, 0x10, 0xb9, 0x26, 0x92, 0x81, 0xce, 0x0b, 0xc1, 0x95, 0x26,
	0x5c, 0xe3, 0x5a, 0x0a, 0x2d, 0x82, 0x91, 0x25, 0x30, 0xa1, 0x0a, 0x77, 0x30, 0xde, 0xc7, 0xb8,
	0x83, 0x6f, 0xde, 0x9d, 0xcb, 0x07, 0xde, 0x54, 0xff, 0xcc, 0xce, 0x95, 0x26, 0xba, 0x51, 0xb6,
	0xc4, 0xcd, 0x53, 0xc7, 0x9b, 0xaf, 0x6d, 0xf3, 0x35, 0xfa, 0x2e, 0x49, 0x5d, 0x83, 0x74, 0xe7,
	0xcf, 0x7e, 0xf4, 0xd0, 0xc3, 0x05, 0x88, 0xb5, 0xc9, 0x98, 0xbb, 0x88, 0xe0, 0x39, 0xba, 0xdf,
	0xb6, 0x90, 0x73, 0x52, 0x41, 0xe8, 0x0d, 0xbd, 0xf1, 0xbd, 0xf4, 0xba, 0xfd, 0xf9, 0x99, 0x54,
	0x10, 0xbc, 0x44, 0x7e, 0x49, 0xc3, 0xde, 0xd0, 0x1b, 0x0f, 0x26, 0x8f, 0x5d, 0xff, 0xb8, 0xad,
	0x83, 0x3f, 0x72, 0xfd, 0xe6, 0xf5, 0x86, 0xec, 0x1a, 0x48, 0xfd, 0x92, 0x06, 0x31, 0xba, 0x32,
	0x41, 0x57, 0xc6, 0xfe, 0xe4, 0xc4, 0xbe, 0xd2, 0xb2, 0xe4, 0xcc, 0xfa, 0x8d, 0x33, 0x78, 0x8f,
	0xae, 0x0b, 0xd1, 0x70, 0x2d, 0x0f, 0x79, 0x21, 0x28, 0x84, 0x77, 0x2e, 0x20, 0x07, 0x8e, 0x98,
	0x0b, 0x0a, 0xc1, 0x5b, 0x34, 0x70, 0xa3, 0xd1, 0x87, 0x1a, 0xc2, 0xfe, 0x05, 0x3c, 0xb2, 0xc0,
	0xfa, 0x50, 0x43, 0xf0, 0x0d, 0xf5, 0xed, 0x24, 0xc3, 0xbb, 0x43, 0x6f, 0xfc, 0x60, 0x92, 0xe2,
	0x73, 0xaf, 0x65, 0x9e, 0x02, 0x9f, 0x4c, 0x71, 0x65, 0xe8, 0x0f, 0xbc, 0xa9, 0xce, 0x9d, 0xa5,
	0xae, 0xc2, 0xec, 0x8f, 0x87, 0x5e, 0x14, 0xa2, 0xc2, 0xb7, 0xee, 0xc3, 0xec, 0xd1, 0x49, 0xd4,
	0xf2, 0x78, 0x91, 0xa5, 0xf7, 0xe5, 0x93, 0x83, 0x99, 0xd8, 0x11, 0xce, 0xb0, 0x90, 0x2c, 0x62,
	0xc0, 0xcd, 0x35, 0xdb, 0xcd, 0xa9, 0x4b, 0xf5, 0x9f, 0x45, 0x9d, 0x76, 0xea, 0xa7, 0xdf, 0x5b,
	0x24, 0xc9, 0x2f, 0x7f, 0xb4, 0xb0, 0x91, 0x09, 0x55, 0xd8, 0xca, 0xa3, 0xda, 0xc4, 0x38, 0x6d,
	0x9d, 0xbf, 0x5b, 0x4f, 0x96, 0x50, 0x95, 0x75, 0x9e, 0x6c, 0x13, 0x67, 0x9d, 0x67, 0xdb, 0x37,
	0x4d, 0xbc, 0xfa, 0x1b, 0x00, 0x00, 0xff, 0xff, 0x70, 0xa7, 0x88, 0xb1, 0x2c, 0x03, 0x00, 0x00,
}
