// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v0/resources/campaign_group.proto

package resources // import "google.golang.org/genproto/googleapis/ads/googleads/v0/resources"

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"
import wrappers "github.com/golang/protobuf/ptypes/wrappers"
import enums "google.golang.org/genproto/googleapis/ads/googleads/v0/enums"

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// A campaign group.
type CampaignGroup struct {
	// The resource name of the campaign group.
	// Campaign group resource names have the form:
	//
	// `customers/{customer_id}/campaignGroups/{campaign_group_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The ID of the campaign group.
	Id *wrappers.Int64Value `protobuf:"bytes,3,opt,name=id,proto3" json:"id,omitempty"`
	// The name of the campaign group.
	//
	// This field is required and should not be empty when creating new campaign
	// groups.
	//
	// It must not contain any null (code point 0x0), NL line feed
	// (code point 0xA) or carriage return (code point 0xD) characters.
	Name *wrappers.StringValue `protobuf:"bytes,4,opt,name=name,proto3" json:"name,omitempty"`
	// The status of the campaign group.
	//
	// When a new campaign group is added, the status defaults to ENABLED.
	Status               enums.CampaignGroupStatusEnum_CampaignGroupStatus `protobuf:"varint,5,opt,name=status,proto3,enum=google.ads.googleads.v0.enums.CampaignGroupStatusEnum_CampaignGroupStatus" json:"status,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                                          `json:"-"`
	XXX_unrecognized     []byte                                            `json:"-"`
	XXX_sizecache        int32                                             `json:"-"`
}

func (m *CampaignGroup) Reset()         { *m = CampaignGroup{} }
func (m *CampaignGroup) String() string { return proto.CompactTextString(m) }
func (*CampaignGroup) ProtoMessage()    {}
func (*CampaignGroup) Descriptor() ([]byte, []int) {
	return fileDescriptor_campaign_group_14ee489e1e23e16b, []int{0}
}
func (m *CampaignGroup) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CampaignGroup.Unmarshal(m, b)
}
func (m *CampaignGroup) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CampaignGroup.Marshal(b, m, deterministic)
}
func (dst *CampaignGroup) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CampaignGroup.Merge(dst, src)
}
func (m *CampaignGroup) XXX_Size() int {
	return xxx_messageInfo_CampaignGroup.Size(m)
}
func (m *CampaignGroup) XXX_DiscardUnknown() {
	xxx_messageInfo_CampaignGroup.DiscardUnknown(m)
}

var xxx_messageInfo_CampaignGroup proto.InternalMessageInfo

func (m *CampaignGroup) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *CampaignGroup) GetId() *wrappers.Int64Value {
	if m != nil {
		return m.Id
	}
	return nil
}

func (m *CampaignGroup) GetName() *wrappers.StringValue {
	if m != nil {
		return m.Name
	}
	return nil
}

func (m *CampaignGroup) GetStatus() enums.CampaignGroupStatusEnum_CampaignGroupStatus {
	if m != nil {
		return m.Status
	}
	return enums.CampaignGroupStatusEnum_UNSPECIFIED
}

func init() {
	proto.RegisterType((*CampaignGroup)(nil), "google.ads.googleads.v0.resources.CampaignGroup")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v0/resources/campaign_group.proto", fileDescriptor_campaign_group_14ee489e1e23e16b)
}

var fileDescriptor_campaign_group_14ee489e1e23e16b = []byte{
	// 351 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x92, 0xcf, 0x4a, 0xeb, 0x40,
	0x14, 0xc6, 0x99, 0xb4, 0xb7, 0x70, 0xe7, 0xde, 0xba, 0xc8, 0xaa, 0x54, 0x91, 0x56, 0x11, 0x0a,
	0xc2, 0x49, 0xa8, 0x52, 0x10, 0x57, 0xa9, 0x48, 0xb1, 0x0b, 0x29, 0x29, 0x74, 0x21, 0x81, 0x32,
	0x6d, 0xc6, 0x21, 0xd0, 0xcc, 0x84, 0x99, 0x4c, 0x7d, 0x1f, 0x97, 0x3e, 0x8a, 0x2f, 0xe0, 0xa3,
	0xb8, 0x95, 0xcc, 0x24, 0x81, 0xaa, 0xd5, 0xdd, 0x97, 0x93, 0xdf, 0xf7, 0x9d, 0x3f, 0x09, 0x1e,
	0x31, 0x21, 0xd8, 0x86, 0x7a, 0x24, 0x56, 0x9e, 0x95, 0x85, 0xda, 0xfa, 0x9e, 0xa4, 0x4a, 0x68,
	0xb9, 0xa6, 0xca, 0x5b, 0x93, 0x34, 0x23, 0x09, 0xe3, 0x4b, 0x26, 0x85, 0xce, 0x20, 0x93, 0x22,
	0x17, 0x6e, 0xdf, 0xc2, 0x40, 0x62, 0x05, 0xb5, 0x0f, 0xb6, 0x3e, 0xd4, 0xbe, 0xee, 0xd5, 0xbe,
	0x68, 0xca, 0x75, 0xfa, 0x39, 0x76, 0xa9, 0x72, 0x92, 0x6b, 0x65, 0xd3, 0xbb, 0xc7, 0xa5, 0xd5,
	0x3c, 0xad, 0xf4, 0xa3, 0xf7, 0x24, 0x49, 0x96, 0x51, 0x59, 0xbe, 0x3f, 0x79, 0x47, 0xb8, 0x7d,
	0x53, 0xfa, 0x27, 0x85, 0xdd, 0x3d, 0xc5, 0xed, 0xaa, 0xf3, 0x92, 0x93, 0x94, 0x76, 0x50, 0x0f,
	0x0d, 0xfe, 0x86, 0xff, 0xab, 0xe2, 0x3d, 0x49, 0xa9, 0x7b, 0x8e, 0x9d, 0x24, 0xee, 0x34, 0x7a,
	0x68, 0xf0, 0x6f, 0x78, 0x58, 0x8e, 0x0d, 0x55, 0x0f, 0xb8, 0xe3, 0xf9, 0xe8, 0x72, 0x41, 0x36,
	0x9a, 0x86, 0x4e, 0x12, 0xbb, 0x3e, 0x6e, 0x9a, 0xa0, 0xa6, 0xc1, 0x8f, 0xbe, 0xe0, 0xf3, 0x5c,
	0x26, 0x9c, 0x59, 0xde, 0x90, 0xee, 0x0a, 0xb7, 0xec, 0x16, 0x9d, 0x3f, 0x3d, 0x34, 0x38, 0x18,
	0x4e, 0x61, 0xdf, 0x91, 0xcc, 0x05, 0x60, 0x67, 0x83, 0xb9, 0x71, 0xde, 0x72, 0x9d, 0x7e, 0x57,
	0x0f, 0xcb, 0xe4, 0xf1, 0x1b, 0xc2, 0x67, 0x6b, 0x91, 0xc2, 0xaf, 0xe7, 0x1f, 0xbb, 0x3b, 0x31,
	0xb3, 0x62, 0xec, 0x19, 0x7a, 0x98, 0x96, 0x46, 0x26, 0x36, 0x84, 0x33, 0x10, 0x92, 0x79, 0x8c,
	0x72, 0xb3, 0x54, 0xf5, 0x91, 0xb2, 0x44, 0xfd, 0xf0, 0x3b, 0x5c, 0xd7, 0xea, 0xd9, 0x69, 0x4c,
	0x82, 0xe0, 0xc5, 0xe9, 0x4f, 0x6c, 0x64, 0x10, 0x2b, 0xb0, 0xb2, 0x50, 0x0b, 0x1f, 0xc2, 0x8a,
	0x7c, 0xad, 0x98, 0x28, 0x88, 0x55, 0x54, 0x33, 0xd1, 0xc2, 0x8f, 0x6a, 0x66, 0xd5, 0x32, 0x43,
	0x5c, 0x7c, 0x04, 0x00, 0x00, 0xff, 0xff, 0x77, 0x85, 0x5a, 0x80, 0x92, 0x02, 0x00, 0x00,
}
