// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v0/services/campaign_shared_set_service.proto

package services // import "google.golang.org/genproto/googleapis/ads/googleads/v0/services"

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"
import resources "google.golang.org/genproto/googleapis/ads/googleads/v0/resources"
import _ "google.golang.org/genproto/googleapis/api/annotations"

import (
	context "golang.org/x/net/context"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// Request message for [CampaignSharedSetService.GetCampaignSharedSet][google.ads.googleads.v0.services.CampaignSharedSetService.GetCampaignSharedSet].
type GetCampaignSharedSetRequest struct {
	// The resource name of the campaign shared set to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetCampaignSharedSetRequest) Reset()         { *m = GetCampaignSharedSetRequest{} }
func (m *GetCampaignSharedSetRequest) String() string { return proto.CompactTextString(m) }
func (*GetCampaignSharedSetRequest) ProtoMessage()    {}
func (*GetCampaignSharedSetRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_campaign_shared_set_service_e990dcd14e355acc, []int{0}
}
func (m *GetCampaignSharedSetRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetCampaignSharedSetRequest.Unmarshal(m, b)
}
func (m *GetCampaignSharedSetRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetCampaignSharedSetRequest.Marshal(b, m, deterministic)
}
func (dst *GetCampaignSharedSetRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetCampaignSharedSetRequest.Merge(dst, src)
}
func (m *GetCampaignSharedSetRequest) XXX_Size() int {
	return xxx_messageInfo_GetCampaignSharedSetRequest.Size(m)
}
func (m *GetCampaignSharedSetRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetCampaignSharedSetRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetCampaignSharedSetRequest proto.InternalMessageInfo

func (m *GetCampaignSharedSetRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

// Request message for [CampaignSharedSetService.MutateCampaignSharedSets][google.ads.googleads.v0.services.CampaignSharedSetService.MutateCampaignSharedSets].
type MutateCampaignSharedSetsRequest struct {
	// The ID of the customer whose campaign shared sets are being modified.
	CustomerId string `protobuf:"bytes,1,opt,name=customer_id,json=customerId,proto3" json:"customer_id,omitempty"`
	// The list of operations to perform on individual campaign shared sets.
	Operations           []*CampaignSharedSetOperation `protobuf:"bytes,2,rep,name=operations,proto3" json:"operations,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                      `json:"-"`
	XXX_unrecognized     []byte                        `json:"-"`
	XXX_sizecache        int32                         `json:"-"`
}

func (m *MutateCampaignSharedSetsRequest) Reset()         { *m = MutateCampaignSharedSetsRequest{} }
func (m *MutateCampaignSharedSetsRequest) String() string { return proto.CompactTextString(m) }
func (*MutateCampaignSharedSetsRequest) ProtoMessage()    {}
func (*MutateCampaignSharedSetsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_campaign_shared_set_service_e990dcd14e355acc, []int{1}
}
func (m *MutateCampaignSharedSetsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MutateCampaignSharedSetsRequest.Unmarshal(m, b)
}
func (m *MutateCampaignSharedSetsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MutateCampaignSharedSetsRequest.Marshal(b, m, deterministic)
}
func (dst *MutateCampaignSharedSetsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MutateCampaignSharedSetsRequest.Merge(dst, src)
}
func (m *MutateCampaignSharedSetsRequest) XXX_Size() int {
	return xxx_messageInfo_MutateCampaignSharedSetsRequest.Size(m)
}
func (m *MutateCampaignSharedSetsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_MutateCampaignSharedSetsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_MutateCampaignSharedSetsRequest proto.InternalMessageInfo

func (m *MutateCampaignSharedSetsRequest) GetCustomerId() string {
	if m != nil {
		return m.CustomerId
	}
	return ""
}

func (m *MutateCampaignSharedSetsRequest) GetOperations() []*CampaignSharedSetOperation {
	if m != nil {
		return m.Operations
	}
	return nil
}

// A single operation (create, remove) on an campaign shared set.
type CampaignSharedSetOperation struct {
	// The mutate operation.
	//
	// Types that are valid to be assigned to Operation:
	//	*CampaignSharedSetOperation_Create
	//	*CampaignSharedSetOperation_Remove
	Operation            isCampaignSharedSetOperation_Operation `protobuf_oneof:"operation"`
	XXX_NoUnkeyedLiteral struct{}                               `json:"-"`
	XXX_unrecognized     []byte                                 `json:"-"`
	XXX_sizecache        int32                                  `json:"-"`
}

func (m *CampaignSharedSetOperation) Reset()         { *m = CampaignSharedSetOperation{} }
func (m *CampaignSharedSetOperation) String() string { return proto.CompactTextString(m) }
func (*CampaignSharedSetOperation) ProtoMessage()    {}
func (*CampaignSharedSetOperation) Descriptor() ([]byte, []int) {
	return fileDescriptor_campaign_shared_set_service_e990dcd14e355acc, []int{2}
}
func (m *CampaignSharedSetOperation) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CampaignSharedSetOperation.Unmarshal(m, b)
}
func (m *CampaignSharedSetOperation) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CampaignSharedSetOperation.Marshal(b, m, deterministic)
}
func (dst *CampaignSharedSetOperation) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CampaignSharedSetOperation.Merge(dst, src)
}
func (m *CampaignSharedSetOperation) XXX_Size() int {
	return xxx_messageInfo_CampaignSharedSetOperation.Size(m)
}
func (m *CampaignSharedSetOperation) XXX_DiscardUnknown() {
	xxx_messageInfo_CampaignSharedSetOperation.DiscardUnknown(m)
}

var xxx_messageInfo_CampaignSharedSetOperation proto.InternalMessageInfo

type isCampaignSharedSetOperation_Operation interface {
	isCampaignSharedSetOperation_Operation()
}

type CampaignSharedSetOperation_Create struct {
	Create *resources.CampaignSharedSet `protobuf:"bytes,1,opt,name=create,proto3,oneof"`
}

type CampaignSharedSetOperation_Remove struct {
	Remove string `protobuf:"bytes,3,opt,name=remove,proto3,oneof"`
}

func (*CampaignSharedSetOperation_Create) isCampaignSharedSetOperation_Operation() {}

func (*CampaignSharedSetOperation_Remove) isCampaignSharedSetOperation_Operation() {}

func (m *CampaignSharedSetOperation) GetOperation() isCampaignSharedSetOperation_Operation {
	if m != nil {
		return m.Operation
	}
	return nil
}

func (m *CampaignSharedSetOperation) GetCreate() *resources.CampaignSharedSet {
	if x, ok := m.GetOperation().(*CampaignSharedSetOperation_Create); ok {
		return x.Create
	}
	return nil
}

func (m *CampaignSharedSetOperation) GetRemove() string {
	if x, ok := m.GetOperation().(*CampaignSharedSetOperation_Remove); ok {
		return x.Remove
	}
	return ""
}

// XXX_OneofFuncs is for the internal use of the proto package.
func (*CampaignSharedSetOperation) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, func(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error), func(msg proto.Message) (n int), []interface{}) {
	return _CampaignSharedSetOperation_OneofMarshaler, _CampaignSharedSetOperation_OneofUnmarshaler, _CampaignSharedSetOperation_OneofSizer, []interface{}{
		(*CampaignSharedSetOperation_Create)(nil),
		(*CampaignSharedSetOperation_Remove)(nil),
	}
}

func _CampaignSharedSetOperation_OneofMarshaler(msg proto.Message, b *proto.Buffer) error {
	m := msg.(*CampaignSharedSetOperation)
	// operation
	switch x := m.Operation.(type) {
	case *CampaignSharedSetOperation_Create:
		b.EncodeVarint(1<<3 | proto.WireBytes)
		if err := b.EncodeMessage(x.Create); err != nil {
			return err
		}
	case *CampaignSharedSetOperation_Remove:
		b.EncodeVarint(3<<3 | proto.WireBytes)
		b.EncodeStringBytes(x.Remove)
	case nil:
	default:
		return fmt.Errorf("CampaignSharedSetOperation.Operation has unexpected type %T", x)
	}
	return nil
}

func _CampaignSharedSetOperation_OneofUnmarshaler(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error) {
	m := msg.(*CampaignSharedSetOperation)
	switch tag {
	case 1: // operation.create
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		msg := new(resources.CampaignSharedSet)
		err := b.DecodeMessage(msg)
		m.Operation = &CampaignSharedSetOperation_Create{msg}
		return true, err
	case 3: // operation.remove
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		x, err := b.DecodeStringBytes()
		m.Operation = &CampaignSharedSetOperation_Remove{x}
		return true, err
	default:
		return false, nil
	}
}

func _CampaignSharedSetOperation_OneofSizer(msg proto.Message) (n int) {
	m := msg.(*CampaignSharedSetOperation)
	// operation
	switch x := m.Operation.(type) {
	case *CampaignSharedSetOperation_Create:
		s := proto.Size(x.Create)
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(s))
		n += s
	case *CampaignSharedSetOperation_Remove:
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(len(x.Remove)))
		n += len(x.Remove)
	case nil:
	default:
		panic(fmt.Sprintf("proto: unexpected type %T in oneof", x))
	}
	return n
}

// Response message for a campaign shared set mutate.
type MutateCampaignSharedSetsResponse struct {
	// All results for the mutate.
	Results              []*MutateCampaignSharedSetResult `protobuf:"bytes,2,rep,name=results,proto3" json:"results,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                         `json:"-"`
	XXX_unrecognized     []byte                           `json:"-"`
	XXX_sizecache        int32                            `json:"-"`
}

func (m *MutateCampaignSharedSetsResponse) Reset()         { *m = MutateCampaignSharedSetsResponse{} }
func (m *MutateCampaignSharedSetsResponse) String() string { return proto.CompactTextString(m) }
func (*MutateCampaignSharedSetsResponse) ProtoMessage()    {}
func (*MutateCampaignSharedSetsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_campaign_shared_set_service_e990dcd14e355acc, []int{3}
}
func (m *MutateCampaignSharedSetsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MutateCampaignSharedSetsResponse.Unmarshal(m, b)
}
func (m *MutateCampaignSharedSetsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MutateCampaignSharedSetsResponse.Marshal(b, m, deterministic)
}
func (dst *MutateCampaignSharedSetsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MutateCampaignSharedSetsResponse.Merge(dst, src)
}
func (m *MutateCampaignSharedSetsResponse) XXX_Size() int {
	return xxx_messageInfo_MutateCampaignSharedSetsResponse.Size(m)
}
func (m *MutateCampaignSharedSetsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_MutateCampaignSharedSetsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_MutateCampaignSharedSetsResponse proto.InternalMessageInfo

func (m *MutateCampaignSharedSetsResponse) GetResults() []*MutateCampaignSharedSetResult {
	if m != nil {
		return m.Results
	}
	return nil
}

// The result for the campaign shared set mutate.
type MutateCampaignSharedSetResult struct {
	// Returned for successful operations.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *MutateCampaignSharedSetResult) Reset()         { *m = MutateCampaignSharedSetResult{} }
func (m *MutateCampaignSharedSetResult) String() string { return proto.CompactTextString(m) }
func (*MutateCampaignSharedSetResult) ProtoMessage()    {}
func (*MutateCampaignSharedSetResult) Descriptor() ([]byte, []int) {
	return fileDescriptor_campaign_shared_set_service_e990dcd14e355acc, []int{4}
}
func (m *MutateCampaignSharedSetResult) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MutateCampaignSharedSetResult.Unmarshal(m, b)
}
func (m *MutateCampaignSharedSetResult) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MutateCampaignSharedSetResult.Marshal(b, m, deterministic)
}
func (dst *MutateCampaignSharedSetResult) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MutateCampaignSharedSetResult.Merge(dst, src)
}
func (m *MutateCampaignSharedSetResult) XXX_Size() int {
	return xxx_messageInfo_MutateCampaignSharedSetResult.Size(m)
}
func (m *MutateCampaignSharedSetResult) XXX_DiscardUnknown() {
	xxx_messageInfo_MutateCampaignSharedSetResult.DiscardUnknown(m)
}

var xxx_messageInfo_MutateCampaignSharedSetResult proto.InternalMessageInfo

func (m *MutateCampaignSharedSetResult) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetCampaignSharedSetRequest)(nil), "google.ads.googleads.v0.services.GetCampaignSharedSetRequest")
	proto.RegisterType((*MutateCampaignSharedSetsRequest)(nil), "google.ads.googleads.v0.services.MutateCampaignSharedSetsRequest")
	proto.RegisterType((*CampaignSharedSetOperation)(nil), "google.ads.googleads.v0.services.CampaignSharedSetOperation")
	proto.RegisterType((*MutateCampaignSharedSetsResponse)(nil), "google.ads.googleads.v0.services.MutateCampaignSharedSetsResponse")
	proto.RegisterType((*MutateCampaignSharedSetResult)(nil), "google.ads.googleads.v0.services.MutateCampaignSharedSetResult")
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// CampaignSharedSetServiceClient is the client API for CampaignSharedSetService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type CampaignSharedSetServiceClient interface {
	// Returns the requested campaign shared set in full detail.
	GetCampaignSharedSet(ctx context.Context, in *GetCampaignSharedSetRequest, opts ...grpc.CallOption) (*resources.CampaignSharedSet, error)
	// Creates or removes campaign shared sets. Operation statuses are returned.
	MutateCampaignSharedSets(ctx context.Context, in *MutateCampaignSharedSetsRequest, opts ...grpc.CallOption) (*MutateCampaignSharedSetsResponse, error)
}

type campaignSharedSetServiceClient struct {
	cc *grpc.ClientConn
}

func NewCampaignSharedSetServiceClient(cc *grpc.ClientConn) CampaignSharedSetServiceClient {
	return &campaignSharedSetServiceClient{cc}
}

func (c *campaignSharedSetServiceClient) GetCampaignSharedSet(ctx context.Context, in *GetCampaignSharedSetRequest, opts ...grpc.CallOption) (*resources.CampaignSharedSet, error) {
	out := new(resources.CampaignSharedSet)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v0.services.CampaignSharedSetService/GetCampaignSharedSet", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *campaignSharedSetServiceClient) MutateCampaignSharedSets(ctx context.Context, in *MutateCampaignSharedSetsRequest, opts ...grpc.CallOption) (*MutateCampaignSharedSetsResponse, error) {
	out := new(MutateCampaignSharedSetsResponse)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v0.services.CampaignSharedSetService/MutateCampaignSharedSets", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// CampaignSharedSetServiceServer is the server API for CampaignSharedSetService service.
type CampaignSharedSetServiceServer interface {
	// Returns the requested campaign shared set in full detail.
	GetCampaignSharedSet(context.Context, *GetCampaignSharedSetRequest) (*resources.CampaignSharedSet, error)
	// Creates or removes campaign shared sets. Operation statuses are returned.
	MutateCampaignSharedSets(context.Context, *MutateCampaignSharedSetsRequest) (*MutateCampaignSharedSetsResponse, error)
}

func RegisterCampaignSharedSetServiceServer(s *grpc.Server, srv CampaignSharedSetServiceServer) {
	s.RegisterService(&_CampaignSharedSetService_serviceDesc, srv)
}

func _CampaignSharedSetService_GetCampaignSharedSet_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetCampaignSharedSetRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(CampaignSharedSetServiceServer).GetCampaignSharedSet(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v0.services.CampaignSharedSetService/GetCampaignSharedSet",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(CampaignSharedSetServiceServer).GetCampaignSharedSet(ctx, req.(*GetCampaignSharedSetRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _CampaignSharedSetService_MutateCampaignSharedSets_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(MutateCampaignSharedSetsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(CampaignSharedSetServiceServer).MutateCampaignSharedSets(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v0.services.CampaignSharedSetService/MutateCampaignSharedSets",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(CampaignSharedSetServiceServer).MutateCampaignSharedSets(ctx, req.(*MutateCampaignSharedSetsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _CampaignSharedSetService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v0.services.CampaignSharedSetService",
	HandlerType: (*CampaignSharedSetServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetCampaignSharedSet",
			Handler:    _CampaignSharedSetService_GetCampaignSharedSet_Handler,
		},
		{
			MethodName: "MutateCampaignSharedSets",
			Handler:    _CampaignSharedSetService_MutateCampaignSharedSets_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v0/services/campaign_shared_set_service.proto",
}

func init() {
	proto.RegisterFile("google/ads/googleads/v0/services/campaign_shared_set_service.proto", fileDescriptor_campaign_shared_set_service_e990dcd14e355acc)
}

var fileDescriptor_campaign_shared_set_service_e990dcd14e355acc = []byte{
	// 542 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xa4, 0x94, 0x41, 0x6b, 0xd4, 0x40,
	0x14, 0xc7, 0xcd, 0x2e, 0x54, 0x3a, 0xab, 0x97, 0xc1, 0x43, 0x58, 0x2d, 0x5d, 0xa2, 0x87, 0xb2,
	0x87, 0xc9, 0xb2, 0x16, 0x85, 0x76, 0x17, 0x49, 0x14, 0xb6, 0x1e, 0xac, 0x25, 0x0b, 0x05, 0x25,
	0x10, 0xc6, 0xe4, 0x11, 0x03, 0x9b, 0x4c, 0x9c, 0x99, 0xec, 0xa5, 0xec, 0xc5, 0xaf, 0xd0, 0x2f,
	0x20, 0x1e, 0xfd, 0x26, 0x7a, 0xf0, 0xe2, 0xd9, 0x9b, 0x7e, 0x0f, 0x49, 0x26, 0x93, 0x56, 0xb6,
	0xe9, 0x4a, 0xbd, 0xbd, 0x64, 0xde, 0xfc, 0xde, 0xfb, 0xbf, 0x37, 0xef, 0x21, 0x37, 0x66, 0x2c,
	0x5e, 0x80, 0x4d, 0x23, 0x61, 0x2b, 0xb3, 0xb4, 0x96, 0x23, 0x5b, 0x00, 0x5f, 0x26, 0x21, 0x08,
	0x3b, 0xa4, 0x69, 0x4e, 0x93, 0x38, 0x0b, 0xc4, 0x7b, 0xca, 0x21, 0x0a, 0x04, 0xc8, 0xa0, 0x3e,
	0x24, 0x39, 0x67, 0x92, 0xe1, 0x81, 0xba, 0x48, 0x68, 0x24, 0x48, 0xc3, 0x20, 0xcb, 0x11, 0xd1,
	0x8c, 0xfe, 0x61, 0x5b, 0x14, 0x0e, 0x82, 0x15, 0xbc, 0x25, 0x8c, 0xc2, 0xf7, 0x1f, 0xe8, 0xcb,
	0x79, 0x62, 0xd3, 0x2c, 0x63, 0x92, 0xca, 0x84, 0x65, 0x42, 0x9d, 0x5a, 0x2e, 0xba, 0x3f, 0x03,
	0xf9, 0xbc, 0xbe, 0x3d, 0xaf, 0x2e, 0xcf, 0x41, 0x7a, 0xf0, 0xa1, 0x00, 0x21, 0xf1, 0x43, 0x74,
	0x57, 0xc7, 0x08, 0x32, 0x9a, 0x82, 0x69, 0x0c, 0x8c, 0xbd, 0x6d, 0xef, 0x8e, 0xfe, 0x79, 0x4c,
	0x53, 0xb0, 0x3e, 0x19, 0x68, 0xf7, 0x55, 0x21, 0xa9, 0x84, 0x35, 0x8e, 0xd0, 0xa0, 0x5d, 0xd4,
	0x0b, 0x0b, 0x21, 0x59, 0x0a, 0x3c, 0x48, 0xa2, 0x1a, 0x83, 0xf4, 0xaf, 0x97, 0x11, 0xf6, 0x11,
	0x62, 0x39, 0x70, 0x95, 0x9c, 0xd9, 0x19, 0x74, 0xf7, 0x7a, 0xe3, 0x09, 0xd9, 0x54, 0x1a, 0xb2,
	0x16, 0xf1, 0xb5, 0x86, 0x78, 0x97, 0x78, 0xd6, 0xb9, 0x81, 0xfa, 0xed, 0xae, 0xf8, 0x18, 0x6d,
	0x85, 0x1c, 0xa8, 0x54, 0xfa, 0x7a, 0xe3, 0xfd, 0xd6, 0xc0, 0x4d, 0xc5, 0xd7, 0x23, 0x1f, 0xdd,
	0xf2, 0x6a, 0x0a, 0x36, 0xd1, 0x16, 0x87, 0x94, 0x2d, 0xc1, 0xec, 0x96, 0x42, 0xcb, 0x13, 0xf5,
	0xed, 0xf6, 0xd0, 0x76, 0x93, 0x96, 0xb5, 0x42, 0x83, 0xf6, 0xba, 0x89, 0x9c, 0x65, 0x02, 0xf0,
	0x1b, 0x74, 0x9b, 0x83, 0x28, 0x16, 0x52, 0x17, 0xe5, 0xd9, 0xe6, 0xa2, 0xb4, 0x40, 0xbd, 0x8a,
	0xe3, 0x69, 0x9e, 0xf5, 0x02, 0xed, 0x5c, 0xeb, 0xf9, 0x4f, 0xdd, 0x1f, 0x7f, 0xef, 0x22, 0x73,
	0x0d, 0x30, 0x57, 0xa9, 0xe0, 0xaf, 0x06, 0xba, 0x77, 0xd5, 0xfb, 0xc2, 0xd3, 0xcd, 0x2a, 0xae,
	0x79, 0x97, 0xfd, 0x1b, 0x35, 0xc8, 0x9a, 0x7c, 0xfc, 0xf1, 0xeb, 0xbc, 0xf3, 0x04, 0xef, 0x97,
	0xb3, 0x73, 0xf6, 0x97, 0xb4, 0xa9, 0x7e, 0x8a, 0xc2, 0x1e, 0x36, 0xc3, 0x74, 0xd1, 0x0e, 0x7b,
	0xb8, 0xc2, 0xbf, 0x0d, 0x64, 0xb6, 0xb5, 0x0b, 0x3b, 0x37, 0xee, 0x8a, 0x1e, 0x91, 0xbe, 0xfb,
	0x3f, 0x08, 0xf5, 0x5a, 0x2c, 0xb7, 0x52, 0x38, 0xb1, 0x9e, 0x96, 0x0a, 0x2f, 0x24, 0x9d, 0x5d,
	0x9a, 0xbd, 0xe9, 0x70, 0x75, 0x85, 0xc0, 0x83, 0xb4, 0x42, 0x1f, 0x18, 0x43, 0xf7, 0xa7, 0x81,
	0x1e, 0x85, 0x2c, 0xdd, 0x98, 0x8d, 0xbb, 0xd3, 0xd6, 0xf6, 0x93, 0x72, 0xb5, 0x9c, 0x18, 0x6f,
	0x8f, 0x6a, 0x44, 0xcc, 0x16, 0x34, 0x8b, 0x09, 0xe3, 0xb1, 0x1d, 0x43, 0x56, 0x2d, 0x1e, 0xbd,
	0xc7, 0xf2, 0x44, 0xb4, 0x2f, 0xcf, 0x43, 0x6d, 0x7c, 0xee, 0x74, 0x67, 0x8e, 0xf3, 0xa5, 0x33,
	0x98, 0x29, 0xa0, 0x13, 0x09, 0xa2, 0xcc, 0xd2, 0x3a, 0x1d, 0x91, 0x3a, 0xb0, 0xf8, 0xa6, 0x5d,
	0x7c, 0x27, 0x12, 0x7e, 0xe3, 0xe2, 0x9f, 0x8e, 0x7c, 0xed, 0xf2, 0x6e, 0xab, 0x4a, 0xe0, 0xf1,
	0x9f, 0x00, 0x00, 0x00, 0xff, 0xff, 0x77, 0x01, 0x00, 0x4c, 0xbc, 0x05, 0x00, 0x00,
}
