// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v0/resources/customer_client.proto

package resources // import "google.golang.org/genproto/googleapis/ads/googleads/v0/resources"

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"
import wrappers "github.com/golang/protobuf/ptypes/wrappers"

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// For a manager, it returns all the customers in its hierarchy and self.
type CustomerClient struct {
	// The resource name of the customer client.
	// CustomerClient resource names have the form:
	// `customers/{customer_id}/customerClients/{client_customer_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The client customer linked to this customer. Read only.
	ClientCustomer *wrappers.StringValue `protobuf:"bytes,3,opt,name=client_customer,json=clientCustomer,proto3" json:"client_customer,omitempty"`
	// Whether the client is hidden or not. Default value is false. Read only.
	Hidden *wrappers.BoolValue `protobuf:"bytes,4,opt,name=hidden,proto3" json:"hidden,omitempty"`
	// Distance between customer and client. For self link, the level value will
	// be 0. Read only.
	Level                *wrappers.Int64Value `protobuf:"bytes,5,opt,name=level,proto3" json:"level,omitempty"`
	XXX_NoUnkeyedLiteral struct{}             `json:"-"`
	XXX_unrecognized     []byte               `json:"-"`
	XXX_sizecache        int32                `json:"-"`
}

func (m *CustomerClient) Reset()         { *m = CustomerClient{} }
func (m *CustomerClient) String() string { return proto.CompactTextString(m) }
func (*CustomerClient) ProtoMessage()    {}
func (*CustomerClient) Descriptor() ([]byte, []int) {
	return fileDescriptor_customer_client_4e068b1367c0b0ff, []int{0}
}
func (m *CustomerClient) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CustomerClient.Unmarshal(m, b)
}
func (m *CustomerClient) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CustomerClient.Marshal(b, m, deterministic)
}
func (dst *CustomerClient) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CustomerClient.Merge(dst, src)
}
func (m *CustomerClient) XXX_Size() int {
	return xxx_messageInfo_CustomerClient.Size(m)
}
func (m *CustomerClient) XXX_DiscardUnknown() {
	xxx_messageInfo_CustomerClient.DiscardUnknown(m)
}

var xxx_messageInfo_CustomerClient proto.InternalMessageInfo

func (m *CustomerClient) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *CustomerClient) GetClientCustomer() *wrappers.StringValue {
	if m != nil {
		return m.ClientCustomer
	}
	return nil
}

func (m *CustomerClient) GetHidden() *wrappers.BoolValue {
	if m != nil {
		return m.Hidden
	}
	return nil
}

func (m *CustomerClient) GetLevel() *wrappers.Int64Value {
	if m != nil {
		return m.Level
	}
	return nil
}

func init() {
	proto.RegisterType((*CustomerClient)(nil), "google.ads.googleads.v0.resources.CustomerClient")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v0/resources/customer_client.proto", fileDescriptor_customer_client_4e068b1367c0b0ff)
}

var fileDescriptor_customer_client_4e068b1367c0b0ff = []byte{
	// 331 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x91, 0x41, 0x4b, 0xf3, 0x30,
	0x18, 0xc7, 0xe9, 0xf6, 0x6e, 0xf0, 0x46, 0x9d, 0x50, 0x2f, 0x65, 0x8a, 0x6c, 0x8a, 0xb0, 0x53,
	0x5a, 0xa7, 0xe8, 0xc1, 0x53, 0x37, 0x64, 0xe8, 0x41, 0xc6, 0x84, 0x1d, 0xa4, 0x30, 0xb2, 0xf6,
	0x31, 0x16, 0xd2, 0xa4, 0x24, 0xed, 0xfc, 0x3e, 0x1e, 0xfd, 0x28, 0x7e, 0x02, 0xef, 0x7e, 0x11,
	0x69, 0xd2, 0x14, 0x64, 0xa0, 0xb7, 0x3f, 0xe1, 0xf7, 0xfb, 0x3f, 0x0f, 0x79, 0xd0, 0x35, 0x15,
	0x82, 0x32, 0xf0, 0x49, 0xa2, 0x7c, 0x13, 0xab, 0xb4, 0x09, 0x7c, 0x09, 0x4a, 0x94, 0x32, 0x06,
	0xe5, 0xc7, 0xa5, 0x2a, 0x44, 0x06, 0x72, 0x15, 0xb3, 0x14, 0x78, 0x81, 0x73, 0x29, 0x0a, 0xe1,
	0x0e, 0x0d, 0x8d, 0x49, 0xa2, 0x70, 0x23, 0xe2, 0x4d, 0x80, 0x1b, 0xb1, 0x7f, 0x5c, 0x77, 0x6b,
	0x61, 0x5d, 0x3e, 0xfb, 0xaf, 0x92, 0xe4, 0x39, 0x48, 0x65, 0x2a, 0x4e, 0xbe, 0x1c, 0xd4, 0x9b,
	0xd6, 0xe5, 0x53, 0xdd, 0xed, 0x9e, 0xa2, 0x3d, 0xeb, 0xaf, 0x38, 0xc9, 0xc0, 0x73, 0x06, 0xce,
	0xe8, 0xff, 0x62, 0xd7, 0x3e, 0x3e, 0x90, 0x0c, 0xdc, 0x5b, 0xb4, 0x6f, 0x56, 0x59, 0xd9, 0xd5,
	0xbc, 0xf6, 0xc0, 0x19, 0xed, 0x8c, 0x8f, 0xea, 0x4d, 0xb0, 0x9d, 0x88, 0x1f, 0x0b, 0x99, 0x72,
	0xba, 0x24, 0xac, 0x84, 0x45, 0xcf, 0x48, 0x76, 0xa2, 0x3b, 0x46, 0xdd, 0x97, 0x34, 0x49, 0x80,
	0x7b, 0xff, 0xb4, 0xdd, 0xdf, 0xb2, 0x27, 0x42, 0x30, 0xe3, 0xd6, 0xa4, 0x7b, 0x8e, 0x3a, 0x0c,
	0x36, 0xc0, 0xbc, 0x8e, 0x56, 0x0e, 0xb7, 0x94, 0x3b, 0x5e, 0x5c, 0x5d, 0x1a, 0xc7, 0x90, 0x93,
	0x4f, 0x07, 0x9d, 0xc5, 0x22, 0xc3, 0x7f, 0xfe, 0xd7, 0xe4, 0xe0, 0xe7, 0x67, 0xcc, 0xab, 0xce,
	0xb9, 0xf3, 0x74, 0x5f, 0x9b, 0x54, 0x30, 0xc2, 0x29, 0x16, 0x92, 0xfa, 0x14, 0xb8, 0x9e, 0x68,
	0x4f, 0x96, 0xa7, 0xea, 0x97, 0x0b, 0xde, 0x34, 0xe9, 0xad, 0xd5, 0x9e, 0x85, 0xe1, 0x7b, 0x6b,
	0x38, 0x33, 0x95, 0x61, 0xa2, 0xb0, 0x89, 0x55, 0x5a, 0x06, 0x78, 0x61, 0xc9, 0x0f, 0xcb, 0x44,
	0x61, 0xa2, 0xa2, 0x86, 0x89, 0x96, 0x41, 0xd4, 0x30, 0xeb, 0xae, 0x5e, 0xe2, 0xe2, 0x3b, 0x00,
	0x00, 0xff, 0xff, 0x13, 0x2b, 0x34, 0x21, 0x45, 0x02, 0x00, 0x00,
}
