// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v0/common/user_lists.proto

package common // import "google.golang.org/genproto/googleapis/ads/googleads/v0/common"

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"
import wrappers "github.com/golang/protobuf/ptypes/wrappers"
import enums "google.golang.org/genproto/googleapis/ads/googleads/v0/enums"

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// SimilarUserList is a list of users which are similar to users from another
// UserList. These lists are read-only and automatically created by Google.
type SimilarUserListInfo struct {
	// Seed UserList from which this list is derived.
	SeedUserList         *wrappers.StringValue `protobuf:"bytes,1,opt,name=seed_user_list,json=seedUserList,proto3" json:"seed_user_list,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *SimilarUserListInfo) Reset()         { *m = SimilarUserListInfo{} }
func (m *SimilarUserListInfo) String() string { return proto.CompactTextString(m) }
func (*SimilarUserListInfo) ProtoMessage()    {}
func (*SimilarUserListInfo) Descriptor() ([]byte, []int) {
	return fileDescriptor_user_lists_7f01f78cb9521749, []int{0}
}
func (m *SimilarUserListInfo) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SimilarUserListInfo.Unmarshal(m, b)
}
func (m *SimilarUserListInfo) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SimilarUserListInfo.Marshal(b, m, deterministic)
}
func (dst *SimilarUserListInfo) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SimilarUserListInfo.Merge(dst, src)
}
func (m *SimilarUserListInfo) XXX_Size() int {
	return xxx_messageInfo_SimilarUserListInfo.Size(m)
}
func (m *SimilarUserListInfo) XXX_DiscardUnknown() {
	xxx_messageInfo_SimilarUserListInfo.DiscardUnknown(m)
}

var xxx_messageInfo_SimilarUserListInfo proto.InternalMessageInfo

func (m *SimilarUserListInfo) GetSeedUserList() *wrappers.StringValue {
	if m != nil {
		return m.SeedUserList
	}
	return nil
}

// UserList of CRM users provided by the advertiser.
type CrmBasedUserListInfo struct {
	// A string that uniquely identifies a mobile application from which the data
	// was collected to the Google Ads API.
	// For iOS, the ID string is the 9 digit string that appears at the end of an
	// App Store URL (e.g., "476943146" for "Flood-It! 2" whose App Store link is
	// http://itunes.apple.com/us/app/flood-it!-2/id476943146).
	// For Android, the ID string is the application's package name
	// (e.g., "com.labpixies.colordrips" for "Color Drips" given Google Play link
	// https://play.google.com/store/apps/details?id=com.labpixies.colordrips).
	// Required when creating CrmBasedUserList for uploading mobile advertising
	// IDs.
	AppId *wrappers.StringValue `protobuf:"bytes,1,opt,name=app_id,json=appId,proto3" json:"app_id,omitempty"`
	// Matching key type of the list.
	// Mixed data types are not allowed on the same list.
	// This field is required for an ADD operation.
	UploadKeyType enums.CustomerMatchUploadKeyTypeEnum_CustomerMatchUploadKeyType `protobuf:"varint,2,opt,name=upload_key_type,json=uploadKeyType,proto3,enum=google.ads.googleads.v0.enums.CustomerMatchUploadKeyTypeEnum_CustomerMatchUploadKeyType" json:"upload_key_type,omitempty"`
	// Data source of the list. Default value is FIRST_PARTY.
	// Only whitelisted customers can create third party sourced crm lists.
	DataSourceType       enums.UserListCrmDataSourceTypeEnum_UserListCrmDataSourceType `protobuf:"varint,3,opt,name=data_source_type,json=dataSourceType,proto3,enum=google.ads.googleads.v0.enums.UserListCrmDataSourceTypeEnum_UserListCrmDataSourceType" json:"data_source_type,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                                                      `json:"-"`
	XXX_unrecognized     []byte                                                        `json:"-"`
	XXX_sizecache        int32                                                         `json:"-"`
}

func (m *CrmBasedUserListInfo) Reset()         { *m = CrmBasedUserListInfo{} }
func (m *CrmBasedUserListInfo) String() string { return proto.CompactTextString(m) }
func (*CrmBasedUserListInfo) ProtoMessage()    {}
func (*CrmBasedUserListInfo) Descriptor() ([]byte, []int) {
	return fileDescriptor_user_lists_7f01f78cb9521749, []int{1}
}
func (m *CrmBasedUserListInfo) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CrmBasedUserListInfo.Unmarshal(m, b)
}
func (m *CrmBasedUserListInfo) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CrmBasedUserListInfo.Marshal(b, m, deterministic)
}
func (dst *CrmBasedUserListInfo) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CrmBasedUserListInfo.Merge(dst, src)
}
func (m *CrmBasedUserListInfo) XXX_Size() int {
	return xxx_messageInfo_CrmBasedUserListInfo.Size(m)
}
func (m *CrmBasedUserListInfo) XXX_DiscardUnknown() {
	xxx_messageInfo_CrmBasedUserListInfo.DiscardUnknown(m)
}

var xxx_messageInfo_CrmBasedUserListInfo proto.InternalMessageInfo

func (m *CrmBasedUserListInfo) GetAppId() *wrappers.StringValue {
	if m != nil {
		return m.AppId
	}
	return nil
}

func (m *CrmBasedUserListInfo) GetUploadKeyType() enums.CustomerMatchUploadKeyTypeEnum_CustomerMatchUploadKeyType {
	if m != nil {
		return m.UploadKeyType
	}
	return enums.CustomerMatchUploadKeyTypeEnum_UNSPECIFIED
}

func (m *CrmBasedUserListInfo) GetDataSourceType() enums.UserListCrmDataSourceTypeEnum_UserListCrmDataSourceType {
	if m != nil {
		return m.DataSourceType
	}
	return enums.UserListCrmDataSourceTypeEnum_UNSPECIFIED
}

func init() {
	proto.RegisterType((*SimilarUserListInfo)(nil), "google.ads.googleads.v0.common.SimilarUserListInfo")
	proto.RegisterType((*CrmBasedUserListInfo)(nil), "google.ads.googleads.v0.common.CrmBasedUserListInfo")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v0/common/user_lists.proto", fileDescriptor_user_lists_7f01f78cb9521749)
}

var fileDescriptor_user_lists_7f01f78cb9521749 = []byte{
	// 427 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x92, 0xcf, 0x6e, 0xd4, 0x30,
	0x10, 0xc6, 0x95, 0x54, 0xf4, 0x10, 0x20, 0xa0, 0x85, 0xc3, 0x0a, 0xa1, 0xaa, 0xda, 0x53, 0x4f,
	0x76, 0xd4, 0x1e, 0x39, 0x25, 0x29, 0xaa, 0x2a, 0x40, 0xaa, 0x76, 0x69, 0x04, 0x28, 0x92, 0xe5,
	0xc6, 0x6e, 0x88, 0x88, 0x63, 0xcb, 0x63, 0x17, 0xe5, 0xc6, 0xb3, 0x70, 0xe4, 0x39, 0x38, 0x71,
	0xe3, 0x8d, 0x50, 0x9c, 0x3f, 0x94, 0x95, 0xb2, 0xcb, 0x69, 0x67, 0xd6, 0x33, 0xbf, 0xf9, 0xe6,
	0xcb, 0x04, 0xb8, 0x94, 0xb2, 0xac, 0x39, 0xa6, 0x0c, 0x86, 0xb0, 0x8b, 0xee, 0x22, 0x5c, 0x48,
	0x21, 0x64, 0x83, 0x2d, 0x70, 0x4d, 0xea, 0x0a, 0x0c, 0x20, 0xa5, 0xa5, 0x91, 0x8b, 0xa3, 0xbe,
	0x0a, 0x51, 0x06, 0x68, 0x6a, 0x40, 0x77, 0x11, 0xea, 0x1b, 0x5e, 0x24, 0x73, 0x40, 0xde, 0x58,
	0x01, 0xb8, 0xb0, 0x60, 0xa4, 0xe0, 0x9a, 0x08, 0x6a, 0x8a, 0xcf, 0xc4, 0xaa, 0x5a, 0x52, 0x46,
	0xbe, 0xf0, 0x96, 0x98, 0x56, 0xf1, 0x7e, 0xc6, 0x3e, 0xc6, 0xa4, 0x89, 0x14, 0x5a, 0x10, 0x46,
	0x0d, 0x25, 0x20, 0xad, 0x2e, 0xf8, 0x7d, 0xc6, 0xa0, 0x13, 0xbb, 0xec, 0xc6, 0xde, 0xe2, 0xaf,
	0x9a, 0x2a, 0xc5, 0xf5, 0xb0, 0xc7, 0xea, 0x63, 0xf0, 0x6c, 0x53, 0x89, 0xaa, 0xa6, 0xfa, 0x1a,
	0xb8, 0x7e, 0x5b, 0x81, 0xb9, 0x6c, 0x6e, 0xe5, 0x22, 0x09, 0x42, 0xe0, 0x9c, 0x91, 0x69, 0xc6,
	0xd2, 0x3b, 0xf6, 0x4e, 0x1e, 0x9e, 0xbe, 0x1c, 0x96, 0x45, 0x23, 0x0f, 0x6d, 0x8c, 0xae, 0x9a,
	0x32, 0xa3, 0xb5, 0xe5, 0xeb, 0x47, 0x5d, 0xcf, 0xc8, 0x59, 0xfd, 0xf6, 0x83, 0xe7, 0xa9, 0x16,
	0x09, 0x85, 0xbf, 0x7f, 0x3a, 0xf8, 0x59, 0x70, 0x48, 0x95, 0x22, 0x15, 0xfb, 0x2f, 0xe8, 0x03,
	0xaa, 0xd4, 0x25, 0x5b, 0x7c, 0xf3, 0x82, 0x27, 0x5b, 0x36, 0x2d, 0xfd, 0x63, 0xef, 0x24, 0x3c,
	0xfd, 0x80, 0xe6, 0xbe, 0x85, 0xf3, 0x09, 0xa5, 0x83, 0xd7, 0xef, 0x3a, 0xab, 0xaf, 0x1d, 0xe2,
	0x0d, 0x6f, 0xdf, 0xb7, 0x8a, 0xbf, 0x6e, 0xac, 0xd8, 0xf1, 0xbc, 0x7e, 0x6c, 0xef, 0xa7, 0x9d,
	0x84, 0xa7, 0xdb, 0x36, 0x2f, 0x0f, 0x9c, 0x86, 0x6c, 0x8f, 0x86, 0x71, 0xff, 0x54, 0x8b, 0x73,
	0x6a, 0xe8, 0xc6, 0x01, 0x26, 0x09, 0xb3, 0xaf, 0xeb, 0x90, 0xfd, 0x93, 0x27, 0x3f, 0xbd, 0x60,
	0x55, 0x48, 0x81, 0x76, 0x5f, 0x5f, 0x12, 0x8e, 0x44, 0xb8, 0xea, 0x2c, 0xbd, 0xf2, 0x3e, 0x9d,
	0x0f, 0x1d, 0xa5, 0xac, 0x69, 0x53, 0x22, 0xa9, 0x4b, 0x5c, 0xf2, 0xc6, 0x19, 0x3e, 0xde, 0x96,
	0xaa, 0x60, 0xee, 0xfe, 0x5f, 0xf5, 0x3f, 0xdf, 0xfd, 0x83, 0x8b, 0x38, 0xfe, 0xe1, 0x1f, 0x5d,
	0xf4, 0xb0, 0x98, 0x01, 0xea, 0xc3, 0x2e, 0xca, 0x22, 0x94, 0xba, 0xb2, 0x5f, 0x63, 0x41, 0x1e,
	0x33, 0xc8, 0xa7, 0x82, 0x3c, 0x8b, 0xf2, 0xbe, 0xe0, 0xe6, 0xd0, 0x0d, 0x3e, 0xfb, 0x13, 0x00,
	0x00, 0xff, 0xff, 0x74, 0x93, 0xe3, 0x13, 0x77, 0x03, 0x00, 0x00,
}
