// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v0/common/feed_common.proto

package common // import "google.golang.org/genproto/googleapis/ads/googleads/v0/common"

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"
import wrappers "github.com/golang/protobuf/ptypes/wrappers"

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// Represents a price in a particular currency.
type Price struct {
	// Three-character ISO 4217 currency code.
	CurrencyCode *wrappers.StringValue `protobuf:"bytes,1,opt,name=currency_code,json=currencyCode,proto3" json:"currency_code,omitempty"`
	// Amount in micros. One million is equivalent to one unit.
	AmountMicros         *wrappers.Int64Value `protobuf:"bytes,2,opt,name=amount_micros,json=amountMicros,proto3" json:"amount_micros,omitempty"`
	XXX_NoUnkeyedLiteral struct{}             `json:"-"`
	XXX_unrecognized     []byte               `json:"-"`
	XXX_sizecache        int32                `json:"-"`
}

func (m *Price) Reset()         { *m = Price{} }
func (m *Price) String() string { return proto.CompactTextString(m) }
func (*Price) ProtoMessage()    {}
func (*Price) Descriptor() ([]byte, []int) {
	return fileDescriptor_feed_common_3c465e0e5062e040, []int{0}
}
func (m *Price) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_Price.Unmarshal(m, b)
}
func (m *Price) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_Price.Marshal(b, m, deterministic)
}
func (dst *Price) XXX_Merge(src proto.Message) {
	xxx_messageInfo_Price.Merge(dst, src)
}
func (m *Price) XXX_Size() int {
	return xxx_messageInfo_Price.Size(m)
}
func (m *Price) XXX_DiscardUnknown() {
	xxx_messageInfo_Price.DiscardUnknown(m)
}

var xxx_messageInfo_Price proto.InternalMessageInfo

func (m *Price) GetCurrencyCode() *wrappers.StringValue {
	if m != nil {
		return m.CurrencyCode
	}
	return nil
}

func (m *Price) GetAmountMicros() *wrappers.Int64Value {
	if m != nil {
		return m.AmountMicros
	}
	return nil
}

func init() {
	proto.RegisterType((*Price)(nil), "google.ads.googleads.v0.common.Price")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v0/common/feed_common.proto", fileDescriptor_feed_common_3c465e0e5062e040)
}

var fileDescriptor_feed_common_3c465e0e5062e040 = []byte{
	// 294 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x90, 0xc1, 0x4a, 0xf3, 0x40,
	0x14, 0x85, 0x49, 0x7f, 0x7e, 0x17, 0xd1, 0x22, 0x74, 0x55, 0x54, 0x8a, 0x74, 0xe5, 0x6a, 0x26,
	0xa8, 0xb8, 0x71, 0x63, 0x5a, 0xb1, 0xb8, 0x10, 0x82, 0x42, 0x16, 0x12, 0x08, 0xd3, 0x99, 0xdb,
	0x21, 0x90, 0xcc, 0x0d, 0x33, 0x49, 0xc5, 0x77, 0xf0, 0x29, 0x5c, 0xfa, 0x1e, 0x6e, 0x7c, 0x2a,
	0xc9, 0xdc, 0xa4, 0x1b, 0xd1, 0x55, 0x0e, 0xe4, 0x7c, 0xdf, 0x61, 0x6e, 0x18, 0x69, 0x44, 0x5d,
	0x02, 0x17, 0xca, 0x71, 0x8a, 0x5d, 0xda, 0x46, 0x5c, 0x62, 0x55, 0xa1, 0xe1, 0x1b, 0x00, 0x95,
	0x53, 0x66, 0xb5, 0xc5, 0x06, 0x27, 0x33, 0xaa, 0x31, 0xa1, 0x1c, 0xdb, 0x11, 0x6c, 0x1b, 0x31,
	0x6a, 0x1d, 0xf5, 0xff, 0xb9, 0x6f, 0xaf, 0xdb, 0x0d, 0x7f, 0xb1, 0xa2, 0xae, 0xc1, 0x3a, 0xe2,
	0xe7, 0x6f, 0x41, 0xf8, 0x3f, 0xb1, 0x85, 0x84, 0x49, 0x1c, 0x8e, 0x65, 0x6b, 0x2d, 0x18, 0xf9,
	0x9a, 0x4b, 0x54, 0x30, 0x0d, 0x4e, 0x83, 0xb3, 0xfd, 0xf3, 0x93, 0x5e, 0xcb, 0x06, 0x03, 0x7b,
	0x6a, 0x6c, 0x61, 0x74, 0x2a, 0xca, 0x16, 0x1e, 0x0f, 0x06, 0x64, 0x89, 0x0a, 0x26, 0x37, 0xe1,
	0x58, 0x54, 0xd8, 0x9a, 0x26, 0xaf, 0x0a, 0x69, 0xd1, 0x4d, 0x47, 0x5e, 0x71, 0xfc, 0x43, 0x71,
	0x6f, 0x9a, 0xab, 0xcb, 0xde, 0x40, 0xc4, 0x83, 0x07, 0x16, 0x9f, 0x41, 0x38, 0x97, 0x58, 0xb1,
	0xbf, 0x5f, 0xb5, 0x38, 0xbc, 0x03, 0x50, 0x4b, 0x9f, 0x93, 0xce, 0x99, 0x04, 0xcf, 0xb7, 0x3d,
	0xa2, 0xb1, 0x14, 0x46, 0x33, 0xb4, 0x9a, 0x6b, 0x30, 0x7e, 0x71, 0x38, 0x65, 0x5d, 0xb8, 0xdf,
	0x2e, 0x7b, 0x4d, 0x9f, 0xf7, 0xd1, 0xbf, 0x55, 0x1c, 0x7f, 0x8c, 0x66, 0x2b, 0x92, 0xc5, 0xca,
	0x31, 0x8a, 0x5d, 0x4a, 0x23, 0x46, 0x9b, 0x5f, 0x43, 0x21, 0x8b, 0x95, 0xcb, 0x76, 0x85, 0x2c,
	0x8d, 0x32, 0x2a, 0xac, 0xf7, 0xfc, 0xf0, 0xc5, 0x77, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfc, 0x3c,
	0x7c, 0x9a, 0xd1, 0x01, 0x00, 0x00,
}
