// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v0/enums/ad_type.proto

package enums // import "google.golang.org/genproto/googleapis/ads/googleads/v0/enums"

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// The possible types of an ad.
type AdTypeEnum_AdType int32

const (
	// No value has been specified.
	AdTypeEnum_UNSPECIFIED AdTypeEnum_AdType = 0
	// The received value is not known in this version.
	//
	// This is a response-only value.
	AdTypeEnum_UNKNOWN AdTypeEnum_AdType = 1
	// The ad is a text ad.
	AdTypeEnum_TEXT_AD AdTypeEnum_AdType = 2
	// The ad is an expanded text ad.
	AdTypeEnum_EXPANDED_TEXT_AD AdTypeEnum_AdType = 3
	// The ad is a dynamic search ad.
	AdTypeEnum_DYNAMIC_SEARCH_AD AdTypeEnum_AdType = 4
	// The ad is a responsive display ad.
	AdTypeEnum_RESPONSIVE_DISPLAY_AD AdTypeEnum_AdType = 5
	// The ad is a call only ad.
	AdTypeEnum_CALL_ONLY_AD AdTypeEnum_AdType = 6
	// The ad is an expanded dynamic search ad.
	AdTypeEnum_EXPANDED_DYNAMIC_SEARCH_AD AdTypeEnum_AdType = 7
	// The ad is a hotel ad.
	AdTypeEnum_HOTEL_AD AdTypeEnum_AdType = 8
	// The ad is a Smart Shopping ad.
	AdTypeEnum_SHOPPING_SMART_AD AdTypeEnum_AdType = 9
	// The ad is a standard Shopping ad.
	AdTypeEnum_SHOPPING_PRODUCT_AD AdTypeEnum_AdType = 10
	// The ad is a video ad.
	AdTypeEnum_VIDEO_AD AdTypeEnum_AdType = 12
	// This ad is a Gmail ad.
	AdTypeEnum_GMAIL_AD AdTypeEnum_AdType = 13
	// This ad is an Image ad.
	AdTypeEnum_IMAGE_AD AdTypeEnum_AdType = 14
)

var AdTypeEnum_AdType_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	2:  "TEXT_AD",
	3:  "EXPANDED_TEXT_AD",
	4:  "DYNAMIC_SEARCH_AD",
	5:  "RESPONSIVE_DISPLAY_AD",
	6:  "CALL_ONLY_AD",
	7:  "EXPANDED_DYNAMIC_SEARCH_AD",
	8:  "HOTEL_AD",
	9:  "SHOPPING_SMART_AD",
	10: "SHOPPING_PRODUCT_AD",
	12: "VIDEO_AD",
	13: "GMAIL_AD",
	14: "IMAGE_AD",
}
var AdTypeEnum_AdType_value = map[string]int32{
	"UNSPECIFIED":                0,
	"UNKNOWN":                    1,
	"TEXT_AD":                    2,
	"EXPANDED_TEXT_AD":           3,
	"DYNAMIC_SEARCH_AD":          4,
	"RESPONSIVE_DISPLAY_AD":      5,
	"CALL_ONLY_AD":               6,
	"EXPANDED_DYNAMIC_SEARCH_AD": 7,
	"HOTEL_AD":                   8,
	"SHOPPING_SMART_AD":          9,
	"SHOPPING_PRODUCT_AD":        10,
	"VIDEO_AD":                   12,
	"GMAIL_AD":                   13,
	"IMAGE_AD":                   14,
}

func (x AdTypeEnum_AdType) String() string {
	return proto.EnumName(AdTypeEnum_AdType_name, int32(x))
}
func (AdTypeEnum_AdType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_ad_type_0178b510acb3ad28, []int{0, 0}
}

// Container for enum describing possible types of an ad.
type AdTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *AdTypeEnum) Reset()         { *m = AdTypeEnum{} }
func (m *AdTypeEnum) String() string { return proto.CompactTextString(m) }
func (*AdTypeEnum) ProtoMessage()    {}
func (*AdTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_ad_type_0178b510acb3ad28, []int{0}
}
func (m *AdTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AdTypeEnum.Unmarshal(m, b)
}
func (m *AdTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AdTypeEnum.Marshal(b, m, deterministic)
}
func (dst *AdTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AdTypeEnum.Merge(dst, src)
}
func (m *AdTypeEnum) XXX_Size() int {
	return xxx_messageInfo_AdTypeEnum.Size(m)
}
func (m *AdTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_AdTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_AdTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterType((*AdTypeEnum)(nil), "google.ads.googleads.v0.enums.AdTypeEnum")
	proto.RegisterEnum("google.ads.googleads.v0.enums.AdTypeEnum_AdType", AdTypeEnum_AdType_name, AdTypeEnum_AdType_value)
}

func init() {
	proto.RegisterFile("google/ads/googleads/v0/enums/ad_type.proto", fileDescriptor_ad_type_0178b510acb3ad28)
}

var fileDescriptor_ad_type_0178b510acb3ad28 = []byte{
	// 386 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x51, 0xdd, 0x8a, 0xd3, 0x40,
	0x14, 0xb6, 0xa9, 0xb6, 0x75, 0x5a, 0x35, 0x8e, 0x16, 0x51, 0xa8, 0x60, 0x6f, 0x85, 0x49, 0xc0,
	0x4b, 0xaf, 0xa6, 0x99, 0x31, 0x1d, 0x4c, 0x26, 0x43, 0x92, 0xc6, 0x56, 0x02, 0x21, 0x9a, 0x10,
	0x84, 0x36, 0x09, 0x4d, 0x5b, 0xe8, 0x83, 0xf8, 0x02, 0xe2, 0xd5, 0x3e, 0xc3, 0x3e, 0xc1, 0x3e,
	0xd5, 0x32, 0x93, 0x6d, 0x6e, 0x96, 0xdd, 0x9b, 0x70, 0xbe, 0x9f, 0x7c, 0x67, 0x38, 0x1f, 0xf8,
	0x5c, 0x54, 0x55, 0xb1, 0xcd, 0x8d, 0x34, 0x6b, 0x8c, 0x76, 0x94, 0xd3, 0xc9, 0x34, 0xf2, 0xf2,
	0xb8, 0x6b, 0x8c, 0x34, 0x4b, 0x0e, 0xe7, 0x3a, 0x47, 0xf5, 0xbe, 0x3a, 0x54, 0x70, 0xd6, 0x3a,
	0x50, 0x9a, 0x35, 0xa8, 0x33, 0xa3, 0x93, 0x89, 0x94, 0x79, 0xfe, 0x5f, 0x03, 0x00, 0x67, 0xe1,
	0xb9, 0xce, 0x69, 0x79, 0xdc, 0xcd, 0xff, 0x6a, 0x60, 0xd0, 0x42, 0xf8, 0x0a, 0x8c, 0x57, 0x3c,
	0x10, 0xd4, 0x62, 0xdf, 0x18, 0x25, 0xfa, 0x13, 0x38, 0x06, 0xc3, 0x15, 0xff, 0xce, 0xbd, 0x1f,
	0x5c, 0xef, 0x49, 0x10, 0xd2, 0x75, 0x98, 0x60, 0xa2, 0x6b, 0xf0, 0x2d, 0xd0, 0xe9, 0x5a, 0x60,
	0x4e, 0x28, 0x49, 0x2e, 0x6c, 0x1f, 0x4e, 0xc1, 0x6b, 0xb2, 0xe1, 0xd8, 0x65, 0x56, 0x12, 0x50,
	0xec, 0x5b, 0x4b, 0x49, 0x3f, 0x85, 0xef, 0xc1, 0xd4, 0xa7, 0x81, 0xf0, 0x78, 0xc0, 0x22, 0x9a,
	0x10, 0x16, 0x08, 0x07, 0x6f, 0xa4, 0xf4, 0x0c, 0xea, 0x60, 0x62, 0x61, 0xc7, 0x49, 0x3c, 0xee,
	0x28, 0x66, 0x00, 0x3f, 0x82, 0x0f, 0x5d, 0xf2, 0xfd, 0xb0, 0x21, 0x9c, 0x80, 0xd1, 0xd2, 0x0b,
	0xa9, 0x23, 0xd1, 0x48, 0x6e, 0x0c, 0x96, 0x9e, 0x10, 0x8c, 0xdb, 0x49, 0xe0, 0x62, 0x5f, 0x3d,
	0xe4, 0x39, 0x7c, 0x07, 0xde, 0x74, 0xb4, 0xf0, 0x3d, 0xb2, 0xb2, 0x94, 0x00, 0xe4, 0xdf, 0x11,
	0x23, 0xd4, 0x93, 0x68, 0x22, 0x91, 0xed, 0x62, 0xa6, 0xb2, 0x5e, 0x48, 0xc4, 0x5c, 0x6c, 0x53,
	0x89, 0x5e, 0x2e, 0xae, 0x7b, 0xe0, 0xd3, 0xef, 0x6a, 0x87, 0x1e, 0x3d, 0xe6, 0x62, 0xdc, 0x9e,
	0x4e, 0xc8, 0xc3, 0x8b, 0xde, 0xcf, 0xc5, 0x9d, 0xbb, 0xa8, 0xb6, 0x69, 0x59, 0xa0, 0x6a, 0x5f,
	0x18, 0x45, 0x5e, 0xaa, 0x5a, 0x2e, 0xbd, 0xd5, 0x7f, 0x9a, 0x07, 0x6a, 0xfc, 0xaa, 0xbe, 0xff,
	0xb4, 0xbe, 0x8d, 0xf1, 0x95, 0x36, 0xb3, 0xdb, 0x28, 0x9c, 0x35, 0xa8, 0x1d, 0xe5, 0x14, 0x99,
	0x48, 0xb6, 0xd6, 0xdc, 0x5c, 0xf4, 0x18, 0x67, 0x4d, 0xdc, 0xe9, 0x71, 0x64, 0xc6, 0x4a, 0xff,
	0x35, 0x50, 0x4b, 0xbf, 0xdc, 0x06, 0x00, 0x00, 0xff, 0xff, 0x0a, 0xf6, 0xba, 0x75, 0x3a, 0x02,
	0x00, 0x00,
}
