// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v0/resources/display_keyword_view.proto

package resources // import "google.golang.org/genproto/googleapis/ads/googleads/v0/resources"

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// A display keyword view.
type DisplayKeywordView struct {
	// The resource name of the display keyword view.
	// Display Keyword view resource names have the form:
	//
	// `customers/{customer_id}/displayKeywordViews/{ad_group_id}_{criterion_id}`
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *DisplayKeywordView) Reset()         { *m = DisplayKeywordView{} }
func (m *DisplayKeywordView) String() string { return proto.CompactTextString(m) }
func (*DisplayKeywordView) ProtoMessage()    {}
func (*DisplayKeywordView) Descriptor() ([]byte, []int) {
	return fileDescriptor_display_keyword_view_8e70ac1b36b894b2, []int{0}
}
func (m *DisplayKeywordView) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_DisplayKeywordView.Unmarshal(m, b)
}
func (m *DisplayKeywordView) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_DisplayKeywordView.Marshal(b, m, deterministic)
}
func (dst *DisplayKeywordView) XXX_Merge(src proto.Message) {
	xxx_messageInfo_DisplayKeywordView.Merge(dst, src)
}
func (m *DisplayKeywordView) XXX_Size() int {
	return xxx_messageInfo_DisplayKeywordView.Size(m)
}
func (m *DisplayKeywordView) XXX_DiscardUnknown() {
	xxx_messageInfo_DisplayKeywordView.DiscardUnknown(m)
}

var xxx_messageInfo_DisplayKeywordView proto.InternalMessageInfo

func (m *DisplayKeywordView) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*DisplayKeywordView)(nil), "google.ads.googleads.v0.resources.DisplayKeywordView")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v0/resources/display_keyword_view.proto", fileDescriptor_display_keyword_view_8e70ac1b36b894b2)
}

var fileDescriptor_display_keyword_view_8e70ac1b36b894b2 = []byte{
	// 235 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xe2, 0xb2, 0x49, 0xcf, 0xcf, 0x4f,
	0xcf, 0x49, 0xd5, 0x4f, 0x4c, 0x29, 0xd6, 0x87, 0x30, 0x41, 0xac, 0x32, 0x03, 0xfd, 0xa2, 0xd4,
	0xe2, 0xfc, 0xd2, 0xa2, 0xe4, 0xd4, 0x62, 0xfd, 0x94, 0xcc, 0xe2, 0x82, 0x9c, 0xc4, 0xca, 0xf8,
	0xec, 0xd4, 0xca, 0xf2, 0xfc, 0xa2, 0x94, 0xf8, 0xb2, 0xcc, 0xd4, 0x72, 0xbd, 0x82, 0xa2, 0xfc,
	0x92, 0x7c, 0x21, 0x45, 0x88, 0x16, 0xbd, 0xc4, 0x94, 0x62, 0x3d, 0xb8, 0x6e, 0xbd, 0x32, 0x03,
	0x3d, 0xb8, 0x6e, 0x25, 0x4b, 0x2e, 0x21, 0x17, 0x88, 0x01, 0xde, 0x10, 0xfd, 0x61, 0x99, 0xa9,
	0xe5, 0x42, 0xca, 0x5c, 0xbc, 0x30, 0x25, 0xf1, 0x79, 0x89, 0xb9, 0xa9, 0x12, 0x8c, 0x0a, 0x8c,
	0x1a, 0x9c, 0x41, 0x3c, 0x30, 0x41, 0xbf, 0xc4, 0xdc, 0x54, 0xa7, 0x3b, 0x8c, 0x5c, 0xaa, 0xc9,
	0xf9, 0xb9, 0x7a, 0x04, 0x2d, 0x71, 0x12, 0xc7, 0xb4, 0x22, 0x00, 0xe4, 0xc0, 0x00, 0xc6, 0x28,
	0x2f, 0xa8, 0xee, 0xf4, 0xfc, 0x9c, 0xc4, 0xbc, 0x74, 0xbd, 0xfc, 0xa2, 0x74, 0xfd, 0xf4, 0xd4,
	0x3c, 0xb0, 0xf3, 0x61, 0x1e, 0x2e, 0xc8, 0x2c, 0xc6, 0xe3, 0x7f, 0x6b, 0x38, 0x6b, 0x11, 0x13,
	0xb3, 0xbb, 0xa3, 0xe3, 0x2a, 0x26, 0x45, 0x77, 0x88, 0x91, 0x8e, 0x29, 0xc5, 0x7a, 0x10, 0x26,
	0x88, 0x15, 0x66, 0xa0, 0x17, 0x04, 0x53, 0x79, 0x0a, 0xa6, 0x26, 0xc6, 0x31, 0xa5, 0x38, 0x06,
	0xae, 0x26, 0x26, 0xcc, 0x20, 0x06, 0xae, 0x26, 0x89, 0x0d, 0xec, 0x08, 0x63, 0x40, 0x00, 0x00,
	0x00, 0xff, 0xff, 0x64, 0xb4, 0x1f, 0x4e, 0x83, 0x01, 0x00, 0x00,
}
