// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v0/services/campaign_bid_modifier_service.proto

package services // import "google.golang.org/genproto/googleapis/ads/googleads/v0/services"

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"
import resources "google.golang.org/genproto/googleapis/ads/googleads/v0/resources"
import _ "google.golang.org/genproto/googleapis/api/annotations"
import field_mask "google.golang.org/genproto/protobuf/field_mask"

import (
	context "golang.org/x/net/context"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// Request message for [CampaignBidModifierService.GetCampaignBidModifier][google.ads.googleads.v0.services.CampaignBidModifierService.GetCampaignBidModifier].
type GetCampaignBidModifierRequest struct {
	// The resource name of the campaign bid modifier to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetCampaignBidModifierRequest) Reset()         { *m = GetCampaignBidModifierRequest{} }
func (m *GetCampaignBidModifierRequest) String() string { return proto.CompactTextString(m) }
func (*GetCampaignBidModifierRequest) ProtoMessage()    {}
func (*GetCampaignBidModifierRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_campaign_bid_modifier_service_2bb6851aed97491b, []int{0}
}
func (m *GetCampaignBidModifierRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetCampaignBidModifierRequest.Unmarshal(m, b)
}
func (m *GetCampaignBidModifierRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetCampaignBidModifierRequest.Marshal(b, m, deterministic)
}
func (dst *GetCampaignBidModifierRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetCampaignBidModifierRequest.Merge(dst, src)
}
func (m *GetCampaignBidModifierRequest) XXX_Size() int {
	return xxx_messageInfo_GetCampaignBidModifierRequest.Size(m)
}
func (m *GetCampaignBidModifierRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetCampaignBidModifierRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetCampaignBidModifierRequest proto.InternalMessageInfo

func (m *GetCampaignBidModifierRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

// Request message for [CampaignBidModifierService.MutateCampaignBidModifier][].
type MutateCampaignBidModifiersRequest struct {
	// ID of the customer whose campaign bid modifiers are being modified.
	CustomerId string `protobuf:"bytes,1,opt,name=customer_id,json=customerId,proto3" json:"customer_id,omitempty"`
	// The list of operations to perform on individual campaign bid modifiers.
	Operations           []*CampaignBidModifierOperation `protobuf:"bytes,2,rep,name=operations,proto3" json:"operations,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                        `json:"-"`
	XXX_unrecognized     []byte                          `json:"-"`
	XXX_sizecache        int32                           `json:"-"`
}

func (m *MutateCampaignBidModifiersRequest) Reset()         { *m = MutateCampaignBidModifiersRequest{} }
func (m *MutateCampaignBidModifiersRequest) String() string { return proto.CompactTextString(m) }
func (*MutateCampaignBidModifiersRequest) ProtoMessage()    {}
func (*MutateCampaignBidModifiersRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_campaign_bid_modifier_service_2bb6851aed97491b, []int{1}
}
func (m *MutateCampaignBidModifiersRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MutateCampaignBidModifiersRequest.Unmarshal(m, b)
}
func (m *MutateCampaignBidModifiersRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MutateCampaignBidModifiersRequest.Marshal(b, m, deterministic)
}
func (dst *MutateCampaignBidModifiersRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MutateCampaignBidModifiersRequest.Merge(dst, src)
}
func (m *MutateCampaignBidModifiersRequest) XXX_Size() int {
	return xxx_messageInfo_MutateCampaignBidModifiersRequest.Size(m)
}
func (m *MutateCampaignBidModifiersRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_MutateCampaignBidModifiersRequest.DiscardUnknown(m)
}

var xxx_messageInfo_MutateCampaignBidModifiersRequest proto.InternalMessageInfo

func (m *MutateCampaignBidModifiersRequest) GetCustomerId() string {
	if m != nil {
		return m.CustomerId
	}
	return ""
}

func (m *MutateCampaignBidModifiersRequest) GetOperations() []*CampaignBidModifierOperation {
	if m != nil {
		return m.Operations
	}
	return nil
}

// A single operation (create, remove, update) on a campaign bid modifier.
type CampaignBidModifierOperation struct {
	// FieldMask that determines which resource fields are modified in an update.
	UpdateMask *field_mask.FieldMask `protobuf:"bytes,4,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
	// The mutate operation.
	//
	// Types that are valid to be assigned to Operation:
	//	*CampaignBidModifierOperation_Create
	//	*CampaignBidModifierOperation_Update
	//	*CampaignBidModifierOperation_Remove
	Operation            isCampaignBidModifierOperation_Operation `protobuf_oneof:"operation"`
	XXX_NoUnkeyedLiteral struct{}                                 `json:"-"`
	XXX_unrecognized     []byte                                   `json:"-"`
	XXX_sizecache        int32                                    `json:"-"`
}

func (m *CampaignBidModifierOperation) Reset()         { *m = CampaignBidModifierOperation{} }
func (m *CampaignBidModifierOperation) String() string { return proto.CompactTextString(m) }
func (*CampaignBidModifierOperation) ProtoMessage()    {}
func (*CampaignBidModifierOperation) Descriptor() ([]byte, []int) {
	return fileDescriptor_campaign_bid_modifier_service_2bb6851aed97491b, []int{2}
}
func (m *CampaignBidModifierOperation) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CampaignBidModifierOperation.Unmarshal(m, b)
}
func (m *CampaignBidModifierOperation) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CampaignBidModifierOperation.Marshal(b, m, deterministic)
}
func (dst *CampaignBidModifierOperation) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CampaignBidModifierOperation.Merge(dst, src)
}
func (m *CampaignBidModifierOperation) XXX_Size() int {
	return xxx_messageInfo_CampaignBidModifierOperation.Size(m)
}
func (m *CampaignBidModifierOperation) XXX_DiscardUnknown() {
	xxx_messageInfo_CampaignBidModifierOperation.DiscardUnknown(m)
}

var xxx_messageInfo_CampaignBidModifierOperation proto.InternalMessageInfo

func (m *CampaignBidModifierOperation) GetUpdateMask() *field_mask.FieldMask {
	if m != nil {
		return m.UpdateMask
	}
	return nil
}

type isCampaignBidModifierOperation_Operation interface {
	isCampaignBidModifierOperation_Operation()
}

type CampaignBidModifierOperation_Create struct {
	Create *resources.CampaignBidModifier `protobuf:"bytes,1,opt,name=create,proto3,oneof"`
}

type CampaignBidModifierOperation_Update struct {
	Update *resources.CampaignBidModifier `protobuf:"bytes,2,opt,name=update,proto3,oneof"`
}

type CampaignBidModifierOperation_Remove struct {
	Remove string `protobuf:"bytes,3,opt,name=remove,proto3,oneof"`
}

func (*CampaignBidModifierOperation_Create) isCampaignBidModifierOperation_Operation() {}

func (*CampaignBidModifierOperation_Update) isCampaignBidModifierOperation_Operation() {}

func (*CampaignBidModifierOperation_Remove) isCampaignBidModifierOperation_Operation() {}

func (m *CampaignBidModifierOperation) GetOperation() isCampaignBidModifierOperation_Operation {
	if m != nil {
		return m.Operation
	}
	return nil
}

func (m *CampaignBidModifierOperation) GetCreate() *resources.CampaignBidModifier {
	if x, ok := m.GetOperation().(*CampaignBidModifierOperation_Create); ok {
		return x.Create
	}
	return nil
}

func (m *CampaignBidModifierOperation) GetUpdate() *resources.CampaignBidModifier {
	if x, ok := m.GetOperation().(*CampaignBidModifierOperation_Update); ok {
		return x.Update
	}
	return nil
}

func (m *CampaignBidModifierOperation) GetRemove() string {
	if x, ok := m.GetOperation().(*CampaignBidModifierOperation_Remove); ok {
		return x.Remove
	}
	return ""
}

// XXX_OneofFuncs is for the internal use of the proto package.
func (*CampaignBidModifierOperation) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, func(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error), func(msg proto.Message) (n int), []interface{}) {
	return _CampaignBidModifierOperation_OneofMarshaler, _CampaignBidModifierOperation_OneofUnmarshaler, _CampaignBidModifierOperation_OneofSizer, []interface{}{
		(*CampaignBidModifierOperation_Create)(nil),
		(*CampaignBidModifierOperation_Update)(nil),
		(*CampaignBidModifierOperation_Remove)(nil),
	}
}

func _CampaignBidModifierOperation_OneofMarshaler(msg proto.Message, b *proto.Buffer) error {
	m := msg.(*CampaignBidModifierOperation)
	// operation
	switch x := m.Operation.(type) {
	case *CampaignBidModifierOperation_Create:
		b.EncodeVarint(1<<3 | proto.WireBytes)
		if err := b.EncodeMessage(x.Create); err != nil {
			return err
		}
	case *CampaignBidModifierOperation_Update:
		b.EncodeVarint(2<<3 | proto.WireBytes)
		if err := b.EncodeMessage(x.Update); err != nil {
			return err
		}
	case *CampaignBidModifierOperation_Remove:
		b.EncodeVarint(3<<3 | proto.WireBytes)
		b.EncodeStringBytes(x.Remove)
	case nil:
	default:
		return fmt.Errorf("CampaignBidModifierOperation.Operation has unexpected type %T", x)
	}
	return nil
}

func _CampaignBidModifierOperation_OneofUnmarshaler(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error) {
	m := msg.(*CampaignBidModifierOperation)
	switch tag {
	case 1: // operation.create
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		msg := new(resources.CampaignBidModifier)
		err := b.DecodeMessage(msg)
		m.Operation = &CampaignBidModifierOperation_Create{msg}
		return true, err
	case 2: // operation.update
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		msg := new(resources.CampaignBidModifier)
		err := b.DecodeMessage(msg)
		m.Operation = &CampaignBidModifierOperation_Update{msg}
		return true, err
	case 3: // operation.remove
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		x, err := b.DecodeStringBytes()
		m.Operation = &CampaignBidModifierOperation_Remove{x}
		return true, err
	default:
		return false, nil
	}
}

func _CampaignBidModifierOperation_OneofSizer(msg proto.Message) (n int) {
	m := msg.(*CampaignBidModifierOperation)
	// operation
	switch x := m.Operation.(type) {
	case *CampaignBidModifierOperation_Create:
		s := proto.Size(x.Create)
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(s))
		n += s
	case *CampaignBidModifierOperation_Update:
		s := proto.Size(x.Update)
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(s))
		n += s
	case *CampaignBidModifierOperation_Remove:
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(len(x.Remove)))
		n += len(x.Remove)
	case nil:
	default:
		panic(fmt.Sprintf("proto: unexpected type %T in oneof", x))
	}
	return n
}

// Response message for campaign bid modifiers mutate.
type MutateCampaignBidModifiersResponse struct {
	// All results for the mutate.
	Results              []*MutateCampaignBidModifierResult `protobuf:"bytes,2,rep,name=results,proto3" json:"results,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                           `json:"-"`
	XXX_unrecognized     []byte                             `json:"-"`
	XXX_sizecache        int32                              `json:"-"`
}

func (m *MutateCampaignBidModifiersResponse) Reset()         { *m = MutateCampaignBidModifiersResponse{} }
func (m *MutateCampaignBidModifiersResponse) String() string { return proto.CompactTextString(m) }
func (*MutateCampaignBidModifiersResponse) ProtoMessage()    {}
func (*MutateCampaignBidModifiersResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_campaign_bid_modifier_service_2bb6851aed97491b, []int{3}
}
func (m *MutateCampaignBidModifiersResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MutateCampaignBidModifiersResponse.Unmarshal(m, b)
}
func (m *MutateCampaignBidModifiersResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MutateCampaignBidModifiersResponse.Marshal(b, m, deterministic)
}
func (dst *MutateCampaignBidModifiersResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MutateCampaignBidModifiersResponse.Merge(dst, src)
}
func (m *MutateCampaignBidModifiersResponse) XXX_Size() int {
	return xxx_messageInfo_MutateCampaignBidModifiersResponse.Size(m)
}
func (m *MutateCampaignBidModifiersResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_MutateCampaignBidModifiersResponse.DiscardUnknown(m)
}

var xxx_messageInfo_MutateCampaignBidModifiersResponse proto.InternalMessageInfo

func (m *MutateCampaignBidModifiersResponse) GetResults() []*MutateCampaignBidModifierResult {
	if m != nil {
		return m.Results
	}
	return nil
}

// The result for the criterion mutate.
type MutateCampaignBidModifierResult struct {
	// Returned for successful operations.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *MutateCampaignBidModifierResult) Reset()         { *m = MutateCampaignBidModifierResult{} }
func (m *MutateCampaignBidModifierResult) String() string { return proto.CompactTextString(m) }
func (*MutateCampaignBidModifierResult) ProtoMessage()    {}
func (*MutateCampaignBidModifierResult) Descriptor() ([]byte, []int) {
	return fileDescriptor_campaign_bid_modifier_service_2bb6851aed97491b, []int{4}
}
func (m *MutateCampaignBidModifierResult) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MutateCampaignBidModifierResult.Unmarshal(m, b)
}
func (m *MutateCampaignBidModifierResult) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MutateCampaignBidModifierResult.Marshal(b, m, deterministic)
}
func (dst *MutateCampaignBidModifierResult) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MutateCampaignBidModifierResult.Merge(dst, src)
}
func (m *MutateCampaignBidModifierResult) XXX_Size() int {
	return xxx_messageInfo_MutateCampaignBidModifierResult.Size(m)
}
func (m *MutateCampaignBidModifierResult) XXX_DiscardUnknown() {
	xxx_messageInfo_MutateCampaignBidModifierResult.DiscardUnknown(m)
}

var xxx_messageInfo_MutateCampaignBidModifierResult proto.InternalMessageInfo

func (m *MutateCampaignBidModifierResult) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetCampaignBidModifierRequest)(nil), "google.ads.googleads.v0.services.GetCampaignBidModifierRequest")
	proto.RegisterType((*MutateCampaignBidModifiersRequest)(nil), "google.ads.googleads.v0.services.MutateCampaignBidModifiersRequest")
	proto.RegisterType((*CampaignBidModifierOperation)(nil), "google.ads.googleads.v0.services.CampaignBidModifierOperation")
	proto.RegisterType((*MutateCampaignBidModifiersResponse)(nil), "google.ads.googleads.v0.services.MutateCampaignBidModifiersResponse")
	proto.RegisterType((*MutateCampaignBidModifierResult)(nil), "google.ads.googleads.v0.services.MutateCampaignBidModifierResult")
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// CampaignBidModifierServiceClient is the client API for CampaignBidModifierService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type CampaignBidModifierServiceClient interface {
	// Returns the requested campaign bid modifier in full detail.
	GetCampaignBidModifier(ctx context.Context, in *GetCampaignBidModifierRequest, opts ...grpc.CallOption) (*resources.CampaignBidModifier, error)
	// Creates, updates, or removes campaign bid modifiers.
	// Operation statuses are returned.
	MutateCampaignBidModifiers(ctx context.Context, in *MutateCampaignBidModifiersRequest, opts ...grpc.CallOption) (*MutateCampaignBidModifiersResponse, error)
}

type campaignBidModifierServiceClient struct {
	cc *grpc.ClientConn
}

func NewCampaignBidModifierServiceClient(cc *grpc.ClientConn) CampaignBidModifierServiceClient {
	return &campaignBidModifierServiceClient{cc}
}

func (c *campaignBidModifierServiceClient) GetCampaignBidModifier(ctx context.Context, in *GetCampaignBidModifierRequest, opts ...grpc.CallOption) (*resources.CampaignBidModifier, error) {
	out := new(resources.CampaignBidModifier)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v0.services.CampaignBidModifierService/GetCampaignBidModifier", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *campaignBidModifierServiceClient) MutateCampaignBidModifiers(ctx context.Context, in *MutateCampaignBidModifiersRequest, opts ...grpc.CallOption) (*MutateCampaignBidModifiersResponse, error) {
	out := new(MutateCampaignBidModifiersResponse)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v0.services.CampaignBidModifierService/MutateCampaignBidModifiers", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// CampaignBidModifierServiceServer is the server API for CampaignBidModifierService service.
type CampaignBidModifierServiceServer interface {
	// Returns the requested campaign bid modifier in full detail.
	GetCampaignBidModifier(context.Context, *GetCampaignBidModifierRequest) (*resources.CampaignBidModifier, error)
	// Creates, updates, or removes campaign bid modifiers.
	// Operation statuses are returned.
	MutateCampaignBidModifiers(context.Context, *MutateCampaignBidModifiersRequest) (*MutateCampaignBidModifiersResponse, error)
}

func RegisterCampaignBidModifierServiceServer(s *grpc.Server, srv CampaignBidModifierServiceServer) {
	s.RegisterService(&_CampaignBidModifierService_serviceDesc, srv)
}

func _CampaignBidModifierService_GetCampaignBidModifier_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetCampaignBidModifierRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(CampaignBidModifierServiceServer).GetCampaignBidModifier(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v0.services.CampaignBidModifierService/GetCampaignBidModifier",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(CampaignBidModifierServiceServer).GetCampaignBidModifier(ctx, req.(*GetCampaignBidModifierRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _CampaignBidModifierService_MutateCampaignBidModifiers_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(MutateCampaignBidModifiersRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(CampaignBidModifierServiceServer).MutateCampaignBidModifiers(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v0.services.CampaignBidModifierService/MutateCampaignBidModifiers",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(CampaignBidModifierServiceServer).MutateCampaignBidModifiers(ctx, req.(*MutateCampaignBidModifiersRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _CampaignBidModifierService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v0.services.CampaignBidModifierService",
	HandlerType: (*CampaignBidModifierServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetCampaignBidModifier",
			Handler:    _CampaignBidModifierService_GetCampaignBidModifier_Handler,
		},
		{
			MethodName: "MutateCampaignBidModifiers",
			Handler:    _CampaignBidModifierService_MutateCampaignBidModifiers_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v0/services/campaign_bid_modifier_service.proto",
}

func init() {
	proto.RegisterFile("google/ads/googleads/v0/services/campaign_bid_modifier_service.proto", fileDescriptor_campaign_bid_modifier_service_2bb6851aed97491b)
}

var fileDescriptor_campaign_bid_modifier_service_2bb6851aed97491b = []byte{
	// 609 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xa4, 0x95, 0x4f, 0x8b, 0xd3, 0x4e,
	0x18, 0xc7, 0x7f, 0x49, 0x7f, 0xac, 0xec, 0x44, 0x2f, 0x73, 0x90, 0x10, 0x56, 0xb6, 0x46, 0x0f,
	0xa5, 0x87, 0xa4, 0x54, 0x58, 0x74, 0x97, 0x56, 0xda, 0x2d, 0xdb, 0xf5, 0x50, 0x2d, 0x11, 0xf6,
	0xa0, 0xc5, 0x30, 0x6d, 0xa6, 0x61, 0xd8, 0x26, 0x13, 0x67, 0x26, 0xbd, 0x2c, 0x7b, 0xd0, 0xb7,
	0xe0, 0x3b, 0x10, 0xf1, 0xe0, 0x4b, 0xf1, 0x26, 0xbe, 0x00, 0x3d, 0x78, 0xf5, 0x3d, 0x48, 0x32,
	0x99, 0x5a, 0x21, 0x69, 0xc5, 0xde, 0x9e, 0x64, 0x9e, 0x7c, 0x9e, 0x3f, 0xdf, 0x79, 0x9e, 0x80,
	0x41, 0x48, 0x69, 0xb8, 0xc0, 0x2e, 0x0a, 0xb8, 0x2b, 0xcd, 0xcc, 0x5a, 0xb6, 0x5c, 0x8e, 0xd9,
	0x92, 0xcc, 0x30, 0x77, 0x67, 0x28, 0x4a, 0x10, 0x09, 0x63, 0x7f, 0x4a, 0x02, 0x3f, 0xa2, 0x01,
	0x99, 0x13, 0xcc, 0xfc, 0xe2, 0xd8, 0x49, 0x18, 0x15, 0x14, 0xd6, 0xe5, 0xa7, 0x0e, 0x0a, 0xb8,
	0xb3, 0xa2, 0x38, 0xcb, 0x96, 0xa3, 0x28, 0x56, 0xa7, 0x2a, 0x0e, 0xc3, 0x9c, 0xa6, 0xac, 0x32,
	0x90, 0x0c, 0x60, 0x1d, 0xa8, 0xcf, 0x13, 0xe2, 0xa2, 0x38, 0xa6, 0x02, 0x09, 0x42, 0x63, 0x5e,
	0x9c, 0x16, 0xe1, 0xdd, 0xfc, 0x69, 0x9a, 0xce, 0xdd, 0x39, 0xc1, 0x8b, 0xc0, 0x8f, 0x10, 0xbf,
	0x94, 0x1e, 0xf6, 0x00, 0xdc, 0x19, 0x62, 0x71, 0x5a, 0x44, 0xe8, 0x93, 0x60, 0x54, 0xf0, 0x3d,
	0xfc, 0x3a, 0xc5, 0x5c, 0xc0, 0x7b, 0xe0, 0x96, 0xca, 0xc4, 0x8f, 0x51, 0x84, 0x4d, 0xad, 0xae,
	0x35, 0xf6, 0xbd, 0x9b, 0xea, 0xe5, 0x53, 0x14, 0x61, 0xfb, 0x83, 0x06, 0xee, 0x8e, 0x52, 0x81,
	0x04, 0x2e, 0x21, 0x71, 0x85, 0x3a, 0x04, 0xc6, 0x2c, 0xe5, 0x82, 0x46, 0x98, 0xf9, 0x24, 0x28,
	0x40, 0x40, 0xbd, 0x7a, 0x12, 0xc0, 0x57, 0x00, 0xd0, 0x04, 0x33, 0x59, 0x82, 0xa9, 0xd7, 0x6b,
	0x0d, 0xa3, 0xdd, 0x75, 0xb6, 0xb5, 0xd0, 0x29, 0x89, 0xf9, 0x4c, 0x61, 0xbc, 0x35, 0xa2, 0xfd,
	0x51, 0x07, 0x07, 0x9b, 0x9c, 0xe1, 0x09, 0x30, 0xd2, 0x24, 0x40, 0x02, 0xe7, 0x2d, 0x32, 0xff,
	0xaf, 0x6b, 0x0d, 0xa3, 0x6d, 0xa9, 0x0c, 0x54, 0x17, 0x9d, 0xb3, 0xac, 0x8b, 0x23, 0xc4, 0x2f,
	0x3d, 0x20, 0xdd, 0x33, 0x1b, 0x8e, 0xc1, 0xde, 0x8c, 0x61, 0x24, 0x64, 0x8b, 0x8c, 0xf6, 0x51,
	0x65, 0xe6, 0x2b, 0x69, 0xcb, 0x52, 0x3f, 0xff, 0xcf, 0x2b, 0x38, 0x19, 0x51, 0xf2, 0x4d, 0x7d,
	0x57, 0xa2, 0xe4, 0x40, 0x13, 0xec, 0x31, 0x1c, 0xd1, 0x25, 0x36, 0x6b, 0x59, 0xf7, 0xb3, 0x13,
	0xf9, 0xdc, 0x37, 0xc0, 0xfe, 0xaa, 0x53, 0xf6, 0x1b, 0x0d, 0xd8, 0x9b, 0xf4, 0xe4, 0x09, 0x8d,
	0x39, 0x86, 0x2f, 0xc1, 0x0d, 0x86, 0x79, 0xba, 0x10, 0x4a, 0xac, 0xde, 0x76, 0xb1, 0x2a, 0xb1,
	0x5e, 0x4e, 0xf2, 0x14, 0xd1, 0x3e, 0x03, 0x87, 0x5b, 0x7c, 0xff, 0xea, 0x6e, 0xb6, 0xbf, 0xd7,
	0x80, 0x55, 0x82, 0x78, 0x2e, 0x13, 0x82, 0x5f, 0x34, 0x70, 0xbb, 0x7c, 0x02, 0xe0, 0xe3, 0xed,
	0xd5, 0x6c, 0x9c, 0x1d, 0xeb, 0x1f, 0xf5, 0xb2, 0xbb, 0x6f, 0xbf, 0xfe, 0x78, 0xa7, 0x3f, 0x84,
	0x47, 0xd9, 0x1e, 0xb8, 0xfa, 0xa3, 0xc4, 0x8e, 0x1a, 0x17, 0xee, 0x36, 0x57, 0x8b, 0x61, 0x5d,
	0x1c, 0xb7, 0x79, 0x0d, 0x7f, 0x6a, 0xc0, 0xaa, 0x96, 0x0f, 0x9e, 0xee, 0xa0, 0x92, 0x1a, 0x66,
	0x6b, 0xb0, 0x1b, 0x44, 0xde, 0x20, 0x7b, 0x90, 0x57, 0xda, 0xb5, 0x1f, 0x65, 0x95, 0xfe, 0x2e,
	0xed, 0x6a, 0x6d, 0x4f, 0x74, 0x9a, 0xd7, 0xa5, 0x85, 0x1e, 0x47, 0x39, 0xfe, 0x58, 0x6b, 0xf6,
	0xbf, 0x69, 0xe0, 0xfe, 0x8c, 0x46, 0x5b, 0x33, 0xea, 0x1f, 0x56, 0x5f, 0x84, 0x71, 0x36, 0xdc,
	0x63, 0xed, 0xc5, 0x79, 0x01, 0x09, 0xe9, 0x02, 0xc5, 0xa1, 0x43, 0x59, 0xe8, 0x86, 0x38, 0xce,
	0x47, 0x5f, 0xed, 0xe7, 0x84, 0xf0, 0xea, 0xdf, 0xc2, 0x89, 0x32, 0xde, 0xeb, 0xb5, 0x61, 0xaf,
	0xf7, 0x49, 0xaf, 0x0f, 0x25, 0xb0, 0x17, 0x70, 0x47, 0x9a, 0x99, 0x75, 0xd1, 0x72, 0x8a, 0xc0,
	0xfc, 0xb3, 0x72, 0x99, 0xf4, 0x02, 0x3e, 0x59, 0xb9, 0x4c, 0x2e, 0x5a, 0x13, 0xe5, 0x32, 0xdd,
	0xcb, 0x13, 0x78, 0xf0, 0x2b, 0x00, 0x00, 0xff, 0xff, 0x12, 0xbd, 0x83, 0x1c, 0x96, 0x06, 0x00,
	0x00,
}
