// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v0/enums/campaign_group_status.proto

package enums // import "google.golang.org/genproto/googleapis/ads/googleads/v0/enums"

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// Possible statuses of a CampaignGroup.
type CampaignGroupStatusEnum_CampaignGroupStatus int32

const (
	// Not specified.
	CampaignGroupStatusEnum_UNSPECIFIED CampaignGroupStatusEnum_CampaignGroupStatus = 0
	// Used for return value only. Represents value unknown in this version.
	CampaignGroupStatusEnum_UNKNOWN CampaignGroupStatusEnum_CampaignGroupStatus = 1
	// Campaign group is currently serving ads depending on budget information.
	CampaignGroupStatusEnum_ENABLED CampaignGroupStatusEnum_CampaignGroupStatus = 2
	// Campaign group has been removed.
	CampaignGroupStatusEnum_REMOVED CampaignGroupStatusEnum_CampaignGroupStatus = 4
)

var CampaignGroupStatusEnum_CampaignGroupStatus_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "ENABLED",
	4: "REMOVED",
}
var CampaignGroupStatusEnum_CampaignGroupStatus_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"ENABLED":     2,
	"REMOVED":     4,
}

func (x CampaignGroupStatusEnum_CampaignGroupStatus) String() string {
	return proto.EnumName(CampaignGroupStatusEnum_CampaignGroupStatus_name, int32(x))
}
func (CampaignGroupStatusEnum_CampaignGroupStatus) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_campaign_group_status_0530aace33372d44, []int{0, 0}
}

// Message describing CampaignGroup statuses.
type CampaignGroupStatusEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CampaignGroupStatusEnum) Reset()         { *m = CampaignGroupStatusEnum{} }
func (m *CampaignGroupStatusEnum) String() string { return proto.CompactTextString(m) }
func (*CampaignGroupStatusEnum) ProtoMessage()    {}
func (*CampaignGroupStatusEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_campaign_group_status_0530aace33372d44, []int{0}
}
func (m *CampaignGroupStatusEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CampaignGroupStatusEnum.Unmarshal(m, b)
}
func (m *CampaignGroupStatusEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CampaignGroupStatusEnum.Marshal(b, m, deterministic)
}
func (dst *CampaignGroupStatusEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CampaignGroupStatusEnum.Merge(dst, src)
}
func (m *CampaignGroupStatusEnum) XXX_Size() int {
	return xxx_messageInfo_CampaignGroupStatusEnum.Size(m)
}
func (m *CampaignGroupStatusEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_CampaignGroupStatusEnum.DiscardUnknown(m)
}

var xxx_messageInfo_CampaignGroupStatusEnum proto.InternalMessageInfo

func init() {
	proto.RegisterType((*CampaignGroupStatusEnum)(nil), "google.ads.googleads.v0.enums.CampaignGroupStatusEnum")
	proto.RegisterEnum("google.ads.googleads.v0.enums.CampaignGroupStatusEnum_CampaignGroupStatus", CampaignGroupStatusEnum_CampaignGroupStatus_name, CampaignGroupStatusEnum_CampaignGroupStatus_value)
}

func init() {
	proto.RegisterFile("google/ads/googleads/v0/enums/campaign_group_status.proto", fileDescriptor_campaign_group_status_0530aace33372d44)
}

var fileDescriptor_campaign_group_status_0530aace33372d44 = []byte{
	// 267 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xe2, 0xb2, 0x4c, 0xcf, 0xcf, 0x4f,
	0xcf, 0x49, 0xd5, 0x4f, 0x4c, 0x29, 0xd6, 0x87, 0x30, 0x41, 0xac, 0x32, 0x03, 0xfd, 0xd4, 0xbc,
	0xd2, 0xdc, 0x62, 0xfd, 0xe4, 0xc4, 0xdc, 0x82, 0xc4, 0xcc, 0xf4, 0xbc, 0xf8, 0xf4, 0xa2, 0xfc,
	0xd2, 0x82, 0xf8, 0xe2, 0x92, 0xc4, 0x92, 0xd2, 0x62, 0xbd, 0x82, 0xa2, 0xfc, 0x92, 0x7c, 0x21,
	0x59, 0x88, 0x7a, 0xbd, 0xc4, 0x94, 0x62, 0x3d, 0xb8, 0x56, 0xbd, 0x32, 0x03, 0x3d, 0xb0, 0x56,
	0xa5, 0x0c, 0x2e, 0x71, 0x67, 0xa8, 0x6e, 0x77, 0x90, 0xe6, 0x60, 0xb0, 0x5e, 0xd7, 0xbc, 0xd2,
	0x5c, 0x25, 0x5f, 0x2e, 0x61, 0x2c, 0x52, 0x42, 0xfc, 0x5c, 0xdc, 0xa1, 0x7e, 0xc1, 0x01, 0xae,
	0xce, 0x9e, 0x6e, 0x9e, 0xae, 0x2e, 0x02, 0x0c, 0x42, 0xdc, 0x5c, 0xec, 0xa1, 0x7e, 0xde, 0x7e,
	0xfe, 0xe1, 0x7e, 0x02, 0x8c, 0x20, 0x8e, 0xab, 0x9f, 0xa3, 0x93, 0x8f, 0xab, 0x8b, 0x00, 0x13,
	0x88, 0x13, 0xe4, 0xea, 0xeb, 0x1f, 0xe6, 0xea, 0x22, 0xc0, 0xe2, 0x74, 0x92, 0x91, 0x4b, 0x31,
	0x39, 0x3f, 0x57, 0x0f, 0xaf, 0x7b, 0x9c, 0x24, 0xb0, 0x58, 0x19, 0x00, 0xf2, 0x48, 0x00, 0x63,
	0x94, 0x13, 0x54, 0x6b, 0x7a, 0x7e, 0x4e, 0x62, 0x5e, 0xba, 0x5e, 0x7e, 0x51, 0xba, 0x7e, 0x7a,
	0x6a, 0x1e, 0xd8, 0x9b, 0xb0, 0x50, 0x29, 0xc8, 0x2c, 0xc6, 0x11, 0x48, 0xd6, 0x60, 0x72, 0x11,
	0x13, 0xb3, 0xbb, 0xa3, 0xe3, 0x2a, 0x26, 0x59, 0x77, 0x88, 0x51, 0x8e, 0x29, 0xc5, 0x7a, 0x10,
	0x26, 0x88, 0x15, 0x66, 0xa0, 0x07, 0xf2, 0x79, 0xf1, 0x29, 0x98, 0x7c, 0x8c, 0x63, 0x4a, 0x71,
	0x0c, 0x5c, 0x3e, 0x26, 0xcc, 0x20, 0x06, 0x2c, 0x9f, 0xc4, 0x06, 0xb6, 0xd4, 0x18, 0x10, 0x00,
	0x00, 0xff, 0xff, 0x2f, 0xcf, 0x77, 0xdc, 0x98, 0x01, 0x00, 0x00,
}
