// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v0/enums/product_type_level.proto

package enums // import "google.golang.org/genproto/googleapis/ads/googleads/v0/enums"

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// Enum describing the level of the type of a product offer.
type ProductTypeLevelEnum_ProductTypeLevel int32

const (
	// Not specified.
	ProductTypeLevelEnum_UNSPECIFIED ProductTypeLevelEnum_ProductTypeLevel = 0
	// Used for return value only. Represents value unknown in this version.
	ProductTypeLevelEnum_UNKNOWN ProductTypeLevelEnum_ProductTypeLevel = 1
	// Level 1.
	ProductTypeLevelEnum_PRODUCT_TYPE_L1 ProductTypeLevelEnum_ProductTypeLevel = 2
	// Level 2.
	ProductTypeLevelEnum_PRODUCT_TYPE_L2 ProductTypeLevelEnum_ProductTypeLevel = 3
	// Level 3.
	ProductTypeLevelEnum_PRODUCT_TYPE_L3 ProductTypeLevelEnum_ProductTypeLevel = 4
	// Level 4.
	ProductTypeLevelEnum_PRODUCT_TYPE_L4 ProductTypeLevelEnum_ProductTypeLevel = 5
	// Level 5.
	ProductTypeLevelEnum_PRODUCT_TYPE_L5 ProductTypeLevelEnum_ProductTypeLevel = 6
)

var ProductTypeLevelEnum_ProductTypeLevel_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "PRODUCT_TYPE_L1",
	3: "PRODUCT_TYPE_L2",
	4: "PRODUCT_TYPE_L3",
	5: "PRODUCT_TYPE_L4",
	6: "PRODUCT_TYPE_L5",
}
var ProductTypeLevelEnum_ProductTypeLevel_value = map[string]int32{
	"UNSPECIFIED":     0,
	"UNKNOWN":         1,
	"PRODUCT_TYPE_L1": 2,
	"PRODUCT_TYPE_L2": 3,
	"PRODUCT_TYPE_L3": 4,
	"PRODUCT_TYPE_L4": 5,
	"PRODUCT_TYPE_L5": 6,
}

func (x ProductTypeLevelEnum_ProductTypeLevel) String() string {
	return proto.EnumName(ProductTypeLevelEnum_ProductTypeLevel_name, int32(x))
}
func (ProductTypeLevelEnum_ProductTypeLevel) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_product_type_level_e9b6c5214d538040, []int{0, 0}
}

// Level of the type of a product offer.
type ProductTypeLevelEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ProductTypeLevelEnum) Reset()         { *m = ProductTypeLevelEnum{} }
func (m *ProductTypeLevelEnum) String() string { return proto.CompactTextString(m) }
func (*ProductTypeLevelEnum) ProtoMessage()    {}
func (*ProductTypeLevelEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_product_type_level_e9b6c5214d538040, []int{0}
}
func (m *ProductTypeLevelEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ProductTypeLevelEnum.Unmarshal(m, b)
}
func (m *ProductTypeLevelEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ProductTypeLevelEnum.Marshal(b, m, deterministic)
}
func (dst *ProductTypeLevelEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ProductTypeLevelEnum.Merge(dst, src)
}
func (m *ProductTypeLevelEnum) XXX_Size() int {
	return xxx_messageInfo_ProductTypeLevelEnum.Size(m)
}
func (m *ProductTypeLevelEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_ProductTypeLevelEnum.DiscardUnknown(m)
}

var xxx_messageInfo_ProductTypeLevelEnum proto.InternalMessageInfo

func init() {
	proto.RegisterType((*ProductTypeLevelEnum)(nil), "google.ads.googleads.v0.enums.ProductTypeLevelEnum")
	proto.RegisterEnum("google.ads.googleads.v0.enums.ProductTypeLevelEnum_ProductTypeLevel", ProductTypeLevelEnum_ProductTypeLevel_name, ProductTypeLevelEnum_ProductTypeLevel_value)
}

func init() {
	proto.RegisterFile("google/ads/googleads/v0/enums/product_type_level.proto", fileDescriptor_product_type_level_e9b6c5214d538040)
}

var fileDescriptor_product_type_level_e9b6c5214d538040 = []byte{
	// 287 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xe2, 0x32, 0x4b, 0xcf, 0xcf, 0x4f,
	0xcf, 0x49, 0xd5, 0x4f, 0x4c, 0x29, 0xd6, 0x87, 0x30, 0x41, 0xac, 0x32, 0x03, 0xfd, 0xd4, 0xbc,
	0xd2, 0xdc, 0x62, 0xfd, 0x82, 0xa2, 0xfc, 0x94, 0xd2, 0xe4, 0x92, 0xf8, 0x92, 0xca, 0x82, 0xd4,
	0xf8, 0x9c, 0xd4, 0xb2, 0xd4, 0x1c, 0xbd, 0x82, 0xa2, 0xfc, 0x92, 0x7c, 0x21, 0x59, 0x88, 0x62,
	0xbd, 0xc4, 0x94, 0x62, 0x3d, 0xb8, 0x3e, 0xbd, 0x32, 0x03, 0x3d, 0xb0, 0x3e, 0xa5, 0x4d, 0x8c,
	0x5c, 0x22, 0x01, 0x10, 0xbd, 0x21, 0x95, 0x05, 0xa9, 0x3e, 0x20, 0x9d, 0xae, 0x79, 0xa5, 0xb9,
	0x4a, 0x33, 0x19, 0xb9, 0x04, 0xd0, 0x25, 0x84, 0xf8, 0xb9, 0xb8, 0x43, 0xfd, 0x82, 0x03, 0x5c,
	0x9d, 0x3d, 0xdd, 0x3c, 0x5d, 0x5d, 0x04, 0x18, 0x84, 0xb8, 0xb9, 0xd8, 0x43, 0xfd, 0xbc, 0xfd,
	0xfc, 0xc3, 0xfd, 0x04, 0x18, 0x85, 0x84, 0xb9, 0xf8, 0x03, 0x82, 0xfc, 0x5d, 0x42, 0x9d, 0x43,
	0xe2, 0x43, 0x22, 0x03, 0x5c, 0xe3, 0x7d, 0x0c, 0x05, 0x98, 0x30, 0x05, 0x8d, 0x04, 0x98, 0x31,
	0x05, 0x8d, 0x05, 0x58, 0x30, 0x05, 0x4d, 0x04, 0x58, 0x31, 0x05, 0x4d, 0x05, 0xd8, 0x9c, 0x8e,
	0x31, 0x72, 0x29, 0x26, 0xe7, 0xe7, 0xea, 0xe1, 0xf5, 0x9a, 0x93, 0x28, 0xba, 0xf3, 0x03, 0x40,
	0x01, 0x12, 0xc0, 0x18, 0xe5, 0x04, 0xd5, 0x97, 0x9e, 0x9f, 0x93, 0x98, 0x97, 0xae, 0x97, 0x5f,
	0x94, 0xae, 0x9f, 0x9e, 0x9a, 0x07, 0x0e, 0x2e, 0x58, 0xd0, 0x16, 0x64, 0x16, 0xe3, 0x08, 0x69,
	0x6b, 0x30, 0xb9, 0x88, 0x89, 0xd9, 0xdd, 0xd1, 0x71, 0x15, 0x93, 0xac, 0x3b, 0xc4, 0x28, 0xc7,
	0x94, 0x62, 0x3d, 0x08, 0x13, 0xc4, 0x0a, 0x33, 0xd0, 0x03, 0x85, 0x61, 0xf1, 0x29, 0x98, 0x7c,
	0x8c, 0x63, 0x4a, 0x71, 0x0c, 0x5c, 0x3e, 0x26, 0xcc, 0x20, 0x06, 0x2c, 0x9f, 0xc4, 0x06, 0xb6,
	0xd4, 0x18, 0x10, 0x00, 0x00, 0xff, 0xff, 0xae, 0x5a, 0x72, 0x1e, 0xdd, 0x01, 0x00, 0x00,
}
