// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/automl/v1beta1/prediction_service.proto

package automl // import "google.golang.org/genproto/googleapis/cloud/automl/v1beta1"

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"
import _ "google.golang.org/genproto/googleapis/api/annotations"

import (
	context "golang.org/x/net/context"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// Request message for [PredictionService.Predict][google.cloud.automl.v1beta1.PredictionService.Predict].
type PredictRequest struct {
	// Name of the model requested to serve the prediction.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Required.
	// Payload to perform a prediction on. The payload must match the
	// problem type that the model was trained to solve.
	Payload *ExamplePayload `protobuf:"bytes,2,opt,name=payload,proto3" json:"payload,omitempty"`
	// Additional domain-specific parameters, any string must be up to 25000
	// characters long.
	//
	// *  For Image Classification:
	//
	//    `score_threshold` - (float) A value from 0.0 to 1.0. When the model
	//     makes predictions for an
	//     image, it will only produce results that have at least this confidence
	//     score threshold. The default is 0.5.
	Params               map[string]string `protobuf:"bytes,3,rep,name=params,proto3" json:"params,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
	XXX_NoUnkeyedLiteral struct{}          `json:"-"`
	XXX_unrecognized     []byte            `json:"-"`
	XXX_sizecache        int32             `json:"-"`
}

func (m *PredictRequest) Reset()         { *m = PredictRequest{} }
func (m *PredictRequest) String() string { return proto.CompactTextString(m) }
func (*PredictRequest) ProtoMessage()    {}
func (*PredictRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_prediction_service_21460c7fedea4ded, []int{0}
}
func (m *PredictRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_PredictRequest.Unmarshal(m, b)
}
func (m *PredictRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_PredictRequest.Marshal(b, m, deterministic)
}
func (dst *PredictRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_PredictRequest.Merge(dst, src)
}
func (m *PredictRequest) XXX_Size() int {
	return xxx_messageInfo_PredictRequest.Size(m)
}
func (m *PredictRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_PredictRequest.DiscardUnknown(m)
}

var xxx_messageInfo_PredictRequest proto.InternalMessageInfo

func (m *PredictRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *PredictRequest) GetPayload() *ExamplePayload {
	if m != nil {
		return m.Payload
	}
	return nil
}

func (m *PredictRequest) GetParams() map[string]string {
	if m != nil {
		return m.Params
	}
	return nil
}

// Response message for [PredictionService.Predict][google.cloud.automl.v1beta1.PredictionService.Predict].
//
// Currently, this is only
// used to return an image recognition prediction result. More prediction
// output metadata might be introduced in the future.
type PredictResponse struct {
	// Prediction result.
	Payload []*AnnotationPayload `protobuf:"bytes,1,rep,name=payload,proto3" json:"payload,omitempty"`
	// Additional domain-specific prediction response metadata.
	Metadata             map[string]string `protobuf:"bytes,2,rep,name=metadata,proto3" json:"metadata,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
	XXX_NoUnkeyedLiteral struct{}          `json:"-"`
	XXX_unrecognized     []byte            `json:"-"`
	XXX_sizecache        int32             `json:"-"`
}

func (m *PredictResponse) Reset()         { *m = PredictResponse{} }
func (m *PredictResponse) String() string { return proto.CompactTextString(m) }
func (*PredictResponse) ProtoMessage()    {}
func (*PredictResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_prediction_service_21460c7fedea4ded, []int{1}
}
func (m *PredictResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_PredictResponse.Unmarshal(m, b)
}
func (m *PredictResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_PredictResponse.Marshal(b, m, deterministic)
}
func (dst *PredictResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_PredictResponse.Merge(dst, src)
}
func (m *PredictResponse) XXX_Size() int {
	return xxx_messageInfo_PredictResponse.Size(m)
}
func (m *PredictResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_PredictResponse.DiscardUnknown(m)
}

var xxx_messageInfo_PredictResponse proto.InternalMessageInfo

func (m *PredictResponse) GetPayload() []*AnnotationPayload {
	if m != nil {
		return m.Payload
	}
	return nil
}

func (m *PredictResponse) GetMetadata() map[string]string {
	if m != nil {
		return m.Metadata
	}
	return nil
}

func init() {
	proto.RegisterType((*PredictRequest)(nil), "google.cloud.automl.v1beta1.PredictRequest")
	proto.RegisterMapType((map[string]string)(nil), "google.cloud.automl.v1beta1.PredictRequest.ParamsEntry")
	proto.RegisterType((*PredictResponse)(nil), "google.cloud.automl.v1beta1.PredictResponse")
	proto.RegisterMapType((map[string]string)(nil), "google.cloud.automl.v1beta1.PredictResponse.MetadataEntry")
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// PredictionServiceClient is the client API for PredictionService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type PredictionServiceClient interface {
	// Perform a prediction.
	Predict(ctx context.Context, in *PredictRequest, opts ...grpc.CallOption) (*PredictResponse, error)
}

type predictionServiceClient struct {
	cc *grpc.ClientConn
}

func NewPredictionServiceClient(cc *grpc.ClientConn) PredictionServiceClient {
	return &predictionServiceClient{cc}
}

func (c *predictionServiceClient) Predict(ctx context.Context, in *PredictRequest, opts ...grpc.CallOption) (*PredictResponse, error) {
	out := new(PredictResponse)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.PredictionService/Predict", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// PredictionServiceServer is the server API for PredictionService service.
type PredictionServiceServer interface {
	// Perform a prediction.
	Predict(context.Context, *PredictRequest) (*PredictResponse, error)
}

func RegisterPredictionServiceServer(s *grpc.Server, srv PredictionServiceServer) {
	s.RegisterService(&_PredictionService_serviceDesc, srv)
}

func _PredictionService_Predict_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(PredictRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(PredictionServiceServer).Predict(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.PredictionService/Predict",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(PredictionServiceServer).Predict(ctx, req.(*PredictRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _PredictionService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.cloud.automl.v1beta1.PredictionService",
	HandlerType: (*PredictionServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Predict",
			Handler:    _PredictionService_Predict_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/cloud/automl/v1beta1/prediction_service.proto",
}

func init() {
	proto.RegisterFile("google/cloud/automl/v1beta1/prediction_service.proto", fileDescriptor_prediction_service_21460c7fedea4ded)
}

var fileDescriptor_prediction_service_21460c7fedea4ded = []byte{
	// 486 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x94, 0x93, 0xdf, 0x8a, 0xd3, 0x40,
	0x14, 0xc6, 0x99, 0x54, 0x77, 0xdd, 0x29, 0xfe, 0x1b, 0x44, 0x4a, 0x56, 0xb0, 0xf4, 0xaa, 0x74,
	0x97, 0x19, 0xb6, 0x0a, 0xab, 0x5d, 0xbd, 0x68, 0xa5, 0xe8, 0xcd, 0x62, 0x88, 0xb0, 0x17, 0x52,
	0x28, 0xb3, 0xc9, 0x10, 0xa2, 0x93, 0x9c, 0x98, 0x99, 0x14, 0x8b, 0x78, 0xe3, 0x2b, 0x78, 0xeb,
	0x03, 0xf8, 0x14, 0x3e, 0x80, 0xb7, 0xbe, 0x82, 0x0f, 0xe0, 0x9d, 0xb7, 0x92, 0x99, 0x31, 0xeb,
	0xb2, 0x12, 0xb6, 0x77, 0x49, 0xe6, 0xfc, 0xbe, 0xf3, 0x7d, 0x99, 0x73, 0xf0, 0xc3, 0x04, 0x20,
	0x91, 0x82, 0x45, 0x12, 0xaa, 0x98, 0xf1, 0x4a, 0x43, 0x26, 0xd9, 0xea, 0xe0, 0x54, 0x68, 0x7e,
	0xc0, 0x8a, 0x52, 0xc4, 0x69, 0xa4, 0x53, 0xc8, 0x97, 0x4a, 0x94, 0xab, 0x34, 0x12, 0xb4, 0x28,
	0x41, 0x03, 0xd9, 0xb5, 0x14, 0x35, 0x14, 0xb5, 0x14, 0x75, 0x94, 0x7f, 0xcf, 0x49, 0xf2, 0x22,
	0x65, 0x3c, 0xcf, 0x41, 0xf3, 0x5a, 0x41, 0x59, 0xd4, 0x6f, 0x6d, 0x78, 0x56, 0xbe, 0x2c, 0xf8,
	0x5a, 0x02, 0x8f, 0x1d, 0xb5, 0xdf, 0x46, 0xc5, 0x5c, 0xf3, 0x65, 0xaa, 0x45, 0xe6, 0x7a, 0x0c,
	0x7e, 0x23, 0x7c, 0x23, 0xb0, 0xde, 0x43, 0xf1, 0xae, 0x12, 0x4a, 0x13, 0x82, 0xaf, 0xe4, 0x3c,
	0x13, 0x3d, 0xd4, 0x47, 0xc3, 0x9d, 0xd0, 0x3c, 0x93, 0x39, 0xde, 0x76, 0x5d, 0x7a, 0x5e, 0x1f,
	0x0d, 0xbb, 0xe3, 0x3d, 0xda, 0x92, 0x8b, 0xce, 0xdf, 0xf3, 0xac, 0x90, 0x22, 0xb0, 0x48, 0xf8,
	0x97, 0x25, 0x2f, 0xf1, 0x56, 0xc1, 0x4b, 0x9e, 0xa9, 0x5e, 0xa7, 0xdf, 0x19, 0x76, 0xc7, 0x87,
	0xad, 0x2a, 0xe7, 0x7d, 0xd1, 0xc0, 0x90, 0xf3, 0x5c, 0x97, 0xeb, 0xd0, 0xc9, 0xf8, 0x8f, 0x71,
	0xf7, 0x9f, 0xcf, 0xe4, 0x16, 0xee, 0xbc, 0x15, 0x6b, 0xe7, 0xbc, 0x7e, 0x24, 0x77, 0xf0, 0xd5,
	0x15, 0x97, 0x95, 0x30, 0xb6, 0x77, 0x42, 0xfb, 0x32, 0xf1, 0x1e, 0xa1, 0xc1, 0x2f, 0x84, 0x6f,
	0x36, 0x1d, 0x54, 0x01, 0xb9, 0x12, 0xe4, 0xc5, 0x59, 0x4c, 0x64, 0x0c, 0xd2, 0x56, 0x83, 0xd3,
	0xe6, 0x0e, 0x2e, 0x24, 0x3d, 0xc1, 0xd7, 0x32, 0xa1, 0x79, 0xfd, 0xbf, 0x7b, 0x9e, 0x91, 0x9a,
	0x5c, 0x2e, 0xab, 0x75, 0x42, 0x8f, 0x1d, 0x6c, 0xe3, 0x36, 0x5a, 0xfe, 0x11, 0xbe, 0x7e, 0xee,
	0x68, 0x93, 0xc8, 0xe3, 0x6f, 0x08, 0xdf, 0x0e, 0x9a, 0x41, 0x7d, 0x65, 0xe7, 0x94, 0x7c, 0x45,
	0x78, 0xdb, 0x7d, 0x25, 0x7b, 0x1b, 0x5c, 0x88, 0xbf, 0xbf, 0x49, 0xa2, 0xc1, 0xec, 0xd3, 0x8f,
	0x9f, 0x9f, 0xbd, 0x27, 0x83, 0xc3, 0x66, 0x18, 0x3f, 0xd4, 0xa3, 0xf5, 0xb4, 0x28, 0xe1, 0x8d,
	0x88, 0xb4, 0x62, 0x23, 0x26, 0x21, 0xb2, 0x0b, 0xc0, 0x46, 0x2c, 0x83, 0x58, 0x48, 0xc5, 0x46,
	0x1f, 0x27, 0x6e, 0xb5, 0x26, 0x68, 0x34, 0xfb, 0x82, 0xf0, 0xfd, 0x08, 0xb2, 0xb6, 0xbe, 0xb3,
	0xbb, 0x17, 0x12, 0x06, 0xf5, 0xa4, 0x07, 0xe8, 0xf5, 0xd4, 0x61, 0x09, 0x48, 0x9e, 0x27, 0x14,
	0xca, 0x84, 0x25, 0x22, 0x37, 0x7b, 0xc0, 0xec, 0x11, 0x2f, 0x52, 0xf5, 0xdf, 0xc5, 0x39, 0xb2,
	0xaf, 0xdf, 0xbd, 0xdd, 0xe7, 0xa6, 0x70, 0xf1, 0xac, 0x2e, 0x5a, 0x4c, 0x2b, 0x0d, 0xc7, 0x72,
	0x71, 0x62, 0x8b, 0x4e, 0xb7, 0x8c, 0xd6, 0x83, 0x3f, 0x01, 0x00, 0x00, 0xff, 0xff, 0x55, 0x88,
	0x1b, 0x5d, 0x2a, 0x04, 0x00, 0x00,
}
