// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/devtools/resultstore/v2/resultstore_download.proto

package resultstore // import "google.golang.org/genproto/googleapis/devtools/resultstore/v2"

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"
import _ "google.golang.org/genproto/googleapis/api/annotations"

import (
	context "golang.org/x/net/context"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// Request passed into GetInvocation
type GetInvocationRequest struct {
	// The name of the invocation to retrieve. It must match this format:
	// invocations/${INVOCATION_ID}
	// where INVOCATION_ID must be an RFC 4122-compliant random UUID.
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetInvocationRequest) Reset()         { *m = GetInvocationRequest{} }
func (m *GetInvocationRequest) String() string { return proto.CompactTextString(m) }
func (*GetInvocationRequest) ProtoMessage()    {}
func (*GetInvocationRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_resultstore_download_b0d8e6d616eef8f3, []int{0}
}
func (m *GetInvocationRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetInvocationRequest.Unmarshal(m, b)
}
func (m *GetInvocationRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetInvocationRequest.Marshal(b, m, deterministic)
}
func (dst *GetInvocationRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetInvocationRequest.Merge(dst, src)
}
func (m *GetInvocationRequest) XXX_Size() int {
	return xxx_messageInfo_GetInvocationRequest.Size(m)
}
func (m *GetInvocationRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetInvocationRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetInvocationRequest proto.InternalMessageInfo

func (m *GetInvocationRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// Request passed into SearchInvocations
type SearchInvocationsRequest struct {
	// The maximum number of items to return. Zero means all, but may be capped by
	// the server.
	PageSize int32 `protobuf:"varint,1,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Options for pagination.
	//
	// Types that are valid to be assigned to PageStart:
	//	*SearchInvocationsRequest_PageToken
	//	*SearchInvocationsRequest_Offset
	PageStart isSearchInvocationsRequest_PageStart `protobuf_oneof:"page_start"`
	// A filtering query string.
	Query string `protobuf:"bytes,4,opt,name=query,proto3" json:"query,omitempty"`
	// The project id to search under.
	ProjectId            string   `protobuf:"bytes,5,opt,name=project_id,json=projectId,proto3" json:"project_id,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *SearchInvocationsRequest) Reset()         { *m = SearchInvocationsRequest{} }
func (m *SearchInvocationsRequest) String() string { return proto.CompactTextString(m) }
func (*SearchInvocationsRequest) ProtoMessage()    {}
func (*SearchInvocationsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_resultstore_download_b0d8e6d616eef8f3, []int{1}
}
func (m *SearchInvocationsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SearchInvocationsRequest.Unmarshal(m, b)
}
func (m *SearchInvocationsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SearchInvocationsRequest.Marshal(b, m, deterministic)
}
func (dst *SearchInvocationsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SearchInvocationsRequest.Merge(dst, src)
}
func (m *SearchInvocationsRequest) XXX_Size() int {
	return xxx_messageInfo_SearchInvocationsRequest.Size(m)
}
func (m *SearchInvocationsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_SearchInvocationsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_SearchInvocationsRequest proto.InternalMessageInfo

func (m *SearchInvocationsRequest) GetPageSize() int32 {
	if m != nil {
		return m.PageSize
	}
	return 0
}

type isSearchInvocationsRequest_PageStart interface {
	isSearchInvocationsRequest_PageStart()
}

type SearchInvocationsRequest_PageToken struct {
	PageToken string `protobuf:"bytes,2,opt,name=page_token,json=pageToken,proto3,oneof"`
}

type SearchInvocationsRequest_Offset struct {
	Offset int64 `protobuf:"varint,3,opt,name=offset,proto3,oneof"`
}

func (*SearchInvocationsRequest_PageToken) isSearchInvocationsRequest_PageStart() {}

func (*SearchInvocationsRequest_Offset) isSearchInvocationsRequest_PageStart() {}

func (m *SearchInvocationsRequest) GetPageStart() isSearchInvocationsRequest_PageStart {
	if m != nil {
		return m.PageStart
	}
	return nil
}

func (m *SearchInvocationsRequest) GetPageToken() string {
	if x, ok := m.GetPageStart().(*SearchInvocationsRequest_PageToken); ok {
		return x.PageToken
	}
	return ""
}

func (m *SearchInvocationsRequest) GetOffset() int64 {
	if x, ok := m.GetPageStart().(*SearchInvocationsRequest_Offset); ok {
		return x.Offset
	}
	return 0
}

func (m *SearchInvocationsRequest) GetQuery() string {
	if m != nil {
		return m.Query
	}
	return ""
}

func (m *SearchInvocationsRequest) GetProjectId() string {
	if m != nil {
		return m.ProjectId
	}
	return ""
}

// XXX_OneofFuncs is for the internal use of the proto package.
func (*SearchInvocationsRequest) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, func(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error), func(msg proto.Message) (n int), []interface{}) {
	return _SearchInvocationsRequest_OneofMarshaler, _SearchInvocationsRequest_OneofUnmarshaler, _SearchInvocationsRequest_OneofSizer, []interface{}{
		(*SearchInvocationsRequest_PageToken)(nil),
		(*SearchInvocationsRequest_Offset)(nil),
	}
}

func _SearchInvocationsRequest_OneofMarshaler(msg proto.Message, b *proto.Buffer) error {
	m := msg.(*SearchInvocationsRequest)
	// page_start
	switch x := m.PageStart.(type) {
	case *SearchInvocationsRequest_PageToken:
		b.EncodeVarint(2<<3 | proto.WireBytes)
		b.EncodeStringBytes(x.PageToken)
	case *SearchInvocationsRequest_Offset:
		b.EncodeVarint(3<<3 | proto.WireVarint)
		b.EncodeVarint(uint64(x.Offset))
	case nil:
	default:
		return fmt.Errorf("SearchInvocationsRequest.PageStart has unexpected type %T", x)
	}
	return nil
}

func _SearchInvocationsRequest_OneofUnmarshaler(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error) {
	m := msg.(*SearchInvocationsRequest)
	switch tag {
	case 2: // page_start.page_token
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		x, err := b.DecodeStringBytes()
		m.PageStart = &SearchInvocationsRequest_PageToken{x}
		return true, err
	case 3: // page_start.offset
		if wire != proto.WireVarint {
			return true, proto.ErrInternalBadWireType
		}
		x, err := b.DecodeVarint()
		m.PageStart = &SearchInvocationsRequest_Offset{int64(x)}
		return true, err
	default:
		return false, nil
	}
}

func _SearchInvocationsRequest_OneofSizer(msg proto.Message) (n int) {
	m := msg.(*SearchInvocationsRequest)
	// page_start
	switch x := m.PageStart.(type) {
	case *SearchInvocationsRequest_PageToken:
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(len(x.PageToken)))
		n += len(x.PageToken)
	case *SearchInvocationsRequest_Offset:
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(x.Offset))
	case nil:
	default:
		panic(fmt.Sprintf("proto: unexpected type %T in oneof", x))
	}
	return n
}

// Response from calling SearchInvocations
type SearchInvocationsResponse struct {
	// Invocations matching the search, possibly capped at request.page_size or a
	// server limit.
	Invocations []*Invocation `protobuf:"bytes,1,rep,name=invocations,proto3" json:"invocations,omitempty"`
	// Token to retrieve the next page of results, or empty if there are no
	// more results.
	NextPageToken        string   `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *SearchInvocationsResponse) Reset()         { *m = SearchInvocationsResponse{} }
func (m *SearchInvocationsResponse) String() string { return proto.CompactTextString(m) }
func (*SearchInvocationsResponse) ProtoMessage()    {}
func (*SearchInvocationsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_resultstore_download_b0d8e6d616eef8f3, []int{2}
}
func (m *SearchInvocationsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SearchInvocationsResponse.Unmarshal(m, b)
}
func (m *SearchInvocationsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SearchInvocationsResponse.Marshal(b, m, deterministic)
}
func (dst *SearchInvocationsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SearchInvocationsResponse.Merge(dst, src)
}
func (m *SearchInvocationsResponse) XXX_Size() int {
	return xxx_messageInfo_SearchInvocationsResponse.Size(m)
}
func (m *SearchInvocationsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_SearchInvocationsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_SearchInvocationsResponse proto.InternalMessageInfo

func (m *SearchInvocationsResponse) GetInvocations() []*Invocation {
	if m != nil {
		return m.Invocations
	}
	return nil
}

func (m *SearchInvocationsResponse) GetNextPageToken() string {
	if m != nil {
		return m.NextPageToken
	}
	return ""
}

// Request passed into GetConfiguration
type GetConfigurationRequest struct {
	// The name of the configuration to retrieve. It must match this format:
	// invocations/${INVOCATION_ID}/configs/${CONFIGURATION_ID}
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetConfigurationRequest) Reset()         { *m = GetConfigurationRequest{} }
func (m *GetConfigurationRequest) String() string { return proto.CompactTextString(m) }
func (*GetConfigurationRequest) ProtoMessage()    {}
func (*GetConfigurationRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_resultstore_download_b0d8e6d616eef8f3, []int{3}
}
func (m *GetConfigurationRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetConfigurationRequest.Unmarshal(m, b)
}
func (m *GetConfigurationRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetConfigurationRequest.Marshal(b, m, deterministic)
}
func (dst *GetConfigurationRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetConfigurationRequest.Merge(dst, src)
}
func (m *GetConfigurationRequest) XXX_Size() int {
	return xxx_messageInfo_GetConfigurationRequest.Size(m)
}
func (m *GetConfigurationRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetConfigurationRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetConfigurationRequest proto.InternalMessageInfo

func (m *GetConfigurationRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// Request passed into ListConfigurations
type ListConfigurationsRequest struct {
	// The invocation name of the configurations to retrieve.
	// It must match this format: invocations/${INVOCATION_ID}
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// The maximum number of items to return.
	// Zero means all, but may be capped by the server.
	PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Options for pagination.
	//
	// Types that are valid to be assigned to PageStart:
	//	*ListConfigurationsRequest_PageToken
	//	*ListConfigurationsRequest_Offset
	PageStart            isListConfigurationsRequest_PageStart `protobuf_oneof:"page_start"`
	XXX_NoUnkeyedLiteral struct{}                              `json:"-"`
	XXX_unrecognized     []byte                                `json:"-"`
	XXX_sizecache        int32                                 `json:"-"`
}

func (m *ListConfigurationsRequest) Reset()         { *m = ListConfigurationsRequest{} }
func (m *ListConfigurationsRequest) String() string { return proto.CompactTextString(m) }
func (*ListConfigurationsRequest) ProtoMessage()    {}
func (*ListConfigurationsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_resultstore_download_b0d8e6d616eef8f3, []int{4}
}
func (m *ListConfigurationsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListConfigurationsRequest.Unmarshal(m, b)
}
func (m *ListConfigurationsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListConfigurationsRequest.Marshal(b, m, deterministic)
}
func (dst *ListConfigurationsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListConfigurationsRequest.Merge(dst, src)
}
func (m *ListConfigurationsRequest) XXX_Size() int {
	return xxx_messageInfo_ListConfigurationsRequest.Size(m)
}
func (m *ListConfigurationsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ListConfigurationsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ListConfigurationsRequest proto.InternalMessageInfo

func (m *ListConfigurationsRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *ListConfigurationsRequest) GetPageSize() int32 {
	if m != nil {
		return m.PageSize
	}
	return 0
}

type isListConfigurationsRequest_PageStart interface {
	isListConfigurationsRequest_PageStart()
}

type ListConfigurationsRequest_PageToken struct {
	PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3,oneof"`
}

type ListConfigurationsRequest_Offset struct {
	Offset int64 `protobuf:"varint,4,opt,name=offset,proto3,oneof"`
}

func (*ListConfigurationsRequest_PageToken) isListConfigurationsRequest_PageStart() {}

func (*ListConfigurationsRequest_Offset) isListConfigurationsRequest_PageStart() {}

func (m *ListConfigurationsRequest) GetPageStart() isListConfigurationsRequest_PageStart {
	if m != nil {
		return m.PageStart
	}
	return nil
}

func (m *ListConfigurationsRequest) GetPageToken() string {
	if x, ok := m.GetPageStart().(*ListConfigurationsRequest_PageToken); ok {
		return x.PageToken
	}
	return ""
}

func (m *ListConfigurationsRequest) GetOffset() int64 {
	if x, ok := m.GetPageStart().(*ListConfigurationsRequest_Offset); ok {
		return x.Offset
	}
	return 0
}

// XXX_OneofFuncs is for the internal use of the proto package.
func (*ListConfigurationsRequest) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, func(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error), func(msg proto.Message) (n int), []interface{}) {
	return _ListConfigurationsRequest_OneofMarshaler, _ListConfigurationsRequest_OneofUnmarshaler, _ListConfigurationsRequest_OneofSizer, []interface{}{
		(*ListConfigurationsRequest_PageToken)(nil),
		(*ListConfigurationsRequest_Offset)(nil),
	}
}

func _ListConfigurationsRequest_OneofMarshaler(msg proto.Message, b *proto.Buffer) error {
	m := msg.(*ListConfigurationsRequest)
	// page_start
	switch x := m.PageStart.(type) {
	case *ListConfigurationsRequest_PageToken:
		b.EncodeVarint(3<<3 | proto.WireBytes)
		b.EncodeStringBytes(x.PageToken)
	case *ListConfigurationsRequest_Offset:
		b.EncodeVarint(4<<3 | proto.WireVarint)
		b.EncodeVarint(uint64(x.Offset))
	case nil:
	default:
		return fmt.Errorf("ListConfigurationsRequest.PageStart has unexpected type %T", x)
	}
	return nil
}

func _ListConfigurationsRequest_OneofUnmarshaler(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error) {
	m := msg.(*ListConfigurationsRequest)
	switch tag {
	case 3: // page_start.page_token
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		x, err := b.DecodeStringBytes()
		m.PageStart = &ListConfigurationsRequest_PageToken{x}
		return true, err
	case 4: // page_start.offset
		if wire != proto.WireVarint {
			return true, proto.ErrInternalBadWireType
		}
		x, err := b.DecodeVarint()
		m.PageStart = &ListConfigurationsRequest_Offset{int64(x)}
		return true, err
	default:
		return false, nil
	}
}

func _ListConfigurationsRequest_OneofSizer(msg proto.Message) (n int) {
	m := msg.(*ListConfigurationsRequest)
	// page_start
	switch x := m.PageStart.(type) {
	case *ListConfigurationsRequest_PageToken:
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(len(x.PageToken)))
		n += len(x.PageToken)
	case *ListConfigurationsRequest_Offset:
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(x.Offset))
	case nil:
	default:
		panic(fmt.Sprintf("proto: unexpected type %T in oneof", x))
	}
	return n
}

// Response from calling ListConfigurations
type ListConfigurationsResponse struct {
	// Configurations matching the request invocation,
	// possibly capped at request.page_size or a server limit.
	Configurations []*Configuration `protobuf:"bytes,1,rep,name=configurations,proto3" json:"configurations,omitempty"`
	// Token to retrieve the next page of results, or empty if there are no
	// more results in the list.
	NextPageToken        string   `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListConfigurationsResponse) Reset()         { *m = ListConfigurationsResponse{} }
func (m *ListConfigurationsResponse) String() string { return proto.CompactTextString(m) }
func (*ListConfigurationsResponse) ProtoMessage()    {}
func (*ListConfigurationsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_resultstore_download_b0d8e6d616eef8f3, []int{5}
}
func (m *ListConfigurationsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListConfigurationsResponse.Unmarshal(m, b)
}
func (m *ListConfigurationsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListConfigurationsResponse.Marshal(b, m, deterministic)
}
func (dst *ListConfigurationsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListConfigurationsResponse.Merge(dst, src)
}
func (m *ListConfigurationsResponse) XXX_Size() int {
	return xxx_messageInfo_ListConfigurationsResponse.Size(m)
}
func (m *ListConfigurationsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ListConfigurationsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ListConfigurationsResponse proto.InternalMessageInfo

func (m *ListConfigurationsResponse) GetConfigurations() []*Configuration {
	if m != nil {
		return m.Configurations
	}
	return nil
}

func (m *ListConfigurationsResponse) GetNextPageToken() string {
	if m != nil {
		return m.NextPageToken
	}
	return ""
}

// Request passed into GetTarget
type GetTargetRequest struct {
	// The name of the target to retrieve. It must match this format:
	// invocations/${INVOCATION_ID}/targets/${TARGET_ID}
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetTargetRequest) Reset()         { *m = GetTargetRequest{} }
func (m *GetTargetRequest) String() string { return proto.CompactTextString(m) }
func (*GetTargetRequest) ProtoMessage()    {}
func (*GetTargetRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_resultstore_download_b0d8e6d616eef8f3, []int{6}
}
func (m *GetTargetRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetTargetRequest.Unmarshal(m, b)
}
func (m *GetTargetRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetTargetRequest.Marshal(b, m, deterministic)
}
func (dst *GetTargetRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetTargetRequest.Merge(dst, src)
}
func (m *GetTargetRequest) XXX_Size() int {
	return xxx_messageInfo_GetTargetRequest.Size(m)
}
func (m *GetTargetRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetTargetRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetTargetRequest proto.InternalMessageInfo

func (m *GetTargetRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// Request passed into ListTargets
type ListTargetsRequest struct {
	// The invocation name of the targets to retrieve. It must match this format:
	// invocations/${INVOCATION_ID}
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// The maximum number of items to return.
	// Zero means all, but may be capped by the server.
	PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Options for pagination.
	//
	// Types that are valid to be assigned to PageStart:
	//	*ListTargetsRequest_PageToken
	//	*ListTargetsRequest_Offset
	PageStart            isListTargetsRequest_PageStart `protobuf_oneof:"page_start"`
	XXX_NoUnkeyedLiteral struct{}                       `json:"-"`
	XXX_unrecognized     []byte                         `json:"-"`
	XXX_sizecache        int32                          `json:"-"`
}

func (m *ListTargetsRequest) Reset()         { *m = ListTargetsRequest{} }
func (m *ListTargetsRequest) String() string { return proto.CompactTextString(m) }
func (*ListTargetsRequest) ProtoMessage()    {}
func (*ListTargetsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_resultstore_download_b0d8e6d616eef8f3, []int{7}
}
func (m *ListTargetsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListTargetsRequest.Unmarshal(m, b)
}
func (m *ListTargetsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListTargetsRequest.Marshal(b, m, deterministic)
}
func (dst *ListTargetsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListTargetsRequest.Merge(dst, src)
}
func (m *ListTargetsRequest) XXX_Size() int {
	return xxx_messageInfo_ListTargetsRequest.Size(m)
}
func (m *ListTargetsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ListTargetsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ListTargetsRequest proto.InternalMessageInfo

func (m *ListTargetsRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *ListTargetsRequest) GetPageSize() int32 {
	if m != nil {
		return m.PageSize
	}
	return 0
}

type isListTargetsRequest_PageStart interface {
	isListTargetsRequest_PageStart()
}

type ListTargetsRequest_PageToken struct {
	PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3,oneof"`
}

type ListTargetsRequest_Offset struct {
	Offset int64 `protobuf:"varint,4,opt,name=offset,proto3,oneof"`
}

func (*ListTargetsRequest_PageToken) isListTargetsRequest_PageStart() {}

func (*ListTargetsRequest_Offset) isListTargetsRequest_PageStart() {}

func (m *ListTargetsRequest) GetPageStart() isListTargetsRequest_PageStart {
	if m != nil {
		return m.PageStart
	}
	return nil
}

func (m *ListTargetsRequest) GetPageToken() string {
	if x, ok := m.GetPageStart().(*ListTargetsRequest_PageToken); ok {
		return x.PageToken
	}
	return ""
}

func (m *ListTargetsRequest) GetOffset() int64 {
	if x, ok := m.GetPageStart().(*ListTargetsRequest_Offset); ok {
		return x.Offset
	}
	return 0
}

// XXX_OneofFuncs is for the internal use of the proto package.
func (*ListTargetsRequest) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, func(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error), func(msg proto.Message) (n int), []interface{}) {
	return _ListTargetsRequest_OneofMarshaler, _ListTargetsRequest_OneofUnmarshaler, _ListTargetsRequest_OneofSizer, []interface{}{
		(*ListTargetsRequest_PageToken)(nil),
		(*ListTargetsRequest_Offset)(nil),
	}
}

func _ListTargetsRequest_OneofMarshaler(msg proto.Message, b *proto.Buffer) error {
	m := msg.(*ListTargetsRequest)
	// page_start
	switch x := m.PageStart.(type) {
	case *ListTargetsRequest_PageToken:
		b.EncodeVarint(3<<3 | proto.WireBytes)
		b.EncodeStringBytes(x.PageToken)
	case *ListTargetsRequest_Offset:
		b.EncodeVarint(4<<3 | proto.WireVarint)
		b.EncodeVarint(uint64(x.Offset))
	case nil:
	default:
		return fmt.Errorf("ListTargetsRequest.PageStart has unexpected type %T", x)
	}
	return nil
}

func _ListTargetsRequest_OneofUnmarshaler(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error) {
	m := msg.(*ListTargetsRequest)
	switch tag {
	case 3: // page_start.page_token
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		x, err := b.DecodeStringBytes()
		m.PageStart = &ListTargetsRequest_PageToken{x}
		return true, err
	case 4: // page_start.offset
		if wire != proto.WireVarint {
			return true, proto.ErrInternalBadWireType
		}
		x, err := b.DecodeVarint()
		m.PageStart = &ListTargetsRequest_Offset{int64(x)}
		return true, err
	default:
		return false, nil
	}
}

func _ListTargetsRequest_OneofSizer(msg proto.Message) (n int) {
	m := msg.(*ListTargetsRequest)
	// page_start
	switch x := m.PageStart.(type) {
	case *ListTargetsRequest_PageToken:
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(len(x.PageToken)))
		n += len(x.PageToken)
	case *ListTargetsRequest_Offset:
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(x.Offset))
	case nil:
	default:
		panic(fmt.Sprintf("proto: unexpected type %T in oneof", x))
	}
	return n
}

// Response from calling ListTargetsResponse
type ListTargetsResponse struct {
	// Targets matching the request invocation,
	// possibly capped at request.page_size or a server limit.
	Targets []*Target `protobuf:"bytes,1,rep,name=targets,proto3" json:"targets,omitempty"`
	// Token to retrieve the next page of results, or empty if there are no
	// more results in the list.
	NextPageToken        string   `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListTargetsResponse) Reset()         { *m = ListTargetsResponse{} }
func (m *ListTargetsResponse) String() string { return proto.CompactTextString(m) }
func (*ListTargetsResponse) ProtoMessage()    {}
func (*ListTargetsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_resultstore_download_b0d8e6d616eef8f3, []int{8}
}
func (m *ListTargetsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListTargetsResponse.Unmarshal(m, b)
}
func (m *ListTargetsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListTargetsResponse.Marshal(b, m, deterministic)
}
func (dst *ListTargetsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListTargetsResponse.Merge(dst, src)
}
func (m *ListTargetsResponse) XXX_Size() int {
	return xxx_messageInfo_ListTargetsResponse.Size(m)
}
func (m *ListTargetsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ListTargetsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ListTargetsResponse proto.InternalMessageInfo

func (m *ListTargetsResponse) GetTargets() []*Target {
	if m != nil {
		return m.Targets
	}
	return nil
}

func (m *ListTargetsResponse) GetNextPageToken() string {
	if m != nil {
		return m.NextPageToken
	}
	return ""
}

// Request passed into GetConfiguredTarget
type GetConfiguredTargetRequest struct {
	// The name of the configured target to retrieve. It must match this format:
	// invocations/${INVOCATION_ID}/targets/${TARGET_ID}/configuredTargets/${CONFIGURATION_ID}
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetConfiguredTargetRequest) Reset()         { *m = GetConfiguredTargetRequest{} }
func (m *GetConfiguredTargetRequest) String() string { return proto.CompactTextString(m) }
func (*GetConfiguredTargetRequest) ProtoMessage()    {}
func (*GetConfiguredTargetRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_resultstore_download_b0d8e6d616eef8f3, []int{9}
}
func (m *GetConfiguredTargetRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetConfiguredTargetRequest.Unmarshal(m, b)
}
func (m *GetConfiguredTargetRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetConfiguredTargetRequest.Marshal(b, m, deterministic)
}
func (dst *GetConfiguredTargetRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetConfiguredTargetRequest.Merge(dst, src)
}
func (m *GetConfiguredTargetRequest) XXX_Size() int {
	return xxx_messageInfo_GetConfiguredTargetRequest.Size(m)
}
func (m *GetConfiguredTargetRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetConfiguredTargetRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetConfiguredTargetRequest proto.InternalMessageInfo

func (m *GetConfiguredTargetRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// Request passed into ListConfiguredTargets
type ListConfiguredTargetsRequest struct {
	// The invocation and target name of the configured targets to retrieve.
	// It must match this format:
	// invocations/${INVOCATION_ID}/targets/${TARGET_ID}
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// The maximum number of items to return.
	// Zero means all, but may be capped by the server.
	PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Options for pagination.
	//
	// Types that are valid to be assigned to PageStart:
	//	*ListConfiguredTargetsRequest_PageToken
	//	*ListConfiguredTargetsRequest_Offset
	PageStart            isListConfiguredTargetsRequest_PageStart `protobuf_oneof:"page_start"`
	XXX_NoUnkeyedLiteral struct{}                                 `json:"-"`
	XXX_unrecognized     []byte                                   `json:"-"`
	XXX_sizecache        int32                                    `json:"-"`
}

func (m *ListConfiguredTargetsRequest) Reset()         { *m = ListConfiguredTargetsRequest{} }
func (m *ListConfiguredTargetsRequest) String() string { return proto.CompactTextString(m) }
func (*ListConfiguredTargetsRequest) ProtoMessage()    {}
func (*ListConfiguredTargetsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_resultstore_download_b0d8e6d616eef8f3, []int{10}
}
func (m *ListConfiguredTargetsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListConfiguredTargetsRequest.Unmarshal(m, b)
}
func (m *ListConfiguredTargetsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListConfiguredTargetsRequest.Marshal(b, m, deterministic)
}
func (dst *ListConfiguredTargetsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListConfiguredTargetsRequest.Merge(dst, src)
}
func (m *ListConfiguredTargetsRequest) XXX_Size() int {
	return xxx_messageInfo_ListConfiguredTargetsRequest.Size(m)
}
func (m *ListConfiguredTargetsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ListConfiguredTargetsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ListConfiguredTargetsRequest proto.InternalMessageInfo

func (m *ListConfiguredTargetsRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *ListConfiguredTargetsRequest) GetPageSize() int32 {
	if m != nil {
		return m.PageSize
	}
	return 0
}

type isListConfiguredTargetsRequest_PageStart interface {
	isListConfiguredTargetsRequest_PageStart()
}

type ListConfiguredTargetsRequest_PageToken struct {
	PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3,oneof"`
}

type ListConfiguredTargetsRequest_Offset struct {
	Offset int64 `protobuf:"varint,4,opt,name=offset,proto3,oneof"`
}

func (*ListConfiguredTargetsRequest_PageToken) isListConfiguredTargetsRequest_PageStart() {}

func (*ListConfiguredTargetsRequest_Offset) isListConfiguredTargetsRequest_PageStart() {}

func (m *ListConfiguredTargetsRequest) GetPageStart() isListConfiguredTargetsRequest_PageStart {
	if m != nil {
		return m.PageStart
	}
	return nil
}

func (m *ListConfiguredTargetsRequest) GetPageToken() string {
	if x, ok := m.GetPageStart().(*ListConfiguredTargetsRequest_PageToken); ok {
		return x.PageToken
	}
	return ""
}

func (m *ListConfiguredTargetsRequest) GetOffset() int64 {
	if x, ok := m.GetPageStart().(*ListConfiguredTargetsRequest_Offset); ok {
		return x.Offset
	}
	return 0
}

// XXX_OneofFuncs is for the internal use of the proto package.
func (*ListConfiguredTargetsRequest) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, func(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error), func(msg proto.Message) (n int), []interface{}) {
	return _ListConfiguredTargetsRequest_OneofMarshaler, _ListConfiguredTargetsRequest_OneofUnmarshaler, _ListConfiguredTargetsRequest_OneofSizer, []interface{}{
		(*ListConfiguredTargetsRequest_PageToken)(nil),
		(*ListConfiguredTargetsRequest_Offset)(nil),
	}
}

func _ListConfiguredTargetsRequest_OneofMarshaler(msg proto.Message, b *proto.Buffer) error {
	m := msg.(*ListConfiguredTargetsRequest)
	// page_start
	switch x := m.PageStart.(type) {
	case *ListConfiguredTargetsRequest_PageToken:
		b.EncodeVarint(3<<3 | proto.WireBytes)
		b.EncodeStringBytes(x.PageToken)
	case *ListConfiguredTargetsRequest_Offset:
		b.EncodeVarint(4<<3 | proto.WireVarint)
		b.EncodeVarint(uint64(x.Offset))
	case nil:
	default:
		return fmt.Errorf("ListConfiguredTargetsRequest.PageStart has unexpected type %T", x)
	}
	return nil
}

func _ListConfiguredTargetsRequest_OneofUnmarshaler(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error) {
	m := msg.(*ListConfiguredTargetsRequest)
	switch tag {
	case 3: // page_start.page_token
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		x, err := b.DecodeStringBytes()
		m.PageStart = &ListConfiguredTargetsRequest_PageToken{x}
		return true, err
	case 4: // page_start.offset
		if wire != proto.WireVarint {
			return true, proto.ErrInternalBadWireType
		}
		x, err := b.DecodeVarint()
		m.PageStart = &ListConfiguredTargetsRequest_Offset{int64(x)}
		return true, err
	default:
		return false, nil
	}
}

func _ListConfiguredTargetsRequest_OneofSizer(msg proto.Message) (n int) {
	m := msg.(*ListConfiguredTargetsRequest)
	// page_start
	switch x := m.PageStart.(type) {
	case *ListConfiguredTargetsRequest_PageToken:
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(len(x.PageToken)))
		n += len(x.PageToken)
	case *ListConfiguredTargetsRequest_Offset:
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(x.Offset))
	case nil:
	default:
		panic(fmt.Sprintf("proto: unexpected type %T in oneof", x))
	}
	return n
}

// Response from calling ListConfiguredTargets
type ListConfiguredTargetsResponse struct {
	// ConfiguredTargets matching the request,
	// possibly capped at request.page_size or a server limit.
	ConfiguredTargets []*ConfiguredTarget `protobuf:"bytes,1,rep,name=configured_targets,json=configuredTargets,proto3" json:"configured_targets,omitempty"`
	// Token to retrieve the next page of results, or empty if there are no
	// more results in the list.
	NextPageToken        string   `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListConfiguredTargetsResponse) Reset()         { *m = ListConfiguredTargetsResponse{} }
func (m *ListConfiguredTargetsResponse) String() string { return proto.CompactTextString(m) }
func (*ListConfiguredTargetsResponse) ProtoMessage()    {}
func (*ListConfiguredTargetsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_resultstore_download_b0d8e6d616eef8f3, []int{11}
}
func (m *ListConfiguredTargetsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListConfiguredTargetsResponse.Unmarshal(m, b)
}
func (m *ListConfiguredTargetsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListConfiguredTargetsResponse.Marshal(b, m, deterministic)
}
func (dst *ListConfiguredTargetsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListConfiguredTargetsResponse.Merge(dst, src)
}
func (m *ListConfiguredTargetsResponse) XXX_Size() int {
	return xxx_messageInfo_ListConfiguredTargetsResponse.Size(m)
}
func (m *ListConfiguredTargetsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ListConfiguredTargetsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ListConfiguredTargetsResponse proto.InternalMessageInfo

func (m *ListConfiguredTargetsResponse) GetConfiguredTargets() []*ConfiguredTarget {
	if m != nil {
		return m.ConfiguredTargets
	}
	return nil
}

func (m *ListConfiguredTargetsResponse) GetNextPageToken() string {
	if m != nil {
		return m.NextPageToken
	}
	return ""
}

// Request passed into GetAction
type GetActionRequest struct {
	// The name of the action to retrieve. It must match this format:
	// invocations/${INVOCATION_ID}/targets/${TARGET_ID}/configuredTargets/${CONFIGURATION_ID}/actions/${ACTION_ID}
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetActionRequest) Reset()         { *m = GetActionRequest{} }
func (m *GetActionRequest) String() string { return proto.CompactTextString(m) }
func (*GetActionRequest) ProtoMessage()    {}
func (*GetActionRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_resultstore_download_b0d8e6d616eef8f3, []int{12}
}
func (m *GetActionRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetActionRequest.Unmarshal(m, b)
}
func (m *GetActionRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetActionRequest.Marshal(b, m, deterministic)
}
func (dst *GetActionRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetActionRequest.Merge(dst, src)
}
func (m *GetActionRequest) XXX_Size() int {
	return xxx_messageInfo_GetActionRequest.Size(m)
}
func (m *GetActionRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetActionRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetActionRequest proto.InternalMessageInfo

func (m *GetActionRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// Request passed into ListActions
type ListActionsRequest struct {
	// The invocation, target, and configuration name of the action to retrieve.
	// It must match this format:
	// invocations/${INVOCATION_ID}/targets/${TARGET_ID}/configuredTargets/${CONFIGURATION_ID}
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// The maximum number of items to return.
	// Zero means all, but may be capped by the server.
	PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Options for pagination.
	//
	// Types that are valid to be assigned to PageStart:
	//	*ListActionsRequest_PageToken
	//	*ListActionsRequest_Offset
	PageStart            isListActionsRequest_PageStart `protobuf_oneof:"page_start"`
	XXX_NoUnkeyedLiteral struct{}                       `json:"-"`
	XXX_unrecognized     []byte                         `json:"-"`
	XXX_sizecache        int32                          `json:"-"`
}

func (m *ListActionsRequest) Reset()         { *m = ListActionsRequest{} }
func (m *ListActionsRequest) String() string { return proto.CompactTextString(m) }
func (*ListActionsRequest) ProtoMessage()    {}
func (*ListActionsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_resultstore_download_b0d8e6d616eef8f3, []int{13}
}
func (m *ListActionsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListActionsRequest.Unmarshal(m, b)
}
func (m *ListActionsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListActionsRequest.Marshal(b, m, deterministic)
}
func (dst *ListActionsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListActionsRequest.Merge(dst, src)
}
func (m *ListActionsRequest) XXX_Size() int {
	return xxx_messageInfo_ListActionsRequest.Size(m)
}
func (m *ListActionsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ListActionsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ListActionsRequest proto.InternalMessageInfo

func (m *ListActionsRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *ListActionsRequest) GetPageSize() int32 {
	if m != nil {
		return m.PageSize
	}
	return 0
}

type isListActionsRequest_PageStart interface {
	isListActionsRequest_PageStart()
}

type ListActionsRequest_PageToken struct {
	PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3,oneof"`
}

type ListActionsRequest_Offset struct {
	Offset int64 `protobuf:"varint,4,opt,name=offset,proto3,oneof"`
}

func (*ListActionsRequest_PageToken) isListActionsRequest_PageStart() {}

func (*ListActionsRequest_Offset) isListActionsRequest_PageStart() {}

func (m *ListActionsRequest) GetPageStart() isListActionsRequest_PageStart {
	if m != nil {
		return m.PageStart
	}
	return nil
}

func (m *ListActionsRequest) GetPageToken() string {
	if x, ok := m.GetPageStart().(*ListActionsRequest_PageToken); ok {
		return x.PageToken
	}
	return ""
}

func (m *ListActionsRequest) GetOffset() int64 {
	if x, ok := m.GetPageStart().(*ListActionsRequest_Offset); ok {
		return x.Offset
	}
	return 0
}

// XXX_OneofFuncs is for the internal use of the proto package.
func (*ListActionsRequest) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, func(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error), func(msg proto.Message) (n int), []interface{}) {
	return _ListActionsRequest_OneofMarshaler, _ListActionsRequest_OneofUnmarshaler, _ListActionsRequest_OneofSizer, []interface{}{
		(*ListActionsRequest_PageToken)(nil),
		(*ListActionsRequest_Offset)(nil),
	}
}

func _ListActionsRequest_OneofMarshaler(msg proto.Message, b *proto.Buffer) error {
	m := msg.(*ListActionsRequest)
	// page_start
	switch x := m.PageStart.(type) {
	case *ListActionsRequest_PageToken:
		b.EncodeVarint(3<<3 | proto.WireBytes)
		b.EncodeStringBytes(x.PageToken)
	case *ListActionsRequest_Offset:
		b.EncodeVarint(4<<3 | proto.WireVarint)
		b.EncodeVarint(uint64(x.Offset))
	case nil:
	default:
		return fmt.Errorf("ListActionsRequest.PageStart has unexpected type %T", x)
	}
	return nil
}

func _ListActionsRequest_OneofUnmarshaler(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error) {
	m := msg.(*ListActionsRequest)
	switch tag {
	case 3: // page_start.page_token
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		x, err := b.DecodeStringBytes()
		m.PageStart = &ListActionsRequest_PageToken{x}
		return true, err
	case 4: // page_start.offset
		if wire != proto.WireVarint {
			return true, proto.ErrInternalBadWireType
		}
		x, err := b.DecodeVarint()
		m.PageStart = &ListActionsRequest_Offset{int64(x)}
		return true, err
	default:
		return false, nil
	}
}

func _ListActionsRequest_OneofSizer(msg proto.Message) (n int) {
	m := msg.(*ListActionsRequest)
	// page_start
	switch x := m.PageStart.(type) {
	case *ListActionsRequest_PageToken:
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(len(x.PageToken)))
		n += len(x.PageToken)
	case *ListActionsRequest_Offset:
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(x.Offset))
	case nil:
	default:
		panic(fmt.Sprintf("proto: unexpected type %T in oneof", x))
	}
	return n
}

// Response from calling ListActions
type ListActionsResponse struct {
	// Actions matching the request,
	// possibly capped at request.page_size or a server limit.
	Actions []*Action `protobuf:"bytes,1,rep,name=actions,proto3" json:"actions,omitempty"`
	// Token to retrieve the next page of results, or empty if there are no
	// more results in the list.
	NextPageToken        string   `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListActionsResponse) Reset()         { *m = ListActionsResponse{} }
func (m *ListActionsResponse) String() string { return proto.CompactTextString(m) }
func (*ListActionsResponse) ProtoMessage()    {}
func (*ListActionsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_resultstore_download_b0d8e6d616eef8f3, []int{14}
}
func (m *ListActionsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListActionsResponse.Unmarshal(m, b)
}
func (m *ListActionsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListActionsResponse.Marshal(b, m, deterministic)
}
func (dst *ListActionsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListActionsResponse.Merge(dst, src)
}
func (m *ListActionsResponse) XXX_Size() int {
	return xxx_messageInfo_ListActionsResponse.Size(m)
}
func (m *ListActionsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ListActionsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ListActionsResponse proto.InternalMessageInfo

func (m *ListActionsResponse) GetActions() []*Action {
	if m != nil {
		return m.Actions
	}
	return nil
}

func (m *ListActionsResponse) GetNextPageToken() string {
	if m != nil {
		return m.NextPageToken
	}
	return ""
}

// Request passed into GetFileSet
type GetFileSetRequest struct {
	// The name of the file set to retrieve. It must match this format:
	// invocations/${INVOCATION_ID}/fileSets/${FILE_SET_ID}
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetFileSetRequest) Reset()         { *m = GetFileSetRequest{} }
func (m *GetFileSetRequest) String() string { return proto.CompactTextString(m) }
func (*GetFileSetRequest) ProtoMessage()    {}
func (*GetFileSetRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_resultstore_download_b0d8e6d616eef8f3, []int{15}
}
func (m *GetFileSetRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetFileSetRequest.Unmarshal(m, b)
}
func (m *GetFileSetRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetFileSetRequest.Marshal(b, m, deterministic)
}
func (dst *GetFileSetRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetFileSetRequest.Merge(dst, src)
}
func (m *GetFileSetRequest) XXX_Size() int {
	return xxx_messageInfo_GetFileSetRequest.Size(m)
}
func (m *GetFileSetRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetFileSetRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetFileSetRequest proto.InternalMessageInfo

func (m *GetFileSetRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// Request passed into ListFileSets
type ListFileSetsRequest struct {
	// The invocation name of the file sets to retrieve.
	// It must match this format: invocations/${INVOCATION_ID}
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// The maximum number of items to return.
	// Zero means all, but may be capped by the server.
	PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Options for pagination.
	//
	// Types that are valid to be assigned to PageStart:
	//	*ListFileSetsRequest_PageToken
	//	*ListFileSetsRequest_Offset
	PageStart            isListFileSetsRequest_PageStart `protobuf_oneof:"page_start"`
	XXX_NoUnkeyedLiteral struct{}                        `json:"-"`
	XXX_unrecognized     []byte                          `json:"-"`
	XXX_sizecache        int32                           `json:"-"`
}

func (m *ListFileSetsRequest) Reset()         { *m = ListFileSetsRequest{} }
func (m *ListFileSetsRequest) String() string { return proto.CompactTextString(m) }
func (*ListFileSetsRequest) ProtoMessage()    {}
func (*ListFileSetsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_resultstore_download_b0d8e6d616eef8f3, []int{16}
}
func (m *ListFileSetsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListFileSetsRequest.Unmarshal(m, b)
}
func (m *ListFileSetsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListFileSetsRequest.Marshal(b, m, deterministic)
}
func (dst *ListFileSetsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListFileSetsRequest.Merge(dst, src)
}
func (m *ListFileSetsRequest) XXX_Size() int {
	return xxx_messageInfo_ListFileSetsRequest.Size(m)
}
func (m *ListFileSetsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ListFileSetsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ListFileSetsRequest proto.InternalMessageInfo

func (m *ListFileSetsRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *ListFileSetsRequest) GetPageSize() int32 {
	if m != nil {
		return m.PageSize
	}
	return 0
}

type isListFileSetsRequest_PageStart interface {
	isListFileSetsRequest_PageStart()
}

type ListFileSetsRequest_PageToken struct {
	PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3,oneof"`
}

type ListFileSetsRequest_Offset struct {
	Offset int64 `protobuf:"varint,4,opt,name=offset,proto3,oneof"`
}

func (*ListFileSetsRequest_PageToken) isListFileSetsRequest_PageStart() {}

func (*ListFileSetsRequest_Offset) isListFileSetsRequest_PageStart() {}

func (m *ListFileSetsRequest) GetPageStart() isListFileSetsRequest_PageStart {
	if m != nil {
		return m.PageStart
	}
	return nil
}

func (m *ListFileSetsRequest) GetPageToken() string {
	if x, ok := m.GetPageStart().(*ListFileSetsRequest_PageToken); ok {
		return x.PageToken
	}
	return ""
}

func (m *ListFileSetsRequest) GetOffset() int64 {
	if x, ok := m.GetPageStart().(*ListFileSetsRequest_Offset); ok {
		return x.Offset
	}
	return 0
}

// XXX_OneofFuncs is for the internal use of the proto package.
func (*ListFileSetsRequest) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, func(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error), func(msg proto.Message) (n int), []interface{}) {
	return _ListFileSetsRequest_OneofMarshaler, _ListFileSetsRequest_OneofUnmarshaler, _ListFileSetsRequest_OneofSizer, []interface{}{
		(*ListFileSetsRequest_PageToken)(nil),
		(*ListFileSetsRequest_Offset)(nil),
	}
}

func _ListFileSetsRequest_OneofMarshaler(msg proto.Message, b *proto.Buffer) error {
	m := msg.(*ListFileSetsRequest)
	// page_start
	switch x := m.PageStart.(type) {
	case *ListFileSetsRequest_PageToken:
		b.EncodeVarint(3<<3 | proto.WireBytes)
		b.EncodeStringBytes(x.PageToken)
	case *ListFileSetsRequest_Offset:
		b.EncodeVarint(4<<3 | proto.WireVarint)
		b.EncodeVarint(uint64(x.Offset))
	case nil:
	default:
		return fmt.Errorf("ListFileSetsRequest.PageStart has unexpected type %T", x)
	}
	return nil
}

func _ListFileSetsRequest_OneofUnmarshaler(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error) {
	m := msg.(*ListFileSetsRequest)
	switch tag {
	case 3: // page_start.page_token
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		x, err := b.DecodeStringBytes()
		m.PageStart = &ListFileSetsRequest_PageToken{x}
		return true, err
	case 4: // page_start.offset
		if wire != proto.WireVarint {
			return true, proto.ErrInternalBadWireType
		}
		x, err := b.DecodeVarint()
		m.PageStart = &ListFileSetsRequest_Offset{int64(x)}
		return true, err
	default:
		return false, nil
	}
}

func _ListFileSetsRequest_OneofSizer(msg proto.Message) (n int) {
	m := msg.(*ListFileSetsRequest)
	// page_start
	switch x := m.PageStart.(type) {
	case *ListFileSetsRequest_PageToken:
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(len(x.PageToken)))
		n += len(x.PageToken)
	case *ListFileSetsRequest_Offset:
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(x.Offset))
	case nil:
	default:
		panic(fmt.Sprintf("proto: unexpected type %T in oneof", x))
	}
	return n
}

// Response from calling ListFileSets
type ListFileSetsResponse struct {
	// File sets matching the request,
	// possibly capped at request.page_size or a server limit.
	FileSets []*FileSet `protobuf:"bytes,1,rep,name=file_sets,json=fileSets,proto3" json:"file_sets,omitempty"`
	// Token to retrieve the next page of results, or empty if there are no
	// more results in the list.
	NextPageToken        string   `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListFileSetsResponse) Reset()         { *m = ListFileSetsResponse{} }
func (m *ListFileSetsResponse) String() string { return proto.CompactTextString(m) }
func (*ListFileSetsResponse) ProtoMessage()    {}
func (*ListFileSetsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_resultstore_download_b0d8e6d616eef8f3, []int{17}
}
func (m *ListFileSetsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListFileSetsResponse.Unmarshal(m, b)
}
func (m *ListFileSetsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListFileSetsResponse.Marshal(b, m, deterministic)
}
func (dst *ListFileSetsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListFileSetsResponse.Merge(dst, src)
}
func (m *ListFileSetsResponse) XXX_Size() int {
	return xxx_messageInfo_ListFileSetsResponse.Size(m)
}
func (m *ListFileSetsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ListFileSetsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ListFileSetsResponse proto.InternalMessageInfo

func (m *ListFileSetsResponse) GetFileSets() []*FileSet {
	if m != nil {
		return m.FileSets
	}
	return nil
}

func (m *ListFileSetsResponse) GetNextPageToken() string {
	if m != nil {
		return m.NextPageToken
	}
	return ""
}

func init() {
	proto.RegisterType((*GetInvocationRequest)(nil), "google.devtools.resultstore.v2.GetInvocationRequest")
	proto.RegisterType((*SearchInvocationsRequest)(nil), "google.devtools.resultstore.v2.SearchInvocationsRequest")
	proto.RegisterType((*SearchInvocationsResponse)(nil), "google.devtools.resultstore.v2.SearchInvocationsResponse")
	proto.RegisterType((*GetConfigurationRequest)(nil), "google.devtools.resultstore.v2.GetConfigurationRequest")
	proto.RegisterType((*ListConfigurationsRequest)(nil), "google.devtools.resultstore.v2.ListConfigurationsRequest")
	proto.RegisterType((*ListConfigurationsResponse)(nil), "google.devtools.resultstore.v2.ListConfigurationsResponse")
	proto.RegisterType((*GetTargetRequest)(nil), "google.devtools.resultstore.v2.GetTargetRequest")
	proto.RegisterType((*ListTargetsRequest)(nil), "google.devtools.resultstore.v2.ListTargetsRequest")
	proto.RegisterType((*ListTargetsResponse)(nil), "google.devtools.resultstore.v2.ListTargetsResponse")
	proto.RegisterType((*GetConfiguredTargetRequest)(nil), "google.devtools.resultstore.v2.GetConfiguredTargetRequest")
	proto.RegisterType((*ListConfiguredTargetsRequest)(nil), "google.devtools.resultstore.v2.ListConfiguredTargetsRequest")
	proto.RegisterType((*ListConfiguredTargetsResponse)(nil), "google.devtools.resultstore.v2.ListConfiguredTargetsResponse")
	proto.RegisterType((*GetActionRequest)(nil), "google.devtools.resultstore.v2.GetActionRequest")
	proto.RegisterType((*ListActionsRequest)(nil), "google.devtools.resultstore.v2.ListActionsRequest")
	proto.RegisterType((*ListActionsResponse)(nil), "google.devtools.resultstore.v2.ListActionsResponse")
	proto.RegisterType((*GetFileSetRequest)(nil), "google.devtools.resultstore.v2.GetFileSetRequest")
	proto.RegisterType((*ListFileSetsRequest)(nil), "google.devtools.resultstore.v2.ListFileSetsRequest")
	proto.RegisterType((*ListFileSetsResponse)(nil), "google.devtools.resultstore.v2.ListFileSetsResponse")
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// ResultStoreDownloadClient is the client API for ResultStoreDownload service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type ResultStoreDownloadClient interface {
	// Retrieves the invocation with the given name.
	//
	// An error will be reported in the following cases:
	// - If the invocation is not found.
	// - If the given invocation name is badly formatted.
	// - If no field mask was given.
	GetInvocation(ctx context.Context, in *GetInvocationRequest, opts ...grpc.CallOption) (*Invocation, error)
	// Searches for invocations matching the given query parameters.
	//
	//
	// An error will be reported in the following cases:
	// - If a query string is not provided
	// - If no field mask was given.
	SearchInvocations(ctx context.Context, in *SearchInvocationsRequest, opts ...grpc.CallOption) (*SearchInvocationsResponse, error)
	// Retrieves the configuration with the given name.
	//
	// An error will be reported in the following cases:
	// - If the configuration or its parent invocation is not found.
	// - If the given configuration name is badly formatted.
	// - If no field mask was given.
	GetConfiguration(ctx context.Context, in *GetConfigurationRequest, opts ...grpc.CallOption) (*Configuration, error)
	// Retrieves all configurations for a parent invocation.
	// This might be limited by user or server,
	// in which case a continuation token is provided.
	//
	// An error will be reported in the following cases:
	// - If the parent invocation is not found.
	// - If the given parent invocation name is badly formatted.
	// - If no field mask was given.
	ListConfigurations(ctx context.Context, in *ListConfigurationsRequest, opts ...grpc.CallOption) (*ListConfigurationsResponse, error)
	// Retrieves the target with the given name.
	//
	// An error will be reported in the following cases:
	// - If the target or its parent invocation is not found.
	// - If the given target name is badly formatted.
	// - If no field mask was given.
	GetTarget(ctx context.Context, in *GetTargetRequest, opts ...grpc.CallOption) (*Target, error)
	// Retrieves all targets for a parent invocation.  This might be limited by
	// user or server, in which case a continuation token is provided.
	//
	// An error will be reported in the following cases:
	// - If the parent is not found.
	// - If the given parent name is badly formatted.
	// - If no field mask was given.
	ListTargets(ctx context.Context, in *ListTargetsRequest, opts ...grpc.CallOption) (*ListTargetsResponse, error)
	// Retrieves the configured target with the given name.
	//
	// An error will be reported in the following cases:
	// - If the configured target is not found.
	// - If the given name is badly formatted.
	// - If no field mask was given.
	GetConfiguredTarget(ctx context.Context, in *GetConfiguredTargetRequest, opts ...grpc.CallOption) (*ConfiguredTarget, error)
	// Retrieves all configured targets for a parent invocation/target.
	// This might be limited by user or server, in which case a continuation
	// token is provided.  Supports '-' for targetId meaning all targets.
	//
	// An error will be reported in the following cases:
	// - If the parent is not found.
	// - If the given parent name is badly formatted.
	// - If no field mask was given.
	ListConfiguredTargets(ctx context.Context, in *ListConfiguredTargetsRequest, opts ...grpc.CallOption) (*ListConfiguredTargetsResponse, error)
	// Retrieves the action with the given name.
	//
	// An error will be reported in the following cases:
	// - If the action is not found.
	// - If the given name is badly formatted.
	// - If no field mask was given.
	GetAction(ctx context.Context, in *GetActionRequest, opts ...grpc.CallOption) (*Action, error)
	// Retrieves all actions for a parent invocation/target/configuration.
	// This might be limited by user or server, in which case a continuation
	// token is provided.  Supports '-' for configurationId to mean all
	// actions for all configurations for a target, or '-' for targetId and
	// configurationId to mean all actions for all configurations and all targets.
	// Does not support targetId '-' with a specified configuration.
	//
	// An error will be reported in the following cases:
	// - If the parent is not found.
	// - If the given parent name is badly formatted.
	// - If no field mask was given.
	ListActions(ctx context.Context, in *ListActionsRequest, opts ...grpc.CallOption) (*ListActionsResponse, error)
	// Retrieves the file set with the given name.
	//
	// An error will be reported in the following cases:
	// - If the file set or its parent invocation is not found.
	// - If the given file set name is badly formatted.
	// - If no field mask was given.
	GetFileSet(ctx context.Context, in *GetFileSetRequest, opts ...grpc.CallOption) (*FileSet, error)
	// Retrieves all file sets for a parent invocation.
	// This might be limited by user or server,
	// in which case a continuation token is provided.
	//
	// An error will be reported in the following cases:
	// - If the parent invocation is not found.
	// - If the given parent invocation name is badly formatted.
	// - If no field mask was given.
	ListFileSets(ctx context.Context, in *ListFileSetsRequest, opts ...grpc.CallOption) (*ListFileSetsResponse, error)
}

type resultStoreDownloadClient struct {
	cc *grpc.ClientConn
}

func NewResultStoreDownloadClient(cc *grpc.ClientConn) ResultStoreDownloadClient {
	return &resultStoreDownloadClient{cc}
}

func (c *resultStoreDownloadClient) GetInvocation(ctx context.Context, in *GetInvocationRequest, opts ...grpc.CallOption) (*Invocation, error) {
	out := new(Invocation)
	err := c.cc.Invoke(ctx, "/google.devtools.resultstore.v2.ResultStoreDownload/GetInvocation", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *resultStoreDownloadClient) SearchInvocations(ctx context.Context, in *SearchInvocationsRequest, opts ...grpc.CallOption) (*SearchInvocationsResponse, error) {
	out := new(SearchInvocationsResponse)
	err := c.cc.Invoke(ctx, "/google.devtools.resultstore.v2.ResultStoreDownload/SearchInvocations", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *resultStoreDownloadClient) GetConfiguration(ctx context.Context, in *GetConfigurationRequest, opts ...grpc.CallOption) (*Configuration, error) {
	out := new(Configuration)
	err := c.cc.Invoke(ctx, "/google.devtools.resultstore.v2.ResultStoreDownload/GetConfiguration", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *resultStoreDownloadClient) ListConfigurations(ctx context.Context, in *ListConfigurationsRequest, opts ...grpc.CallOption) (*ListConfigurationsResponse, error) {
	out := new(ListConfigurationsResponse)
	err := c.cc.Invoke(ctx, "/google.devtools.resultstore.v2.ResultStoreDownload/ListConfigurations", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *resultStoreDownloadClient) GetTarget(ctx context.Context, in *GetTargetRequest, opts ...grpc.CallOption) (*Target, error) {
	out := new(Target)
	err := c.cc.Invoke(ctx, "/google.devtools.resultstore.v2.ResultStoreDownload/GetTarget", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *resultStoreDownloadClient) ListTargets(ctx context.Context, in *ListTargetsRequest, opts ...grpc.CallOption) (*ListTargetsResponse, error) {
	out := new(ListTargetsResponse)
	err := c.cc.Invoke(ctx, "/google.devtools.resultstore.v2.ResultStoreDownload/ListTargets", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *resultStoreDownloadClient) GetConfiguredTarget(ctx context.Context, in *GetConfiguredTargetRequest, opts ...grpc.CallOption) (*ConfiguredTarget, error) {
	out := new(ConfiguredTarget)
	err := c.cc.Invoke(ctx, "/google.devtools.resultstore.v2.ResultStoreDownload/GetConfiguredTarget", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *resultStoreDownloadClient) ListConfiguredTargets(ctx context.Context, in *ListConfiguredTargetsRequest, opts ...grpc.CallOption) (*ListConfiguredTargetsResponse, error) {
	out := new(ListConfiguredTargetsResponse)
	err := c.cc.Invoke(ctx, "/google.devtools.resultstore.v2.ResultStoreDownload/ListConfiguredTargets", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *resultStoreDownloadClient) GetAction(ctx context.Context, in *GetActionRequest, opts ...grpc.CallOption) (*Action, error) {
	out := new(Action)
	err := c.cc.Invoke(ctx, "/google.devtools.resultstore.v2.ResultStoreDownload/GetAction", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *resultStoreDownloadClient) ListActions(ctx context.Context, in *ListActionsRequest, opts ...grpc.CallOption) (*ListActionsResponse, error) {
	out := new(ListActionsResponse)
	err := c.cc.Invoke(ctx, "/google.devtools.resultstore.v2.ResultStoreDownload/ListActions", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *resultStoreDownloadClient) GetFileSet(ctx context.Context, in *GetFileSetRequest, opts ...grpc.CallOption) (*FileSet, error) {
	out := new(FileSet)
	err := c.cc.Invoke(ctx, "/google.devtools.resultstore.v2.ResultStoreDownload/GetFileSet", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *resultStoreDownloadClient) ListFileSets(ctx context.Context, in *ListFileSetsRequest, opts ...grpc.CallOption) (*ListFileSetsResponse, error) {
	out := new(ListFileSetsResponse)
	err := c.cc.Invoke(ctx, "/google.devtools.resultstore.v2.ResultStoreDownload/ListFileSets", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// ResultStoreDownloadServer is the server API for ResultStoreDownload service.
type ResultStoreDownloadServer interface {
	// Retrieves the invocation with the given name.
	//
	// An error will be reported in the following cases:
	// - If the invocation is not found.
	// - If the given invocation name is badly formatted.
	// - If no field mask was given.
	GetInvocation(context.Context, *GetInvocationRequest) (*Invocation, error)
	// Searches for invocations matching the given query parameters.
	//
	//
	// An error will be reported in the following cases:
	// - If a query string is not provided
	// - If no field mask was given.
	SearchInvocations(context.Context, *SearchInvocationsRequest) (*SearchInvocationsResponse, error)
	// Retrieves the configuration with the given name.
	//
	// An error will be reported in the following cases:
	// - If the configuration or its parent invocation is not found.
	// - If the given configuration name is badly formatted.
	// - If no field mask was given.
	GetConfiguration(context.Context, *GetConfigurationRequest) (*Configuration, error)
	// Retrieves all configurations for a parent invocation.
	// This might be limited by user or server,
	// in which case a continuation token is provided.
	//
	// An error will be reported in the following cases:
	// - If the parent invocation is not found.
	// - If the given parent invocation name is badly formatted.
	// - If no field mask was given.
	ListConfigurations(context.Context, *ListConfigurationsRequest) (*ListConfigurationsResponse, error)
	// Retrieves the target with the given name.
	//
	// An error will be reported in the following cases:
	// - If the target or its parent invocation is not found.
	// - If the given target name is badly formatted.
	// - If no field mask was given.
	GetTarget(context.Context, *GetTargetRequest) (*Target, error)
	// Retrieves all targets for a parent invocation.  This might be limited by
	// user or server, in which case a continuation token is provided.
	//
	// An error will be reported in the following cases:
	// - If the parent is not found.
	// - If the given parent name is badly formatted.
	// - If no field mask was given.
	ListTargets(context.Context, *ListTargetsRequest) (*ListTargetsResponse, error)
	// Retrieves the configured target with the given name.
	//
	// An error will be reported in the following cases:
	// - If the configured target is not found.
	// - If the given name is badly formatted.
	// - If no field mask was given.
	GetConfiguredTarget(context.Context, *GetConfiguredTargetRequest) (*ConfiguredTarget, error)
	// Retrieves all configured targets for a parent invocation/target.
	// This might be limited by user or server, in which case a continuation
	// token is provided.  Supports '-' for targetId meaning all targets.
	//
	// An error will be reported in the following cases:
	// - If the parent is not found.
	// - If the given parent name is badly formatted.
	// - If no field mask was given.
	ListConfiguredTargets(context.Context, *ListConfiguredTargetsRequest) (*ListConfiguredTargetsResponse, error)
	// Retrieves the action with the given name.
	//
	// An error will be reported in the following cases:
	// - If the action is not found.
	// - If the given name is badly formatted.
	// - If no field mask was given.
	GetAction(context.Context, *GetActionRequest) (*Action, error)
	// Retrieves all actions for a parent invocation/target/configuration.
	// This might be limited by user or server, in which case a continuation
	// token is provided.  Supports '-' for configurationId to mean all
	// actions for all configurations for a target, or '-' for targetId and
	// configurationId to mean all actions for all configurations and all targets.
	// Does not support targetId '-' with a specified configuration.
	//
	// An error will be reported in the following cases:
	// - If the parent is not found.
	// - If the given parent name is badly formatted.
	// - If no field mask was given.
	ListActions(context.Context, *ListActionsRequest) (*ListActionsResponse, error)
	// Retrieves the file set with the given name.
	//
	// An error will be reported in the following cases:
	// - If the file set or its parent invocation is not found.
	// - If the given file set name is badly formatted.
	// - If no field mask was given.
	GetFileSet(context.Context, *GetFileSetRequest) (*FileSet, error)
	// Retrieves all file sets for a parent invocation.
	// This might be limited by user or server,
	// in which case a continuation token is provided.
	//
	// An error will be reported in the following cases:
	// - If the parent invocation is not found.
	// - If the given parent invocation name is badly formatted.
	// - If no field mask was given.
	ListFileSets(context.Context, *ListFileSetsRequest) (*ListFileSetsResponse, error)
}

func RegisterResultStoreDownloadServer(s *grpc.Server, srv ResultStoreDownloadServer) {
	s.RegisterService(&_ResultStoreDownload_serviceDesc, srv)
}

func _ResultStoreDownload_GetInvocation_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetInvocationRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ResultStoreDownloadServer).GetInvocation(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.devtools.resultstore.v2.ResultStoreDownload/GetInvocation",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ResultStoreDownloadServer).GetInvocation(ctx, req.(*GetInvocationRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _ResultStoreDownload_SearchInvocations_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(SearchInvocationsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ResultStoreDownloadServer).SearchInvocations(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.devtools.resultstore.v2.ResultStoreDownload/SearchInvocations",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ResultStoreDownloadServer).SearchInvocations(ctx, req.(*SearchInvocationsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _ResultStoreDownload_GetConfiguration_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetConfigurationRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ResultStoreDownloadServer).GetConfiguration(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.devtools.resultstore.v2.ResultStoreDownload/GetConfiguration",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ResultStoreDownloadServer).GetConfiguration(ctx, req.(*GetConfigurationRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _ResultStoreDownload_ListConfigurations_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListConfigurationsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ResultStoreDownloadServer).ListConfigurations(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.devtools.resultstore.v2.ResultStoreDownload/ListConfigurations",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ResultStoreDownloadServer).ListConfigurations(ctx, req.(*ListConfigurationsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _ResultStoreDownload_GetTarget_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetTargetRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ResultStoreDownloadServer).GetTarget(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.devtools.resultstore.v2.ResultStoreDownload/GetTarget",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ResultStoreDownloadServer).GetTarget(ctx, req.(*GetTargetRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _ResultStoreDownload_ListTargets_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListTargetsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ResultStoreDownloadServer).ListTargets(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.devtools.resultstore.v2.ResultStoreDownload/ListTargets",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ResultStoreDownloadServer).ListTargets(ctx, req.(*ListTargetsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _ResultStoreDownload_GetConfiguredTarget_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetConfiguredTargetRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ResultStoreDownloadServer).GetConfiguredTarget(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.devtools.resultstore.v2.ResultStoreDownload/GetConfiguredTarget",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ResultStoreDownloadServer).GetConfiguredTarget(ctx, req.(*GetConfiguredTargetRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _ResultStoreDownload_ListConfiguredTargets_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListConfiguredTargetsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ResultStoreDownloadServer).ListConfiguredTargets(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.devtools.resultstore.v2.ResultStoreDownload/ListConfiguredTargets",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ResultStoreDownloadServer).ListConfiguredTargets(ctx, req.(*ListConfiguredTargetsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _ResultStoreDownload_GetAction_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetActionRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ResultStoreDownloadServer).GetAction(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.devtools.resultstore.v2.ResultStoreDownload/GetAction",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ResultStoreDownloadServer).GetAction(ctx, req.(*GetActionRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _ResultStoreDownload_ListActions_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListActionsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ResultStoreDownloadServer).ListActions(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.devtools.resultstore.v2.ResultStoreDownload/ListActions",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ResultStoreDownloadServer).ListActions(ctx, req.(*ListActionsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _ResultStoreDownload_GetFileSet_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetFileSetRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ResultStoreDownloadServer).GetFileSet(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.devtools.resultstore.v2.ResultStoreDownload/GetFileSet",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ResultStoreDownloadServer).GetFileSet(ctx, req.(*GetFileSetRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _ResultStoreDownload_ListFileSets_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListFileSetsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ResultStoreDownloadServer).ListFileSets(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.devtools.resultstore.v2.ResultStoreDownload/ListFileSets",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ResultStoreDownloadServer).ListFileSets(ctx, req.(*ListFileSetsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _ResultStoreDownload_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.devtools.resultstore.v2.ResultStoreDownload",
	HandlerType: (*ResultStoreDownloadServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetInvocation",
			Handler:    _ResultStoreDownload_GetInvocation_Handler,
		},
		{
			MethodName: "SearchInvocations",
			Handler:    _ResultStoreDownload_SearchInvocations_Handler,
		},
		{
			MethodName: "GetConfiguration",
			Handler:    _ResultStoreDownload_GetConfiguration_Handler,
		},
		{
			MethodName: "ListConfigurations",
			Handler:    _ResultStoreDownload_ListConfigurations_Handler,
		},
		{
			MethodName: "GetTarget",
			Handler:    _ResultStoreDownload_GetTarget_Handler,
		},
		{
			MethodName: "ListTargets",
			Handler:    _ResultStoreDownload_ListTargets_Handler,
		},
		{
			MethodName: "GetConfiguredTarget",
			Handler:    _ResultStoreDownload_GetConfiguredTarget_Handler,
		},
		{
			MethodName: "ListConfiguredTargets",
			Handler:    _ResultStoreDownload_ListConfiguredTargets_Handler,
		},
		{
			MethodName: "GetAction",
			Handler:    _ResultStoreDownload_GetAction_Handler,
		},
		{
			MethodName: "ListActions",
			Handler:    _ResultStoreDownload_ListActions_Handler,
		},
		{
			MethodName: "GetFileSet",
			Handler:    _ResultStoreDownload_GetFileSet_Handler,
		},
		{
			MethodName: "ListFileSets",
			Handler:    _ResultStoreDownload_ListFileSets_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/devtools/resultstore/v2/resultstore_download.proto",
}

func init() {
	proto.RegisterFile("google/devtools/resultstore/v2/resultstore_download.proto", fileDescriptor_resultstore_download_b0d8e6d616eef8f3)
}

var fileDescriptor_resultstore_download_b0d8e6d616eef8f3 = []byte{
	// 1043 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xcc, 0x98, 0xcf, 0x6f, 0xdc, 0x44,
	0x14, 0xc7, 0x3b, 0xf9, 0x45, 0xf7, 0xa5, 0x85, 0xe6, 0x25, 0x14, 0xd7, 0xb4, 0x25, 0x32, 0x90,
	0x46, 0xa9, 0xb2, 0x1b, 0xb6, 0x55, 0x69, 0x03, 0x45, 0x25, 0x54, 0x24, 0x91, 0x7a, 0xa8, 0x36,
	0xe5, 0xc2, 0x65, 0x65, 0x76, 0x67, 0x8d, 0x61, 0xe3, 0xd9, 0x78, 0x26, 0x01, 0x8a, 0x10, 0x12,
	0xe2, 0x1f, 0x28, 0x11, 0x07, 0x04, 0x27, 0x0e, 0x55, 0x6e, 0x9c, 0x10, 0x57, 0x24, 0xc4, 0x5f,
	0x00, 0x7f, 0x02, 0x7f, 0x08, 0xf2, 0x78, 0x66, 0xe3, 0x71, 0xbc, 0xeb, 0x71, 0x4e, 0xb9, 0xc5,
	0xde, 0xf7, 0x9d, 0x79, 0xef, 0x33, 0x5f, 0xfb, 0xbd, 0x18, 0xee, 0x05, 0x8c, 0x05, 0x7d, 0xda,
	0xe8, 0xd2, 0x03, 0xc1, 0x58, 0x9f, 0x37, 0x62, 0xca, 0xf7, 0xfb, 0x82, 0x0b, 0x16, 0xd3, 0xc6,
	0x41, 0x33, 0x7b, 0xd9, 0xee, 0xb2, 0x2f, 0xa2, 0x3e, 0xf3, 0xbb, 0xf5, 0x41, 0xcc, 0x04, 0xc3,
	0xeb, 0xa9, 0xb4, 0xae, 0xa5, 0xf5, 0x4c, 0x6c, 0xfd, 0xa0, 0xe9, 0x5e, 0x55, 0x4b, 0xfb, 0x83,
	0xb0, 0xe1, 0x47, 0x11, 0x13, 0xbe, 0x08, 0x59, 0xc4, 0x53, 0xb5, 0x7b, 0xb3, 0x64, 0x63, 0xbf,
	0x93, 0x44, 0x5b, 0x06, 0x77, 0xd8, 0xee, 0xee, 0x30, 0xb8, 0x59, 0x1a, 0x1c, 0xf5, 0xc2, 0x60,
	0x3f, 0xf6, 0x33, 0x1b, 0xdc, 0xb1, 0xd4, 0xd0, 0x6e, 0x5b, 0xf8, 0x71, 0x40, 0x85, 0xd2, 0xad,
	0x96, 0xe8, 0x7a, 0x61, 0x9f, 0xb6, 0xf9, 0x30, 0xbc, 0x51, 0x12, 0x1e, 0x46, 0x07, 0xac, 0xe3,
	0x57, 0x28, 0x3c, 0x9b, 0x8c, 0xb7, 0x02, 0x0b, 0x9b, 0x54, 0x6c, 0x0f, 0xd7, 0x68, 0xd1, 0xbd,
	0x7d, 0xca, 0x05, 0x22, 0x4c, 0x45, 0xfe, 0x2e, 0x75, 0xc8, 0x22, 0x59, 0xae, 0xb5, 0xe4, 0xdf,
	0xde, 0xef, 0x04, 0x9c, 0x1d, 0xea, 0xc7, 0x9d, 0x4f, 0x8f, 0xe3, 0xb9, 0x16, 0xbc, 0x0a, 0xb5,
	0x81, 0x1f, 0xd0, 0x36, 0x0f, 0x9f, 0xa6, 0xaa, 0xe9, 0xd6, 0xf9, 0xe4, 0xc6, 0x4e, 0xf8, 0x94,
	0xe2, 0x6b, 0x00, 0xf2, 0x47, 0xc1, 0x3e, 0xa7, 0x91, 0x33, 0x91, 0xac, 0xb9, 0x75, 0xae, 0x25,
	0x05, 0x4f, 0x92, 0x5b, 0xe8, 0xc0, 0x0c, 0xeb, 0xf5, 0x38, 0x15, 0xce, 0xe4, 0x22, 0x59, 0x9e,
	0xdc, 0x3a, 0xd7, 0x52, 0xd7, 0xb8, 0x00, 0xd3, 0x7b, 0xfb, 0x34, 0xfe, 0xca, 0x99, 0x92, 0x99,
	0xa4, 0x17, 0x78, 0x0d, 0x60, 0x10, 0xb3, 0xcf, 0x68, 0x47, 0xb4, 0xc3, 0xae, 0x33, 0x2d, 0x7f,
	0xaa, 0xa9, 0x3b, 0xdb, 0xdd, 0x8d, 0x0b, 0x6a, 0x3f, 0x2e, 0xfc, 0x58, 0x78, 0xcf, 0x08, 0x5c,
	0x29, 0xc8, 0x9b, 0x0f, 0x58, 0xc4, 0x29, 0x3e, 0x82, 0xd9, 0x63, 0x84, 0xdc, 0x21, 0x8b, 0x93,
	0xcb, 0xb3, 0xcd, 0x95, 0xfa, 0x78, 0xa3, 0xd6, 0x33, 0xc4, 0xb2, 0x72, 0x5c, 0x82, 0x97, 0x22,
	0xfa, 0xa5, 0x68, 0xe7, 0xcb, 0x6d, 0x5d, 0x4c, 0x6e, 0x3f, 0xd6, 0x05, 0x7b, 0xab, 0xf0, 0xca,
	0x26, 0x15, 0x1f, 0x64, 0x6d, 0x35, 0x0e, 0xfd, 0x4f, 0x04, 0xae, 0x3c, 0x0a, 0xb9, 0x29, 0x18,
	0xb2, 0xbf, 0x0c, 0x33, 0x03, 0x3f, 0xa6, 0x91, 0x50, 0x1a, 0x75, 0x65, 0x9e, 0xc9, 0xc4, 0xd8,
	0x33, 0x99, 0x1c, 0x77, 0x26, 0x53, 0xe6, 0x99, 0xe4, 0xf0, 0xfe, 0x4c, 0xc0, 0x2d, 0xca, 0x4d,
	0xf1, 0xfd, 0x08, 0x5e, 0x34, 0x9e, 0x1e, 0x8d, 0x78, 0xb5, 0x0c, 0xb1, 0x09, 0x27, 0xb7, 0x88,
	0x35, 0xe8, 0x25, 0xb8, 0xb4, 0x49, 0xc5, 0x13, 0xe9, 0xf9, 0x71, 0x84, 0x7f, 0x20, 0x80, 0x49,
	0x15, 0x69, 0xe4, 0x19, 0x41, 0xfb, 0x2d, 0xcc, 0x1b, 0x39, 0x29, 0xa4, 0x0f, 0xe0, 0x85, 0xf4,
	0x21, 0xd6, 0x2c, 0x97, 0xca, 0x58, 0xaa, 0xfa, 0xb5, 0xcc, 0x9a, 0xde, 0x1a, 0xb8, 0x19, 0x9b,
	0xd2, 0x6e, 0x39, 0xc7, 0x5f, 0x08, 0x5c, 0xcd, 0xba, 0x41, 0x6b, 0xce, 0x08, 0xd1, 0x23, 0x02,
	0xd7, 0x46, 0xa4, 0xa7, 0xe0, 0xb6, 0x01, 0x4f, 0xbc, 0xb9, 0x35, 0xe7, 0x35, 0x5b, 0xcf, 0x0e,
	0x49, 0xcd, 0x75, 0xf2, 0x1b, 0x55, 0x74, 0xee, 0xfb, 0x9d, 0xb2, 0x77, 0x83, 0x76, 0x6e, 0x1a,
	0x79, 0xb6, 0x9c, 0x3b, 0xcc, 0xe9, 0xd8, 0xb9, 0x69, 0x93, 0xb6, 0x76, 0xae, 0xaa, 0x5f, 0xcb,
	0xac, 0xe9, 0xdd, 0x80, 0xb9, 0x4d, 0x2a, 0x3e, 0x0c, 0xfb, 0x74, 0x67, 0xbc, 0x61, 0x0f, 0x49,
	0x9a, 0xaa, 0x0a, 0x3d, 0x23, 0xfc, 0xbe, 0x27, 0xb0, 0x60, 0x66, 0xa5, 0x08, 0x3e, 0x84, 0x9a,
	0x1e, 0x10, 0x34, 0xc3, 0x1b, 0x65, 0x0c, 0x35, 0x85, 0xf3, 0x3d, 0xb5, 0x9a, 0x2d, 0xc5, 0xe6,
	0xdf, 0x97, 0x60, 0xbe, 0x25, 0x17, 0xdb, 0x49, 0x16, 0x7b, 0xa8, 0xa6, 0x39, 0x3c, 0x24, 0x70,
	0xd1, 0x98, 0x1b, 0xf0, 0x76, 0x59, 0x12, 0x45, 0x63, 0x86, 0x5b, 0xa1, 0xcf, 0x7a, 0x8b, 0xdf,
	0xfd, 0xf3, 0xdf, 0xe1, 0x84, 0x8b, 0x4e, 0x32, 0xc4, 0x7c, 0x9d, 0x9c, 0xdd, 0xfd, 0x4c, 0xe7,
	0x6d, 0xac, 0x7c, 0x83, 0x47, 0x04, 0xe6, 0x4e, 0x34, 0x7a, 0xbc, 0x5b, 0xb6, 0xc7, 0xa8, 0x99,
	0xc6, 0xbd, 0x77, 0x0a, 0x65, 0x7a, 0x4c, 0xde, 0x75, 0x99, 0xac, 0x83, 0x97, 0xcd, 0x11, 0x8d,
	0xaf, 0x73, 0x29, 0xc1, 0xe7, 0x44, 0x3e, 0xdd, 0x46, 0x8f, 0xc3, 0xb7, 0x2d, 0x18, 0x16, 0x8d,
	0x0c, 0x6e, 0xb5, 0x5e, 0xea, 0xad, 0xc8, 0xe4, 0xde, 0x40, 0x6f, 0x04, 0x49, 0x35, 0xba, 0x4a,
	0xa6, 0x7f, 0xa8, 0xb7, 0x8b, 0xd9, 0xdd, 0xb1, 0x14, 0xcd, 0xc8, 0x69, 0xc5, 0x5d, 0x3f, 0x8d,
	0x54, 0x61, 0x35, 0x33, 0x4f, 0x9f, 0xc8, 0x9c, 0x0b, 0x74, 0xf2, 0xf8, 0x8c, 0x40, 0x6d, 0xd8,
	0xfa, 0x71, 0xcd, 0x82, 0xad, 0xd1, 0xdd, 0x5c, 0xcb, 0xa6, 0x5a, 0x4e, 0x53, 0xf5, 0x90, 0x84,
	0xe6, 0xaf, 0x04, 0x66, 0x33, 0x1d, 0x1d, 0x9b, 0x36, 0x2c, 0xcc, 0x06, 0xea, 0xde, 0xaa, 0xa4,
	0xa9, 0x00, 0x4e, 0x0f, 0x07, 0x7f, 0x11, 0x98, 0x2f, 0xe8, 0xfa, 0xb8, 0x5e, 0xc1, 0x9e, 0xb9,
	0x51, 0xc1, 0xad, 0xdc, 0x39, 0xbd, 0xf7, 0x64, 0xc6, 0x77, 0xf1, 0x4e, 0x29, 0xd6, 0xc6, 0x89,
	0x1e, 0x9b, 0xa0, 0xfe, 0x97, 0xc0, 0xcb, 0x85, 0x9d, 0x1e, 0xdf, 0xad, 0x62, 0xc0, 0xfc, 0xfc,
	0xe2, 0xde, 0x3f, 0xa5, 0x5a, 0x1d, 0x84, 0x59, 0x56, 0xd1, 0x41, 0x64, 0xfc, 0x72, 0xb2, 0x32,
	0xfc, 0x2d, 0x75, 0x75, 0xda, 0x16, 0xad, 0x5c, 0x6d, 0x4c, 0x10, 0xae, 0x65, 0xc3, 0xf5, 0xb6,
	0x64, 0x9e, 0x1b, 0xf8, 0xe0, 0x54, 0xf8, 0xd5, 0xbf, 0xe2, 0xf2, 0x20, 0xfe, 0x54, 0x9e, 0x57,
	0xb3, 0x80, 0x9d, 0xe7, 0xcd, 0x61, 0xc6, 0xce, 0xf3, 0xb9, 0x61, 0x23, 0x57, 0xc2, 0x78, 0xd4,
	0x85, 0x1e, 0xd2, 0x55, 0xe0, 0x8f, 0x04, 0xe0, 0x78, 0x9a, 0xc0, 0xb7, 0x2c, 0xa8, 0x9b, 0x93,
	0x87, 0x6b, 0xdb, 0xa3, 0xbd, 0x9b, 0x32, 0xe9, 0x37, 0xf1, 0xf5, 0x51, 0xdc, 0x75, 0x0f, 0x4f,
	0xd0, 0x3e, 0x27, 0x70, 0x21, 0x3b, 0x25, 0xa0, 0x15, 0xa7, 0xdc, 0xa4, 0xe3, 0xde, 0xae, 0x26,
	0x52, 0x74, 0xcd, 0x44, 0x8b, 0xdf, 0x28, 0x3a, 0xd7, 0x8d, 0x3d, 0xf0, 0x3a, 0x6c, 0xb7, 0x64,
	0x9f, 0xc7, 0xe4, 0xe3, 0x6d, 0x15, 0x11, 0xb0, 0xbe, 0x1f, 0x05, 0x75, 0x16, 0x07, 0x8d, 0x80,
	0x46, 0xf2, 0x53, 0x85, 0xfa, 0x0e, 0xe2, 0x0f, 0x42, 0x3e, 0xea, 0xd3, 0xc6, 0x3b, 0x99, 0xcb,
	0x4f, 0x66, 0xa4, 0xea, 0xd6, 0xff, 0x01, 0x00, 0x00, 0xff, 0xff, 0x69, 0xe0, 0x2a, 0x9a, 0xae,
	0x12, 0x00, 0x00,
}
