// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v0/errors/campaign_group_error.proto

package errors // import "google.golang.org/genproto/googleapis/ads/googleads/v0/errors"

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// Enum describing possible campaign group errors.
type CampaignGroupErrorEnum_CampaignGroupError int32

const (
	// Enum unspecified.
	CampaignGroupErrorEnum_UNSPECIFIED CampaignGroupErrorEnum_CampaignGroupError = 0
	// The received error code is not known in this version.
	CampaignGroupErrorEnum_UNKNOWN CampaignGroupErrorEnum_CampaignGroupError = 1
	// CampaignGroup was removed with ENABLED or PAUSED Campaigns associated
	// with it.
	CampaignGroupErrorEnum_CANNOT_REMOVE_CAMPAIGN_GROUP_WITH_ENABLED_OR_PAUSED_CAMPAIGNS CampaignGroupErrorEnum_CampaignGroupError = 2
	// CampaignGroup with the given name already exists.
	CampaignGroupErrorEnum_DUPLICATE_NAME CampaignGroupErrorEnum_CampaignGroupError = 3
	// Cannot modify a removed campaign group.
	CampaignGroupErrorEnum_CANNOT_MODIFY_REMOVED_CAMPAIGN_GROUP CampaignGroupErrorEnum_CampaignGroupError = 4
)

var CampaignGroupErrorEnum_CampaignGroupError_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "CANNOT_REMOVE_CAMPAIGN_GROUP_WITH_ENABLED_OR_PAUSED_CAMPAIGNS",
	3: "DUPLICATE_NAME",
	4: "CANNOT_MODIFY_REMOVED_CAMPAIGN_GROUP",
}
var CampaignGroupErrorEnum_CampaignGroupError_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"CANNOT_REMOVE_CAMPAIGN_GROUP_WITH_ENABLED_OR_PAUSED_CAMPAIGNS": 2,
	"DUPLICATE_NAME":                       3,
	"CANNOT_MODIFY_REMOVED_CAMPAIGN_GROUP": 4,
}

func (x CampaignGroupErrorEnum_CampaignGroupError) String() string {
	return proto.EnumName(CampaignGroupErrorEnum_CampaignGroupError_name, int32(x))
}
func (CampaignGroupErrorEnum_CampaignGroupError) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_campaign_group_error_675a06723b979a2f, []int{0, 0}
}

// Container for enum describing possible campaign group errors.
type CampaignGroupErrorEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CampaignGroupErrorEnum) Reset()         { *m = CampaignGroupErrorEnum{} }
func (m *CampaignGroupErrorEnum) String() string { return proto.CompactTextString(m) }
func (*CampaignGroupErrorEnum) ProtoMessage()    {}
func (*CampaignGroupErrorEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_campaign_group_error_675a06723b979a2f, []int{0}
}
func (m *CampaignGroupErrorEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CampaignGroupErrorEnum.Unmarshal(m, b)
}
func (m *CampaignGroupErrorEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CampaignGroupErrorEnum.Marshal(b, m, deterministic)
}
func (dst *CampaignGroupErrorEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CampaignGroupErrorEnum.Merge(dst, src)
}
func (m *CampaignGroupErrorEnum) XXX_Size() int {
	return xxx_messageInfo_CampaignGroupErrorEnum.Size(m)
}
func (m *CampaignGroupErrorEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_CampaignGroupErrorEnum.DiscardUnknown(m)
}

var xxx_messageInfo_CampaignGroupErrorEnum proto.InternalMessageInfo

func init() {
	proto.RegisterType((*CampaignGroupErrorEnum)(nil), "google.ads.googleads.v0.errors.CampaignGroupErrorEnum")
	proto.RegisterEnum("google.ads.googleads.v0.errors.CampaignGroupErrorEnum_CampaignGroupError", CampaignGroupErrorEnum_CampaignGroupError_name, CampaignGroupErrorEnum_CampaignGroupError_value)
}

func init() {
	proto.RegisterFile("google/ads/googleads/v0/errors/campaign_group_error.proto", fileDescriptor_campaign_group_error_675a06723b979a2f)
}

var fileDescriptor_campaign_group_error_675a06723b979a2f = []byte{
	// 334 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x91, 0x41, 0x4b, 0xc3, 0x30,
	0x1c, 0xc5, 0xed, 0x26, 0x0a, 0x19, 0x68, 0xc9, 0x41, 0x6f, 0x3b, 0x0c, 0x0f, 0x9e, 0xd2, 0x82,
	0x27, 0x11, 0x0f, 0x59, 0x93, 0xd5, 0xe2, 0x9a, 0x86, 0x6d, 0xdd, 0x50, 0x0a, 0xa1, 0xae, 0x23,
	0x0c, 0xb6, 0xa6, 0x34, 0x6e, 0x1f, 0xc8, 0xa3, 0x57, 0xbf, 0x85, 0xa0, 0x9f, 0x49, 0xda, 0x74,
	0x3b, 0x38, 0xf4, 0xd4, 0xc7, 0xbf, 0xef, 0xf7, 0xfe, 0xfc, 0x5f, 0xc0, 0xad, 0x54, 0x4a, 0xae,
	0x16, 0x4e, 0x9a, 0x69, 0xc7, 0xc8, 0x4a, 0x6d, 0x5d, 0x67, 0x51, 0x96, 0xaa, 0xd4, 0xce, 0x3c,
	0x5d, 0x17, 0xe9, 0x52, 0xe6, 0x42, 0x96, 0x6a, 0x53, 0x88, 0x7a, 0x8a, 0x8a, 0x52, 0xbd, 0x2a,
	0xd8, 0x35, 0x7e, 0x94, 0x66, 0x1a, 0xed, 0x51, 0xb4, 0x75, 0x91, 0x41, 0x7b, 0xdf, 0x16, 0xb8,
	0xf0, 0x1a, 0xdc, 0xaf, 0x68, 0x5a, 0xcd, 0x69, 0xbe, 0x59, 0xf7, 0x3e, 0x2c, 0x00, 0x0f, 0x7f,
	0xc1, 0x73, 0xd0, 0x89, 0xd9, 0x98, 0x53, 0x2f, 0x18, 0x04, 0x94, 0xd8, 0x47, 0xb0, 0x03, 0x4e,
	0x63, 0xf6, 0xc8, 0xa2, 0x19, 0xb3, 0x2d, 0x88, 0xc1, 0xbd, 0x87, 0x19, 0x8b, 0x26, 0x62, 0x44,
	0xc3, 0x68, 0x4a, 0x85, 0x87, 0x43, 0x8e, 0x03, 0x9f, 0x09, 0x7f, 0x14, 0xc5, 0x5c, 0xcc, 0x82,
	0xc9, 0x83, 0xa0, 0x0c, 0xf7, 0x87, 0x94, 0x88, 0x68, 0x24, 0x38, 0x8e, 0xc7, 0x94, 0xec, 0x5d,
	0x63, 0xbb, 0x05, 0x21, 0x38, 0x23, 0x31, 0x1f, 0x06, 0x1e, 0x9e, 0x50, 0xc1, 0x70, 0x48, 0xed,
	0x36, 0xbc, 0x06, 0x57, 0x4d, 0x6c, 0x18, 0x91, 0x60, 0xf0, 0xd4, 0xa4, 0x93, 0x5f, 0xf1, 0xf6,
	0x71, 0xff, 0xcb, 0x02, 0xbd, 0xb9, 0x5a, 0xa3, 0xff, 0xef, 0xee, 0x5f, 0x1e, 0x5e, 0xc6, 0xab,
	0xc2, 0xb8, 0xf5, 0x4c, 0x1a, 0x54, 0xaa, 0x55, 0x9a, 0x4b, 0xa4, 0x4a, 0xe9, 0xc8, 0x45, 0x5e,
	0xd7, 0xb9, 0x6b, 0xbf, 0x58, 0xea, 0xbf, 0x1e, 0xe3, 0xce, 0x7c, 0xde, 0x5a, 0x6d, 0x1f, 0xe3,
	0xf7, 0x56, 0xd7, 0x37, 0x61, 0x38, 0xd3, 0xc8, 0xc8, 0x4a, 0x4d, 0x5d, 0x54, 0xaf, 0xd4, 0x9f,
	0x3b, 0x43, 0x82, 0x33, 0x9d, 0xec, 0x0d, 0xc9, 0xd4, 0x4d, 0x8c, 0xe1, 0xe5, 0xa4, 0x5e, 0x7c,
	0xf3, 0x13, 0x00, 0x00, 0xff, 0xff, 0x18, 0x8d, 0x63, 0x1d, 0x04, 0x02, 0x00, 0x00,
}
