// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v0/enums/placeholder_type.proto

package enums // import "google.golang.org/genproto/googleapis/ads/googleads/v0/enums"

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// Possible placeholder types for a feed mapping.
type PlaceholderTypeEnum_PlaceholderType int32

const (
	// Not specified.
	PlaceholderTypeEnum_UNSPECIFIED PlaceholderTypeEnum_PlaceholderType = 0
	// Used for return value only. Represents value unknown in this version.
	PlaceholderTypeEnum_UNKNOWN PlaceholderTypeEnum_PlaceholderType = 1
	// Sitelink.
	PlaceholderTypeEnum_SITELINK PlaceholderTypeEnum_PlaceholderType = 2
	// Call.
	PlaceholderTypeEnum_CALL PlaceholderTypeEnum_PlaceholderType = 3
	// App.
	PlaceholderTypeEnum_APP PlaceholderTypeEnum_PlaceholderType = 4
	// Location.
	PlaceholderTypeEnum_LOCATION PlaceholderTypeEnum_PlaceholderType = 5
	// Affiliate location.
	PlaceholderTypeEnum_AFFILIATE_LOCATION PlaceholderTypeEnum_PlaceholderType = 6
	// Callout.
	PlaceholderTypeEnum_CALLOUT PlaceholderTypeEnum_PlaceholderType = 7
	// Structured snippet.
	PlaceholderTypeEnum_STRUCTURED_SNIPPET PlaceholderTypeEnum_PlaceholderType = 8
	// Message.
	PlaceholderTypeEnum_MESSAGE PlaceholderTypeEnum_PlaceholderType = 9
	// Price.
	PlaceholderTypeEnum_PRICE PlaceholderTypeEnum_PlaceholderType = 10
	// Promotion.
	PlaceholderTypeEnum_PROMOTION PlaceholderTypeEnum_PlaceholderType = 11
	// Ad customizer.
	PlaceholderTypeEnum_AD_CUSTOMIZER PlaceholderTypeEnum_PlaceholderType = 12
	// Dynamic education.
	PlaceholderTypeEnum_DYNAMIC_EDUCATION PlaceholderTypeEnum_PlaceholderType = 13
	// Dynamic flights.
	PlaceholderTypeEnum_DYNAMIC_FLIGHT PlaceholderTypeEnum_PlaceholderType = 14
	// Dynamic custom.
	PlaceholderTypeEnum_DYNAMIC_CUSTOM PlaceholderTypeEnum_PlaceholderType = 15
	// Dynamic hotels.
	PlaceholderTypeEnum_DYNAMIC_HOTEL PlaceholderTypeEnum_PlaceholderType = 16
	// Dynamic real estate.
	PlaceholderTypeEnum_DYNAMIC_REAL_ESTATE PlaceholderTypeEnum_PlaceholderType = 17
	// Dynamic travel.
	PlaceholderTypeEnum_DYNAMIC_TRAVEL PlaceholderTypeEnum_PlaceholderType = 18
	// Dynamic local.
	PlaceholderTypeEnum_DYNAMIC_LOCAL PlaceholderTypeEnum_PlaceholderType = 19
	// Dynamic jobs.
	PlaceholderTypeEnum_DYNAMIC_JOB PlaceholderTypeEnum_PlaceholderType = 20
)

var PlaceholderTypeEnum_PlaceholderType_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	2:  "SITELINK",
	3:  "CALL",
	4:  "APP",
	5:  "LOCATION",
	6:  "AFFILIATE_LOCATION",
	7:  "CALLOUT",
	8:  "STRUCTURED_SNIPPET",
	9:  "MESSAGE",
	10: "PRICE",
	11: "PROMOTION",
	12: "AD_CUSTOMIZER",
	13: "DYNAMIC_EDUCATION",
	14: "DYNAMIC_FLIGHT",
	15: "DYNAMIC_CUSTOM",
	16: "DYNAMIC_HOTEL",
	17: "DYNAMIC_REAL_ESTATE",
	18: "DYNAMIC_TRAVEL",
	19: "DYNAMIC_LOCAL",
	20: "DYNAMIC_JOB",
}
var PlaceholderTypeEnum_PlaceholderType_value = map[string]int32{
	"UNSPECIFIED":         0,
	"UNKNOWN":             1,
	"SITELINK":            2,
	"CALL":                3,
	"APP":                 4,
	"LOCATION":            5,
	"AFFILIATE_LOCATION":  6,
	"CALLOUT":             7,
	"STRUCTURED_SNIPPET":  8,
	"MESSAGE":             9,
	"PRICE":               10,
	"PROMOTION":           11,
	"AD_CUSTOMIZER":       12,
	"DYNAMIC_EDUCATION":   13,
	"DYNAMIC_FLIGHT":      14,
	"DYNAMIC_CUSTOM":      15,
	"DYNAMIC_HOTEL":       16,
	"DYNAMIC_REAL_ESTATE": 17,
	"DYNAMIC_TRAVEL":      18,
	"DYNAMIC_LOCAL":       19,
	"DYNAMIC_JOB":         20,
}

func (x PlaceholderTypeEnum_PlaceholderType) String() string {
	return proto.EnumName(PlaceholderTypeEnum_PlaceholderType_name, int32(x))
}
func (PlaceholderTypeEnum_PlaceholderType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_placeholder_type_816ab67b31ba6b71, []int{0, 0}
}

// Container for enum describing possible placeholder types for a feed mapping.
type PlaceholderTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *PlaceholderTypeEnum) Reset()         { *m = PlaceholderTypeEnum{} }
func (m *PlaceholderTypeEnum) String() string { return proto.CompactTextString(m) }
func (*PlaceholderTypeEnum) ProtoMessage()    {}
func (*PlaceholderTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_placeholder_type_816ab67b31ba6b71, []int{0}
}
func (m *PlaceholderTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_PlaceholderTypeEnum.Unmarshal(m, b)
}
func (m *PlaceholderTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_PlaceholderTypeEnum.Marshal(b, m, deterministic)
}
func (dst *PlaceholderTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_PlaceholderTypeEnum.Merge(dst, src)
}
func (m *PlaceholderTypeEnum) XXX_Size() int {
	return xxx_messageInfo_PlaceholderTypeEnum.Size(m)
}
func (m *PlaceholderTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_PlaceholderTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_PlaceholderTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterType((*PlaceholderTypeEnum)(nil), "google.ads.googleads.v0.enums.PlaceholderTypeEnum")
	proto.RegisterEnum("google.ads.googleads.v0.enums.PlaceholderTypeEnum_PlaceholderType", PlaceholderTypeEnum_PlaceholderType_name, PlaceholderTypeEnum_PlaceholderType_value)
}

func init() {
	proto.RegisterFile("google/ads/googleads/v0/enums/placeholder_type.proto", fileDescriptor_placeholder_type_816ab67b31ba6b71)
}

var fileDescriptor_placeholder_type_816ab67b31ba6b71 = []byte{
	// 451 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x52, 0xc1, 0x6e, 0xda, 0x40,
	0x14, 0x2c, 0x90, 0x04, 0x58, 0x42, 0x78, 0x2c, 0x69, 0x7b, 0xca, 0xa1, 0xf9, 0x00, 0x1b, 0xa9,
	0xbd, 0xf5, 0xb4, 0xd8, 0x0f, 0xb2, 0xcd, 0xe2, 0x5d, 0xd9, 0x6b, 0xaa, 0x46, 0x48, 0x16, 0x8d,
	0x2d, 0xb7, 0x12, 0x60, 0x0b, 0x27, 0x91, 0xf2, 0x17, 0xfd, 0x86, 0x1e, 0xfb, 0x1f, 0xbd, 0xf4,
	0x8b, 0x7a, 0xac, 0xd6, 0x8e, 0x29, 0x8a, 0xd4, 0x5e, 0xac, 0xd1, 0xbc, 0x99, 0x79, 0xf2, 0xbe,
	0x21, 0xef, 0xd2, 0x2c, 0x4b, 0xd7, 0x89, 0xbd, 0x8a, 0x0b, 0xbb, 0x82, 0x06, 0x3d, 0x8c, 0xed,
	0x64, 0x7b, 0xbf, 0x29, 0xec, 0x7c, 0xbd, 0xba, 0x4d, 0xbe, 0x64, 0xeb, 0x38, 0xd9, 0x45, 0x77,
	0x8f, 0x79, 0x62, 0xe5, 0xbb, 0xec, 0x2e, 0xa3, 0x17, 0x95, 0xd4, 0x5a, 0xc5, 0x85, 0xb5, 0x77,
	0x59, 0x0f, 0x63, 0xab, 0x74, 0x5d, 0x7e, 0x6b, 0x91, 0x91, 0xfa, 0xeb, 0xd4, 0x8f, 0x79, 0x82,
	0xdb, 0xfb, 0xcd, 0xe5, 0xef, 0x26, 0x19, 0x3c, 0xe3, 0xe9, 0x80, 0xf4, 0x42, 0x2f, 0x50, 0xe8,
	0xf0, 0x29, 0x47, 0x17, 0x5e, 0xd0, 0x1e, 0x69, 0x87, 0xde, 0xb5, 0x27, 0x3f, 0x7a, 0xd0, 0xa0,
	0xa7, 0xa4, 0x13, 0x70, 0x8d, 0x82, 0x7b, 0xd7, 0xd0, 0xa4, 0x1d, 0x72, 0xe4, 0x30, 0x21, 0xa0,
	0x45, 0xdb, 0xa4, 0xc5, 0x94, 0x82, 0x23, 0x23, 0x10, 0xd2, 0x61, 0x9a, 0x4b, 0x0f, 0x8e, 0xe9,
	0x2b, 0x42, 0xd9, 0x74, 0xca, 0x05, 0x67, 0x1a, 0xa3, 0x3d, 0x7f, 0x62, 0x32, 0x8d, 0x51, 0x86,
	0x1a, 0xda, 0x46, 0x14, 0x68, 0x3f, 0x74, 0x74, 0xe8, 0xa3, 0x1b, 0x05, 0x1e, 0x57, 0x0a, 0x35,
	0x74, 0x8c, 0x68, 0x8e, 0x41, 0xc0, 0x66, 0x08, 0x5d, 0xda, 0x25, 0xc7, 0xca, 0xe7, 0x0e, 0x02,
	0xa1, 0x7d, 0xd2, 0x55, 0xbe, 0x9c, 0xcb, 0x32, 0xab, 0x47, 0x87, 0xa4, 0xcf, 0xdc, 0xc8, 0x09,
	0x03, 0x2d, 0xe7, 0xfc, 0x06, 0x7d, 0x38, 0xa5, 0x2f, 0xc9, 0xd0, 0xfd, 0xe4, 0xb1, 0x39, 0x77,
	0x22, 0x74, 0xc3, 0xa7, 0xad, 0x7d, 0x4a, 0xc9, 0x59, 0x4d, 0x4f, 0x05, 0x9f, 0x5d, 0x69, 0x38,
	0x3b, 0xe4, 0xaa, 0x08, 0x18, 0x98, 0xc4, 0x9a, 0xbb, 0x92, 0x1a, 0x05, 0x00, 0x7d, 0x4d, 0x46,
	0x35, 0xe5, 0x23, 0x13, 0x11, 0x06, 0x9a, 0x69, 0x84, 0xe1, 0xa1, 0x5f, 0xfb, 0x6c, 0x81, 0x02,
	0xe8, 0xa1, 0xdf, 0xfc, 0xb3, 0x80, 0x91, 0x79, 0xd5, 0x9a, 0xfa, 0x20, 0x27, 0x70, 0x3e, 0xf9,
	0xd9, 0x20, 0x6f, 0x6e, 0xb3, 0x8d, 0xf5, 0xdf, 0xc3, 0x4d, 0xce, 0x9f, 0x5d, 0x47, 0x99, 0x6b,
	0xab, 0xc6, 0xcd, 0xe4, 0xc9, 0x96, 0x66, 0xeb, 0xd5, 0x36, 0xb5, 0xb2, 0x5d, 0x6a, 0xa7, 0xc9,
	0xb6, 0xec, 0x42, 0xdd, 0x9a, 0xfc, 0x6b, 0xf1, 0x8f, 0x12, 0xbd, 0x2f, 0xbf, 0xdf, 0x9b, 0xad,
	0x19, 0x63, 0x3f, 0x9a, 0x17, 0xb3, 0x2a, 0x8a, 0xc5, 0x85, 0x55, 0x41, 0x83, 0x16, 0x63, 0xcb,
	0x34, 0xa4, 0xf8, 0x55, 0xcf, 0x97, 0x2c, 0x2e, 0x96, 0xfb, 0xf9, 0x72, 0x31, 0x5e, 0x96, 0xf3,
	0xcf, 0x27, 0xe5, 0xd2, 0xb7, 0x7f, 0x02, 0x00, 0x00, 0xff, 0xff, 0x1f, 0xd3, 0x86, 0x87, 0xb8,
	0x02, 0x00, 0x00,
}
