// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v0/resources/managed_placement_view.proto

package resources // import "google.golang.org/genproto/googleapis/ads/googleads/v0/resources"

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// A managed placement view.
type ManagedPlacementView struct {
	// The resource name of the Managed Placement view.
	// Managed placement view resource names have the form:
	//
	//
	// `customers/{customer_id}/managedPlacementViews/{ad_group_id}_{criterion_id}`
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ManagedPlacementView) Reset()         { *m = ManagedPlacementView{} }
func (m *ManagedPlacementView) String() string { return proto.CompactTextString(m) }
func (*ManagedPlacementView) ProtoMessage()    {}
func (*ManagedPlacementView) Descriptor() ([]byte, []int) {
	return fileDescriptor_managed_placement_view_d5d49526d4cf47f2, []int{0}
}
func (m *ManagedPlacementView) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ManagedPlacementView.Unmarshal(m, b)
}
func (m *ManagedPlacementView) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ManagedPlacementView.Marshal(b, m, deterministic)
}
func (dst *ManagedPlacementView) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ManagedPlacementView.Merge(dst, src)
}
func (m *ManagedPlacementView) XXX_Size() int {
	return xxx_messageInfo_ManagedPlacementView.Size(m)
}
func (m *ManagedPlacementView) XXX_DiscardUnknown() {
	xxx_messageInfo_ManagedPlacementView.DiscardUnknown(m)
}

var xxx_messageInfo_ManagedPlacementView proto.InternalMessageInfo

func (m *ManagedPlacementView) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*ManagedPlacementView)(nil), "google.ads.googleads.v0.resources.ManagedPlacementView")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v0/resources/managed_placement_view.proto", fileDescriptor_managed_placement_view_d5d49526d4cf47f2)
}

var fileDescriptor_managed_placement_view_d5d49526d4cf47f2 = []byte{
	// 237 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xe2, 0xb2, 0x4b, 0xcf, 0xcf, 0x4f,
	0xcf, 0x49, 0xd5, 0x4f, 0x4c, 0x29, 0xd6, 0x87, 0x30, 0x41, 0xac, 0x32, 0x03, 0xfd, 0xa2, 0xd4,
	0xe2, 0xfc, 0xd2, 0xa2, 0xe4, 0xd4, 0x62, 0xfd, 0xdc, 0xc4, 0xbc, 0xc4, 0xf4, 0xd4, 0x94, 0xf8,
	0x82, 0x9c, 0xc4, 0xe4, 0xd4, 0xdc, 0xd4, 0xbc, 0x92, 0xf8, 0xb2, 0xcc, 0xd4, 0x72, 0xbd, 0x82,
	0xa2, 0xfc, 0x92, 0x7c, 0x21, 0x45, 0x88, 0x26, 0xbd, 0xc4, 0x94, 0x62, 0x3d, 0xb8, 0x7e, 0xbd,
	0x32, 0x03, 0x3d, 0xb8, 0x7e, 0x25, 0x6b, 0x2e, 0x11, 0x5f, 0x88, 0x11, 0x01, 0x30, 0x13, 0xc2,
	0x32, 0x53, 0xcb, 0x85, 0x94, 0xb9, 0x78, 0x61, 0x8a, 0xe2, 0xf3, 0x12, 0x73, 0x53, 0x25, 0x18,
	0x15, 0x18, 0x35, 0x38, 0x83, 0x78, 0x60, 0x82, 0x7e, 0x89, 0xb9, 0xa9, 0x4e, 0xf7, 0x18, 0xb9,
	0x54, 0x93, 0xf3, 0x73, 0xf5, 0x08, 0x5a, 0xe3, 0x24, 0x89, 0xcd, 0x92, 0x00, 0x90, 0x23, 0x03,
	0x18, 0xa3, 0xbc, 0xa0, 0xfa, 0xd3, 0xf3, 0x73, 0x12, 0xf3, 0xd2, 0xf5, 0xf2, 0x8b, 0xd2, 0xf5,
	0xd3, 0x53, 0xf3, 0xc0, 0x5e, 0x80, 0x79, 0xbb, 0x20, 0xb3, 0x18, 0x4f, 0x28, 0x58, 0xc3, 0x59,
	0x8b, 0x98, 0x98, 0xdd, 0x1d, 0x1d, 0x57, 0x31, 0x29, 0xba, 0x43, 0x8c, 0x74, 0x4c, 0x29, 0xd6,
	0x83, 0x30, 0x41, 0xac, 0x30, 0x03, 0xbd, 0x20, 0x98, 0xca, 0x53, 0x30, 0x35, 0x31, 0x8e, 0x29,
	0xc5, 0x31, 0x70, 0x35, 0x31, 0x61, 0x06, 0x31, 0x70, 0x35, 0x49, 0x6c, 0x60, 0x47, 0x18, 0x03,
	0x02, 0x00, 0x00, 0xff, 0xff, 0x07, 0x6a, 0x38, 0x21, 0x89, 0x01, 0x00, 0x00,
}
