// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v0/resources/bidding_strategy.proto

package resources // import "google.golang.org/genproto/googleapis/ads/googleads/v0/resources"

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"
import wrappers "github.com/golang/protobuf/ptypes/wrappers"
import common "google.golang.org/genproto/googleapis/ads/googleads/v0/common"
import enums "google.golang.org/genproto/googleapis/ads/googleads/v0/enums"

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// A bidding strategy.
type BiddingStrategy struct {
	// The resource name of the bidding strategy.
	// Bidding strategy resource names have the form:
	//
	// `customers/{customer_id}/biddingStrategies/{bidding_strategy_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The ID of the bidding strategy.
	Id *wrappers.Int64Value `protobuf:"bytes,3,opt,name=id,proto3" json:"id,omitempty"`
	// The name of the bidding strategy.
	// All bidding strategies within an account must be named distinctly.
	//
	// The length of this string should be between 1 and 255, inclusive,
	// in UTF-8 bytes, (trimmed).
	Name *wrappers.StringValue `protobuf:"bytes,4,opt,name=name,proto3" json:"name,omitempty"`
	// The type of the bidding strategy.
	// Create a bidding strategy by setting the bidding scheme.
	//
	// This field is read-only.
	Type enums.BiddingStrategyTypeEnum_BiddingStrategyType `protobuf:"varint,5,opt,name=type,proto3,enum=google.ads.googleads.v0.enums.BiddingStrategyTypeEnum_BiddingStrategyType" json:"type,omitempty"`
	// The bidding scheme.
	//
	// Only one can be set.
	//
	// Types that are valid to be assigned to Scheme:
	//	*BiddingStrategy_EnhancedCpc
	//	*BiddingStrategy_PageOnePromoted
	//	*BiddingStrategy_TargetCpa
	//	*BiddingStrategy_TargetOutrankShare
	//	*BiddingStrategy_TargetRoas
	//	*BiddingStrategy_TargetSpend
	Scheme               isBiddingStrategy_Scheme `protobuf_oneof:"scheme"`
	XXX_NoUnkeyedLiteral struct{}                 `json:"-"`
	XXX_unrecognized     []byte                   `json:"-"`
	XXX_sizecache        int32                    `json:"-"`
}

func (m *BiddingStrategy) Reset()         { *m = BiddingStrategy{} }
func (m *BiddingStrategy) String() string { return proto.CompactTextString(m) }
func (*BiddingStrategy) ProtoMessage()    {}
func (*BiddingStrategy) Descriptor() ([]byte, []int) {
	return fileDescriptor_bidding_strategy_d0682b5c71f925fb, []int{0}
}
func (m *BiddingStrategy) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_BiddingStrategy.Unmarshal(m, b)
}
func (m *BiddingStrategy) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_BiddingStrategy.Marshal(b, m, deterministic)
}
func (dst *BiddingStrategy) XXX_Merge(src proto.Message) {
	xxx_messageInfo_BiddingStrategy.Merge(dst, src)
}
func (m *BiddingStrategy) XXX_Size() int {
	return xxx_messageInfo_BiddingStrategy.Size(m)
}
func (m *BiddingStrategy) XXX_DiscardUnknown() {
	xxx_messageInfo_BiddingStrategy.DiscardUnknown(m)
}

var xxx_messageInfo_BiddingStrategy proto.InternalMessageInfo

func (m *BiddingStrategy) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *BiddingStrategy) GetId() *wrappers.Int64Value {
	if m != nil {
		return m.Id
	}
	return nil
}

func (m *BiddingStrategy) GetName() *wrappers.StringValue {
	if m != nil {
		return m.Name
	}
	return nil
}

func (m *BiddingStrategy) GetType() enums.BiddingStrategyTypeEnum_BiddingStrategyType {
	if m != nil {
		return m.Type
	}
	return enums.BiddingStrategyTypeEnum_UNSPECIFIED
}

type isBiddingStrategy_Scheme interface {
	isBiddingStrategy_Scheme()
}

type BiddingStrategy_EnhancedCpc struct {
	EnhancedCpc *common.EnhancedCpc `protobuf:"bytes,7,opt,name=enhanced_cpc,json=enhancedCpc,proto3,oneof"`
}

type BiddingStrategy_PageOnePromoted struct {
	PageOnePromoted *common.PageOnePromoted `protobuf:"bytes,8,opt,name=page_one_promoted,json=pageOnePromoted,proto3,oneof"`
}

type BiddingStrategy_TargetCpa struct {
	TargetCpa *common.TargetCpa `protobuf:"bytes,9,opt,name=target_cpa,json=targetCpa,proto3,oneof"`
}

type BiddingStrategy_TargetOutrankShare struct {
	TargetOutrankShare *common.TargetOutrankShare `protobuf:"bytes,10,opt,name=target_outrank_share,json=targetOutrankShare,proto3,oneof"`
}

type BiddingStrategy_TargetRoas struct {
	TargetRoas *common.TargetRoas `protobuf:"bytes,11,opt,name=target_roas,json=targetRoas,proto3,oneof"`
}

type BiddingStrategy_TargetSpend struct {
	TargetSpend *common.TargetSpend `protobuf:"bytes,12,opt,name=target_spend,json=targetSpend,proto3,oneof"`
}

func (*BiddingStrategy_EnhancedCpc) isBiddingStrategy_Scheme() {}

func (*BiddingStrategy_PageOnePromoted) isBiddingStrategy_Scheme() {}

func (*BiddingStrategy_TargetCpa) isBiddingStrategy_Scheme() {}

func (*BiddingStrategy_TargetOutrankShare) isBiddingStrategy_Scheme() {}

func (*BiddingStrategy_TargetRoas) isBiddingStrategy_Scheme() {}

func (*BiddingStrategy_TargetSpend) isBiddingStrategy_Scheme() {}

func (m *BiddingStrategy) GetScheme() isBiddingStrategy_Scheme {
	if m != nil {
		return m.Scheme
	}
	return nil
}

func (m *BiddingStrategy) GetEnhancedCpc() *common.EnhancedCpc {
	if x, ok := m.GetScheme().(*BiddingStrategy_EnhancedCpc); ok {
		return x.EnhancedCpc
	}
	return nil
}

func (m *BiddingStrategy) GetPageOnePromoted() *common.PageOnePromoted {
	if x, ok := m.GetScheme().(*BiddingStrategy_PageOnePromoted); ok {
		return x.PageOnePromoted
	}
	return nil
}

func (m *BiddingStrategy) GetTargetCpa() *common.TargetCpa {
	if x, ok := m.GetScheme().(*BiddingStrategy_TargetCpa); ok {
		return x.TargetCpa
	}
	return nil
}

func (m *BiddingStrategy) GetTargetOutrankShare() *common.TargetOutrankShare {
	if x, ok := m.GetScheme().(*BiddingStrategy_TargetOutrankShare); ok {
		return x.TargetOutrankShare
	}
	return nil
}

func (m *BiddingStrategy) GetTargetRoas() *common.TargetRoas {
	if x, ok := m.GetScheme().(*BiddingStrategy_TargetRoas); ok {
		return x.TargetRoas
	}
	return nil
}

func (m *BiddingStrategy) GetTargetSpend() *common.TargetSpend {
	if x, ok := m.GetScheme().(*BiddingStrategy_TargetSpend); ok {
		return x.TargetSpend
	}
	return nil
}

// XXX_OneofFuncs is for the internal use of the proto package.
func (*BiddingStrategy) XXX_OneofFuncs() (func(msg proto.Message, b *proto.Buffer) error, func(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error), func(msg proto.Message) (n int), []interface{}) {
	return _BiddingStrategy_OneofMarshaler, _BiddingStrategy_OneofUnmarshaler, _BiddingStrategy_OneofSizer, []interface{}{
		(*BiddingStrategy_EnhancedCpc)(nil),
		(*BiddingStrategy_PageOnePromoted)(nil),
		(*BiddingStrategy_TargetCpa)(nil),
		(*BiddingStrategy_TargetOutrankShare)(nil),
		(*BiddingStrategy_TargetRoas)(nil),
		(*BiddingStrategy_TargetSpend)(nil),
	}
}

func _BiddingStrategy_OneofMarshaler(msg proto.Message, b *proto.Buffer) error {
	m := msg.(*BiddingStrategy)
	// scheme
	switch x := m.Scheme.(type) {
	case *BiddingStrategy_EnhancedCpc:
		b.EncodeVarint(7<<3 | proto.WireBytes)
		if err := b.EncodeMessage(x.EnhancedCpc); err != nil {
			return err
		}
	case *BiddingStrategy_PageOnePromoted:
		b.EncodeVarint(8<<3 | proto.WireBytes)
		if err := b.EncodeMessage(x.PageOnePromoted); err != nil {
			return err
		}
	case *BiddingStrategy_TargetCpa:
		b.EncodeVarint(9<<3 | proto.WireBytes)
		if err := b.EncodeMessage(x.TargetCpa); err != nil {
			return err
		}
	case *BiddingStrategy_TargetOutrankShare:
		b.EncodeVarint(10<<3 | proto.WireBytes)
		if err := b.EncodeMessage(x.TargetOutrankShare); err != nil {
			return err
		}
	case *BiddingStrategy_TargetRoas:
		b.EncodeVarint(11<<3 | proto.WireBytes)
		if err := b.EncodeMessage(x.TargetRoas); err != nil {
			return err
		}
	case *BiddingStrategy_TargetSpend:
		b.EncodeVarint(12<<3 | proto.WireBytes)
		if err := b.EncodeMessage(x.TargetSpend); err != nil {
			return err
		}
	case nil:
	default:
		return fmt.Errorf("BiddingStrategy.Scheme has unexpected type %T", x)
	}
	return nil
}

func _BiddingStrategy_OneofUnmarshaler(msg proto.Message, tag, wire int, b *proto.Buffer) (bool, error) {
	m := msg.(*BiddingStrategy)
	switch tag {
	case 7: // scheme.enhanced_cpc
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		msg := new(common.EnhancedCpc)
		err := b.DecodeMessage(msg)
		m.Scheme = &BiddingStrategy_EnhancedCpc{msg}
		return true, err
	case 8: // scheme.page_one_promoted
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		msg := new(common.PageOnePromoted)
		err := b.DecodeMessage(msg)
		m.Scheme = &BiddingStrategy_PageOnePromoted{msg}
		return true, err
	case 9: // scheme.target_cpa
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		msg := new(common.TargetCpa)
		err := b.DecodeMessage(msg)
		m.Scheme = &BiddingStrategy_TargetCpa{msg}
		return true, err
	case 10: // scheme.target_outrank_share
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		msg := new(common.TargetOutrankShare)
		err := b.DecodeMessage(msg)
		m.Scheme = &BiddingStrategy_TargetOutrankShare{msg}
		return true, err
	case 11: // scheme.target_roas
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		msg := new(common.TargetRoas)
		err := b.DecodeMessage(msg)
		m.Scheme = &BiddingStrategy_TargetRoas{msg}
		return true, err
	case 12: // scheme.target_spend
		if wire != proto.WireBytes {
			return true, proto.ErrInternalBadWireType
		}
		msg := new(common.TargetSpend)
		err := b.DecodeMessage(msg)
		m.Scheme = &BiddingStrategy_TargetSpend{msg}
		return true, err
	default:
		return false, nil
	}
}

func _BiddingStrategy_OneofSizer(msg proto.Message) (n int) {
	m := msg.(*BiddingStrategy)
	// scheme
	switch x := m.Scheme.(type) {
	case *BiddingStrategy_EnhancedCpc:
		s := proto.Size(x.EnhancedCpc)
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(s))
		n += s
	case *BiddingStrategy_PageOnePromoted:
		s := proto.Size(x.PageOnePromoted)
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(s))
		n += s
	case *BiddingStrategy_TargetCpa:
		s := proto.Size(x.TargetCpa)
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(s))
		n += s
	case *BiddingStrategy_TargetOutrankShare:
		s := proto.Size(x.TargetOutrankShare)
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(s))
		n += s
	case *BiddingStrategy_TargetRoas:
		s := proto.Size(x.TargetRoas)
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(s))
		n += s
	case *BiddingStrategy_TargetSpend:
		s := proto.Size(x.TargetSpend)
		n += 1 // tag and wire
		n += proto.SizeVarint(uint64(s))
		n += s
	case nil:
	default:
		panic(fmt.Sprintf("proto: unexpected type %T in oneof", x))
	}
	return n
}

func init() {
	proto.RegisterType((*BiddingStrategy)(nil), "google.ads.googleads.v0.resources.BiddingStrategy")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v0/resources/bidding_strategy.proto", fileDescriptor_bidding_strategy_d0682b5c71f925fb)
}

var fileDescriptor_bidding_strategy_d0682b5c71f925fb = []byte{
	// 554 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x94, 0xd1, 0x6e, 0xd3, 0x3c,
	0x14, 0xc7, 0x9b, 0x6e, 0xdf, 0xbe, 0xd5, 0x2d, 0x4c, 0x44, 0xbb, 0x88, 0x06, 0x42, 0x1d, 0x08,
	0xa9, 0x30, 0xe4, 0x54, 0x05, 0x21, 0x10, 0x57, 0xed, 0x34, 0xad, 0x54, 0x82, 0x55, 0xe9, 0xd4,
	0x0b, 0x54, 0x88, 0xdc, 0xe4, 0xcc, 0x8d, 0x68, 0x6c, 0xcb, 0x76, 0x86, 0xfa, 0x00, 0xbc, 0x08,
	0x97, 0x3c, 0x0a, 0x6f, 0xc0, 0xdb, 0xa0, 0x38, 0x4e, 0x27, 0x56, 0x4a, 0x7b, 0x77, 0xce, 0xe9,
	0xff, 0xff, 0xf3, 0x39, 0x39, 0x76, 0xd1, 0x6b, 0xca, 0x39, 0x9d, 0x83, 0x4f, 0x62, 0xe5, 0x17,
	0x61, 0x1e, 0x5d, 0xb7, 0x7d, 0x09, 0x8a, 0x67, 0x32, 0x02, 0xe5, 0x4f, 0x93, 0x38, 0x4e, 0x18,
	0x0d, 0x95, 0x96, 0x44, 0x03, 0x5d, 0x60, 0x21, 0xb9, 0xe6, 0xee, 0x71, 0x21, 0xc7, 0x24, 0x56,
	0x78, 0xe9, 0xc4, 0xd7, 0x6d, 0xbc, 0x74, 0x1e, 0x3d, 0x5f, 0x07, 0x8f, 0x78, 0x9a, 0x72, 0x56,
	0x92, 0x0b, 0xe0, 0xd1, 0x9b, 0x75, 0x6a, 0x60, 0x59, 0xba, 0xda, 0x46, 0xa8, 0x17, 0x02, 0xac,
	0xf5, 0xa1, 0xb5, 0x9a, 0x6c, 0x9a, 0x5d, 0xf9, 0x5f, 0x25, 0x11, 0x02, 0xa4, 0x2a, 0x7e, 0x7f,
	0xf4, 0x6d, 0x0f, 0x1d, 0xf4, 0x0a, 0xff, 0xc8, 0xda, 0xdd, 0xc7, 0xe8, 0x4e, 0xd9, 0x69, 0xc8,
	0x48, 0x0a, 0x9e, 0xd3, 0x74, 0x5a, 0xb5, 0xa0, 0x51, 0x16, 0x3f, 0x90, 0x14, 0xdc, 0x13, 0x54,
	0x4d, 0x62, 0x6f, 0xa7, 0xe9, 0xb4, 0xea, 0x9d, 0xfb, 0x76, 0x4c, 0x5c, 0x9e, 0x82, 0xdf, 0x31,
	0xfd, 0xea, 0xe5, 0x98, 0xcc, 0x33, 0x08, 0xaa, 0x49, 0xec, 0xb6, 0xd1, 0xae, 0x01, 0xed, 0x1a,
	0xf9, 0x83, 0x15, 0xf9, 0x48, 0xcb, 0x84, 0xd1, 0x42, 0x6f, 0x94, 0xee, 0x67, 0xb4, 0x9b, 0x4f,
	0xe1, 0xfd, 0xd7, 0x74, 0x5a, 0x77, 0x3b, 0x03, 0xbc, 0xee, 0x93, 0x9a, 0x2f, 0x80, 0x6f, 0x4d,
	0x70, 0xb9, 0x10, 0x70, 0xc6, 0xb2, 0xf4, 0x6f, 0xf5, 0xc0, 0x70, 0xdd, 0x21, 0x6a, 0x00, 0x9b,
	0x11, 0x16, 0x41, 0x1c, 0x46, 0x22, 0xf2, 0xfe, 0x37, 0x9d, 0x9d, 0xac, 0x3d, 0xa7, 0xd8, 0x0b,
	0x3e, 0xb3, 0x9e, 0x53, 0x11, 0xf5, 0x2b, 0x41, 0x1d, 0x6e, 0x52, 0xf7, 0x13, 0xba, 0x27, 0x08,
	0x85, 0x90, 0x33, 0x08, 0x85, 0xe4, 0x29, 0xd7, 0x10, 0x7b, 0xfb, 0x06, 0xeb, 0x6f, 0xc2, 0x0e,
	0x09, 0x85, 0x0b, 0x06, 0x43, 0x6b, 0xeb, 0x57, 0x82, 0x03, 0xf1, 0x67, 0xc9, 0x1d, 0x20, 0xa4,
	0x89, 0xa4, 0xa0, 0xc3, 0x48, 0x10, 0xaf, 0x66, 0xb8, 0x4f, 0x37, 0x71, 0x2f, 0x8d, 0xe3, 0x54,
	0x90, 0x7e, 0x25, 0xa8, 0xe9, 0x32, 0x71, 0xaf, 0xd0, 0xa1, 0x65, 0xf1, 0x4c, 0x4b, 0xc2, 0xbe,
	0x84, 0x6a, 0x46, 0x24, 0x78, 0xc8, 0x50, 0x3b, 0xdb, 0x51, 0x2f, 0x0a, 0xeb, 0x28, 0x77, 0xf6,
	0x2b, 0x81, 0xab, 0x57, 0xaa, 0xee, 0x7b, 0x54, 0xb7, 0xe7, 0x48, 0x4e, 0x94, 0x57, 0x37, 0xf8,
	0x67, 0xdb, 0xe1, 0x03, 0x4e, 0x54, 0xbf, 0x12, 0xd8, 0xa1, 0xf3, 0x2c, 0xdf, 0x99, 0xc5, 0x29,
	0x01, 0x2c, 0xf6, 0x1a, 0xdb, 0xed, 0xac, 0xe0, 0x8d, 0x72, 0x4b, 0xbe, 0x33, 0x7d, 0x93, 0xf6,
	0xf6, 0xd1, 0x9e, 0x8a, 0x66, 0x90, 0x42, 0xef, 0x97, 0x83, 0x9e, 0x44, 0x3c, 0xc5, 0x1b, 0x9f,
	0x6e, 0xef, 0xf0, 0xd6, 0xa5, 0x1a, 0xe6, 0x97, 0x78, 0xe8, 0x7c, 0x1c, 0x58, 0x2b, 0xe5, 0x73,
	0xc2, 0x28, 0xe6, 0x92, 0xfa, 0x14, 0x98, 0xb9, 0xe2, 0xe5, 0xa3, 0x15, 0x89, 0xfa, 0xc7, 0xdf,
	0xc9, 0xdb, 0x65, 0xf4, 0xbd, 0xba, 0x73, 0xde, 0xed, 0xfe, 0xa8, 0x1e, 0x9f, 0x17, 0xc8, 0x6e,
	0xac, 0x70, 0x11, 0xe6, 0xd1, 0xb8, 0x8d, 0x83, 0x52, 0xf9, 0xb3, 0xd4, 0x4c, 0xba, 0xb1, 0x9a,
	0x2c, 0x35, 0x93, 0x71, 0x7b, 0xb2, 0xd4, 0x4c, 0xf7, 0x4c, 0x13, 0x2f, 0x7e, 0x07, 0x00, 0x00,
	0xff, 0xff, 0x20, 0x42, 0x14, 0xed, 0xd2, 0x04, 0x00, 0x00,
}
