// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/dialogflow/v2beta1/audio_config.proto

package dialogflow // import "google.golang.org/genproto/googleapis/cloud/dialogflow/v2beta1"

import proto "github.com/golang/protobuf/proto"
import fmt "fmt"
import math "math"
import _ "google.golang.org/genproto/googleapis/api/annotations"

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion2 // please upgrade the proto package

// Gender of the voice as described in
// [SSML voice element](https://www.w3.org/TR/speech-synthesis11/#edef_voice).
type SsmlVoiceGender int32

const (
	// An unspecified gender, which means that the client doesn't care which
	// gender the selected voice will have.
	SsmlVoiceGender_SSML_VOICE_GENDER_UNSPECIFIED SsmlVoiceGender = 0
	// A male voice.
	SsmlVoiceGender_SSML_VOICE_GENDER_MALE SsmlVoiceGender = 1
	// A female voice.
	SsmlVoiceGender_SSML_VOICE_GENDER_FEMALE SsmlVoiceGender = 2
	// A gender-neutral voice.
	SsmlVoiceGender_SSML_VOICE_GENDER_NEUTRAL SsmlVoiceGender = 3
)

var SsmlVoiceGender_name = map[int32]string{
	0: "SSML_VOICE_GENDER_UNSPECIFIED",
	1: "SSML_VOICE_GENDER_MALE",
	2: "SSML_VOICE_GENDER_FEMALE",
	3: "SSML_VOICE_GENDER_NEUTRAL",
}
var SsmlVoiceGender_value = map[string]int32{
	"SSML_VOICE_GENDER_UNSPECIFIED": 0,
	"SSML_VOICE_GENDER_MALE":        1,
	"SSML_VOICE_GENDER_FEMALE":      2,
	"SSML_VOICE_GENDER_NEUTRAL":     3,
}

func (x SsmlVoiceGender) String() string {
	return proto.EnumName(SsmlVoiceGender_name, int32(x))
}
func (SsmlVoiceGender) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_audio_config_b255710fcad33f7d, []int{0}
}

// Audio encoding of the output audio format in Text-To-Speech.
type OutputAudioEncoding int32

const (
	// Not specified.
	OutputAudioEncoding_OUTPUT_AUDIO_ENCODING_UNSPECIFIED OutputAudioEncoding = 0
	// Uncompressed 16-bit signed little-endian samples (Linear PCM).
	// Audio content returned as LINEAR16 also contains a WAV header.
	OutputAudioEncoding_OUTPUT_AUDIO_ENCODING_LINEAR_16 OutputAudioEncoding = 1
	// MP3 audio.
	OutputAudioEncoding_OUTPUT_AUDIO_ENCODING_MP3 OutputAudioEncoding = 2
	// Opus encoded audio wrapped in an ogg container. The result will be a
	// file which can be played natively on Android, and in browsers (at least
	// Chrome and Firefox). The quality of the encoding is considerably higher
	// than MP3 while using approximately the same bitrate.
	OutputAudioEncoding_OUTPUT_AUDIO_ENCODING_OGG_OPUS OutputAudioEncoding = 3
)

var OutputAudioEncoding_name = map[int32]string{
	0: "OUTPUT_AUDIO_ENCODING_UNSPECIFIED",
	1: "OUTPUT_AUDIO_ENCODING_LINEAR_16",
	2: "OUTPUT_AUDIO_ENCODING_MP3",
	3: "OUTPUT_AUDIO_ENCODING_OGG_OPUS",
}
var OutputAudioEncoding_value = map[string]int32{
	"OUTPUT_AUDIO_ENCODING_UNSPECIFIED": 0,
	"OUTPUT_AUDIO_ENCODING_LINEAR_16":   1,
	"OUTPUT_AUDIO_ENCODING_MP3":         2,
	"OUTPUT_AUDIO_ENCODING_OGG_OPUS":    3,
}

func (x OutputAudioEncoding) String() string {
	return proto.EnumName(OutputAudioEncoding_name, int32(x))
}
func (OutputAudioEncoding) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_audio_config_b255710fcad33f7d, []int{1}
}

// Description of which voice to use for speech synthesis.
type VoiceSelectionParams struct {
	// Optional. The name of the voice. If not set, the service will choose a
	// voice based on the other parameters such as language_code and gender.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Optional. The preferred gender of the voice. If not set, the service will
	// choose a voice based on the other parameters such as language_code and
	// name. Note that this is only a preference, not requirement. If a
	// voice of the appropriate gender is not available, the synthesizer should
	// substitute a voice with a different gender rather than failing the request.
	SsmlGender           SsmlVoiceGender `protobuf:"varint,2,opt,name=ssml_gender,json=ssmlGender,proto3,enum=google.cloud.dialogflow.v2beta1.SsmlVoiceGender" json:"ssml_gender,omitempty"`
	XXX_NoUnkeyedLiteral struct{}        `json:"-"`
	XXX_unrecognized     []byte          `json:"-"`
	XXX_sizecache        int32           `json:"-"`
}

func (m *VoiceSelectionParams) Reset()         { *m = VoiceSelectionParams{} }
func (m *VoiceSelectionParams) String() string { return proto.CompactTextString(m) }
func (*VoiceSelectionParams) ProtoMessage()    {}
func (*VoiceSelectionParams) Descriptor() ([]byte, []int) {
	return fileDescriptor_audio_config_b255710fcad33f7d, []int{0}
}
func (m *VoiceSelectionParams) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_VoiceSelectionParams.Unmarshal(m, b)
}
func (m *VoiceSelectionParams) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_VoiceSelectionParams.Marshal(b, m, deterministic)
}
func (dst *VoiceSelectionParams) XXX_Merge(src proto.Message) {
	xxx_messageInfo_VoiceSelectionParams.Merge(dst, src)
}
func (m *VoiceSelectionParams) XXX_Size() int {
	return xxx_messageInfo_VoiceSelectionParams.Size(m)
}
func (m *VoiceSelectionParams) XXX_DiscardUnknown() {
	xxx_messageInfo_VoiceSelectionParams.DiscardUnknown(m)
}

var xxx_messageInfo_VoiceSelectionParams proto.InternalMessageInfo

func (m *VoiceSelectionParams) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *VoiceSelectionParams) GetSsmlGender() SsmlVoiceGender {
	if m != nil {
		return m.SsmlGender
	}
	return SsmlVoiceGender_SSML_VOICE_GENDER_UNSPECIFIED
}

// Configuration of how speech should be synthesized.
type SynthesizeSpeechConfig struct {
	// Optional. Speaking rate/speed, in the range [0.25, 4.0]. 1.0 is the normal
	// native speed supported by the specific voice. 2.0 is twice as fast, and
	// 0.5 is half as fast. If unset(0.0), defaults to the native 1.0 speed. Any
	// other values < 0.25 or > 4.0 will return an error.
	SpeakingRate float64 `protobuf:"fixed64,1,opt,name=speaking_rate,json=speakingRate,proto3" json:"speaking_rate,omitempty"`
	// Optional. Speaking pitch, in the range [-20.0, 20.0]. 20 means increase 20
	// semitones from the original pitch. -20 means decrease 20 semitones from the
	// original pitch.
	Pitch float64 `protobuf:"fixed64,2,opt,name=pitch,proto3" json:"pitch,omitempty"`
	// Optional. Volume gain (in dB) of the normal native volume supported by the
	// specific voice, in the range [-96.0, 16.0]. If unset, or set to a value of
	// 0.0 (dB), will play at normal native signal amplitude. A value of -6.0 (dB)
	// will play at approximately half the amplitude of the normal native signal
	// amplitude. A value of +6.0 (dB) will play at approximately twice the
	// amplitude of the normal native signal amplitude. We strongly recommend not
	// to exceed +10 (dB) as there's usually no effective increase in loudness for
	// any value greater than that.
	VolumeGainDb float64 `protobuf:"fixed64,3,opt,name=volume_gain_db,json=volumeGainDb,proto3" json:"volume_gain_db,omitempty"`
	// Optional. An identifier which selects 'audio effects' profiles that are
	// applied on (post synthesized) text to speech. Effects are applied on top of
	// each other in the order they are given.
	EffectsProfileId []string `protobuf:"bytes,5,rep,name=effects_profile_id,json=effectsProfileId,proto3" json:"effects_profile_id,omitempty"`
	// Optional. The desired voice of the synthesized audio.
	Voice                *VoiceSelectionParams `protobuf:"bytes,4,opt,name=voice,proto3" json:"voice,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *SynthesizeSpeechConfig) Reset()         { *m = SynthesizeSpeechConfig{} }
func (m *SynthesizeSpeechConfig) String() string { return proto.CompactTextString(m) }
func (*SynthesizeSpeechConfig) ProtoMessage()    {}
func (*SynthesizeSpeechConfig) Descriptor() ([]byte, []int) {
	return fileDescriptor_audio_config_b255710fcad33f7d, []int{1}
}
func (m *SynthesizeSpeechConfig) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SynthesizeSpeechConfig.Unmarshal(m, b)
}
func (m *SynthesizeSpeechConfig) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SynthesizeSpeechConfig.Marshal(b, m, deterministic)
}
func (dst *SynthesizeSpeechConfig) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SynthesizeSpeechConfig.Merge(dst, src)
}
func (m *SynthesizeSpeechConfig) XXX_Size() int {
	return xxx_messageInfo_SynthesizeSpeechConfig.Size(m)
}
func (m *SynthesizeSpeechConfig) XXX_DiscardUnknown() {
	xxx_messageInfo_SynthesizeSpeechConfig.DiscardUnknown(m)
}

var xxx_messageInfo_SynthesizeSpeechConfig proto.InternalMessageInfo

func (m *SynthesizeSpeechConfig) GetSpeakingRate() float64 {
	if m != nil {
		return m.SpeakingRate
	}
	return 0
}

func (m *SynthesizeSpeechConfig) GetPitch() float64 {
	if m != nil {
		return m.Pitch
	}
	return 0
}

func (m *SynthesizeSpeechConfig) GetVolumeGainDb() float64 {
	if m != nil {
		return m.VolumeGainDb
	}
	return 0
}

func (m *SynthesizeSpeechConfig) GetEffectsProfileId() []string {
	if m != nil {
		return m.EffectsProfileId
	}
	return nil
}

func (m *SynthesizeSpeechConfig) GetVoice() *VoiceSelectionParams {
	if m != nil {
		return m.Voice
	}
	return nil
}

// Instructs the speech synthesizer how to generate the output audio content.
type OutputAudioConfig struct {
	// Required. Audio encoding of the synthesized audio content.
	AudioEncoding OutputAudioEncoding `protobuf:"varint,1,opt,name=audio_encoding,json=audioEncoding,proto3,enum=google.cloud.dialogflow.v2beta1.OutputAudioEncoding" json:"audio_encoding,omitempty"`
	// Optional. The synthesis sample rate (in hertz) for this audio. If not
	// provided, then the synthesizer will use the default sample rate based on
	// the audio encoding. If this is different from the voice's natural sample
	// rate, then the synthesizer will honor this request by converting to the
	// desired sample rate (which might result in worse audio quality).
	SampleRateHertz int32 `protobuf:"varint,2,opt,name=sample_rate_hertz,json=sampleRateHertz,proto3" json:"sample_rate_hertz,omitempty"`
	// Optional. Configuration of how speech should be synthesized.
	SynthesizeSpeechConfig *SynthesizeSpeechConfig `protobuf:"bytes,3,opt,name=synthesize_speech_config,json=synthesizeSpeechConfig,proto3" json:"synthesize_speech_config,omitempty"`
	XXX_NoUnkeyedLiteral   struct{}                `json:"-"`
	XXX_unrecognized       []byte                  `json:"-"`
	XXX_sizecache          int32                   `json:"-"`
}

func (m *OutputAudioConfig) Reset()         { *m = OutputAudioConfig{} }
func (m *OutputAudioConfig) String() string { return proto.CompactTextString(m) }
func (*OutputAudioConfig) ProtoMessage()    {}
func (*OutputAudioConfig) Descriptor() ([]byte, []int) {
	return fileDescriptor_audio_config_b255710fcad33f7d, []int{2}
}
func (m *OutputAudioConfig) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_OutputAudioConfig.Unmarshal(m, b)
}
func (m *OutputAudioConfig) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_OutputAudioConfig.Marshal(b, m, deterministic)
}
func (dst *OutputAudioConfig) XXX_Merge(src proto.Message) {
	xxx_messageInfo_OutputAudioConfig.Merge(dst, src)
}
func (m *OutputAudioConfig) XXX_Size() int {
	return xxx_messageInfo_OutputAudioConfig.Size(m)
}
func (m *OutputAudioConfig) XXX_DiscardUnknown() {
	xxx_messageInfo_OutputAudioConfig.DiscardUnknown(m)
}

var xxx_messageInfo_OutputAudioConfig proto.InternalMessageInfo

func (m *OutputAudioConfig) GetAudioEncoding() OutputAudioEncoding {
	if m != nil {
		return m.AudioEncoding
	}
	return OutputAudioEncoding_OUTPUT_AUDIO_ENCODING_UNSPECIFIED
}

func (m *OutputAudioConfig) GetSampleRateHertz() int32 {
	if m != nil {
		return m.SampleRateHertz
	}
	return 0
}

func (m *OutputAudioConfig) GetSynthesizeSpeechConfig() *SynthesizeSpeechConfig {
	if m != nil {
		return m.SynthesizeSpeechConfig
	}
	return nil
}

func init() {
	proto.RegisterType((*VoiceSelectionParams)(nil), "google.cloud.dialogflow.v2beta1.VoiceSelectionParams")
	proto.RegisterType((*SynthesizeSpeechConfig)(nil), "google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig")
	proto.RegisterType((*OutputAudioConfig)(nil), "google.cloud.dialogflow.v2beta1.OutputAudioConfig")
	proto.RegisterEnum("google.cloud.dialogflow.v2beta1.SsmlVoiceGender", SsmlVoiceGender_name, SsmlVoiceGender_value)
	proto.RegisterEnum("google.cloud.dialogflow.v2beta1.OutputAudioEncoding", OutputAudioEncoding_name, OutputAudioEncoding_value)
}

func init() {
	proto.RegisterFile("google/cloud/dialogflow/v2beta1/audio_config.proto", fileDescriptor_audio_config_b255710fcad33f7d)
}

var fileDescriptor_audio_config_b255710fcad33f7d = []byte{
	// 647 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x54, 0x4f, 0x6f, 0xd3, 0x3e,
	0x18, 0xfe, 0xb9, 0x5d, 0x7f, 0xd2, 0x3c, 0xd6, 0x65, 0x66, 0x9a, 0xca, 0xb4, 0xb1, 0xae, 0x03,
	0xa9, 0x9a, 0x50, 0xcb, 0x3a, 0xfe, 0x1c, 0x38, 0x75, 0x6d, 0x56, 0x22, 0xba, 0x26, 0x24, 0xeb,
	0x0e, 0x70, 0xb0, 0xdc, 0xc4, 0x4d, 0x2d, 0x12, 0x3b, 0x24, 0xe9, 0x10, 0x93, 0xf8, 0x08, 0x88,
	0xef, 0x80, 0x38, 0x71, 0xe0, 0xd3, 0x71, 0xe0, 0x88, 0x62, 0x07, 0x36, 0x6d, 0x41, 0xbd, 0xc5,
	0xef, 0xe3, 0xe7, 0xf5, 0xf3, 0x3e, 0x8f, 0x63, 0xd8, 0xf1, 0x85, 0xf0, 0x03, 0xda, 0x76, 0x03,
	0x31, 0xf7, 0xda, 0x1e, 0x23, 0x81, 0xf0, 0xa7, 0x81, 0xf8, 0xd0, 0xbe, 0xe8, 0x4c, 0x68, 0x4a,
	0x0e, 0xdb, 0x64, 0xee, 0x31, 0x81, 0x5d, 0xc1, 0xa7, 0xcc, 0x6f, 0x45, 0xb1, 0x48, 0x05, 0xda,
	0x55, 0x9c, 0x96, 0xe4, 0xb4, 0xae, 0x38, 0xad, 0x9c, 0xb3, 0xb5, 0x9d, 0x37, 0x25, 0x11, 0x6b,
	0x13, 0xce, 0x45, 0x4a, 0x52, 0x26, 0x78, 0xa2, 0xe8, 0x8d, 0x4f, 0x70, 0xe3, 0x5c, 0x30, 0x97,
	0x3a, 0x34, 0xa0, 0x6e, 0x06, 0x58, 0x24, 0x26, 0x61, 0x82, 0x10, 0x5c, 0xe2, 0x24, 0xa4, 0x35,
	0x50, 0x07, 0xcd, 0x65, 0x5b, 0x7e, 0xa3, 0xd7, 0x70, 0x25, 0x49, 0xc2, 0x00, 0xfb, 0x94, 0x7b,
	0x34, 0xae, 0x95, 0xea, 0xa0, 0x59, 0xed, 0x3c, 0x6e, 0x2d, 0x10, 0xd0, 0x72, 0x92, 0x30, 0x90,
	0x67, 0x0c, 0x24, 0xcf, 0x86, 0x59, 0x13, 0xf5, 0xdd, 0xf8, 0x09, 0xe0, 0xa6, 0xf3, 0x91, 0xa7,
	0x33, 0x9a, 0xb0, 0x4b, 0xea, 0x44, 0x94, 0xba, 0xb3, 0x9e, 0x1c, 0x0f, 0xed, 0xc3, 0xd5, 0x24,
	0xa2, 0xe4, 0x1d, 0xe3, 0x3e, 0x8e, 0x49, 0xaa, 0xa4, 0x00, 0xfb, 0xce, 0x9f, 0xa2, 0x4d, 0x52,
	0x8a, 0x36, 0x60, 0x25, 0x62, 0xa9, 0x3b, 0x93, 0x62, 0x80, 0xad, 0x16, 0xe8, 0x01, 0xac, 0x5e,
	0x88, 0x60, 0x1e, 0x52, 0xec, 0x13, 0xc6, 0xb1, 0x37, 0xa9, 0x95, 0x15, 0x57, 0x55, 0x07, 0x84,
	0xf1, 0xfe, 0x04, 0x3d, 0x82, 0x88, 0x4e, 0xa7, 0xd4, 0x4d, 0x13, 0x1c, 0xc5, 0x62, 0xca, 0x02,
	0x8a, 0x99, 0x57, 0xab, 0xd4, 0xcb, 0xcd, 0x65, 0x5b, 0xcb, 0x11, 0x4b, 0x01, 0x86, 0x87, 0x5e,
	0xc1, 0xca, 0x45, 0x36, 0x44, 0x6d, 0xa9, 0x0e, 0x9a, 0x2b, 0x9d, 0xa7, 0x0b, 0xc7, 0x2e, 0xb2,
	0xd5, 0x56, 0x3d, 0x1a, 0x5f, 0x4a, 0x70, 0xdd, 0x9c, 0xa7, 0xd1, 0x3c, 0xed, 0x66, 0x89, 0xe6,
	0x13, 0xbf, 0x85, 0x55, 0x15, 0x30, 0xe5, 0xae, 0xf0, 0x18, 0xf7, 0xe5, 0xc8, 0xd5, 0xce, 0x93,
	0x85, 0x67, 0x5d, 0xeb, 0xa5, 0xe7, 0x5c, 0x7b, 0x95, 0x5c, 0x5f, 0xa2, 0x03, 0xb8, 0x9e, 0x90,
	0x30, 0x0a, 0xa8, 0x34, 0x13, 0xcf, 0x68, 0x9c, 0x5e, 0x4a, 0xd7, 0x2a, 0xf6, 0x9a, 0x02, 0x32,
	0x43, 0x5f, 0x66, 0x65, 0xf4, 0x1e, 0xd6, 0x92, 0xbf, 0xa1, 0xe0, 0x44, 0xa6, 0x92, 0xdf, 0x3a,
	0xe9, 0xe4, 0x4a, 0xe7, 0xf9, 0xe2, 0xd4, 0x0b, 0x53, 0xb5, 0x37, 0x93, 0xc2, 0xfa, 0xc1, 0x67,
	0x00, 0xd7, 0x6e, 0x5c, 0x14, 0xb4, 0x07, 0x77, 0x1c, 0xe7, 0x74, 0x88, 0xcf, 0x4d, 0xa3, 0xa7,
	0xe3, 0x81, 0x3e, 0xea, 0xeb, 0x36, 0x1e, 0x8f, 0x1c, 0x4b, 0xef, 0x19, 0x27, 0x86, 0xde, 0xd7,
	0xfe, 0x43, 0x5b, 0x70, 0xf3, 0xf6, 0x96, 0xd3, 0xee, 0x50, 0xd7, 0x00, 0xda, 0x86, 0xb5, 0xdb,
	0xd8, 0x89, 0x2e, 0xd1, 0x12, 0xda, 0x81, 0xf7, 0x6e, 0xa3, 0x23, 0x7d, 0x7c, 0x66, 0x77, 0x87,
	0x5a, 0xf9, 0xe0, 0x1b, 0x80, 0x77, 0x0b, 0x5c, 0x45, 0x0f, 0xe1, 0x9e, 0x39, 0x3e, 0xb3, 0xc6,
	0x67, 0xb8, 0x3b, 0xee, 0x1b, 0x26, 0xd6, 0x47, 0x3d, 0xb3, 0x6f, 0x8c, 0x06, 0x37, 0x74, 0xed,
	0xc3, 0xdd, 0xe2, 0x6d, 0x43, 0x63, 0xa4, 0x77, 0x6d, 0x7c, 0xf8, 0x4c, 0x03, 0x99, 0x84, 0xe2,
	0x4d, 0xa7, 0xd6, 0x91, 0x56, 0x42, 0x0d, 0x78, 0xbf, 0x18, 0x36, 0x07, 0x03, 0x6c, 0x5a, 0x63,
	0x47, 0x2b, 0x1f, 0xff, 0x00, 0x70, 0xdf, 0x15, 0xe1, 0xa2, 0x34, 0x8e, 0xb5, 0x6b, 0xf7, 0xcc,
	0xca, 0x7e, 0x7c, 0x0b, 0xbc, 0x31, 0x72, 0x92, 0x2f, 0x02, 0xc2, 0xfd, 0x96, 0x88, 0xfd, 0xb6,
	0x4f, 0xb9, 0x7c, 0x16, 0xda, 0x0a, 0x22, 0x11, 0x4b, 0xfe, 0xf9, 0x18, 0xbd, 0xb8, 0x2a, 0xfd,
	0x02, 0xe0, 0x6b, 0xa9, 0xd4, 0x3f, 0xf9, 0x5e, 0xda, 0x1d, 0xa8, 0x9e, 0x3d, 0x29, 0xa4, 0x7f,
	0x25, 0xe4, 0x5c, 0x91, 0x26, 0xff, 0xcb, 0xfe, 0x47, 0xbf, 0x03, 0x00, 0x00, 0xff, 0xff, 0x18,
	0xb5, 0x45, 0x5e, 0xeb, 0x04, 0x00, 0x00,
}
